@@ -127,9 +127,9 @@ sub buildmotif
               $mode++;
             } else {
               if (/^\s*\"(.*)\",.*,\s*"(.*)"}/) {
-                print OUTFILE "$2\n{\"$name\",\"$1\"},\n#endif\n";
+                print OUTFILE "\(char \*\) $2\n{\"$name\", \(char \*\) \"$1\"},\n#endif\n";
               } elsif (/^\s*\"(.*)\",.*,\s*(.*)}/) { #NULL
-                print OUTFILE "{\"$name\",\"$1\"},\n";
+                print OUTFILE "{\(char \*\) \"$name\", \(char \*\) \"$1\"},\n";
               } else {
                 print OUTFILE "#$_#\n";
               }
