@@ -70,6 +70,9 @@ LockStruct  LockProcs[] =
 	{"ant",
 	 1000, -3, 40000, -7, 64, 1.0, "",
 	 "Shows Langton's and Turk's generalized ants", 0, NULL, NULL},
+	{"apollonian",
+	 1000000, 64, 20, 1, 64, 1.0, "",
+	"Shows Apollonian Circles", 0, NULL, NULL},
 #ifdef USE_GL
 	{"atlantis",
 	 18000, 4, 100, 6000, 64, 1.0, "",
@@ -404,10 +407,10 @@ LockStruct  LockProcs[] =
 	{"tetris",
 	 50000, 1, 1, -100, 64, 1.0, "",
 	 "Shows an autoplaying tetris game", 0, NULL, NULL},
-#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )
+#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT )
 	{"text3d",
 	 100000, 1, 1, 1, 64, 1.0, "",
-	 "Shows 3D text", 0, NULL, "#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )"},
+	 "Shows 3D text", 0, NULL, "#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT )"},
 #endif
 	{"thornbird",
 	 1000, 800, 16, 1, 64, 1.0, "",
