@@ -651,6 +651,7 @@ listbox $LISTSCROL.list -yscroll  "$LISTSCROL.scroll set"
 #---------------------------
 $LISTSCROL.list  insert 0 \
 ant\
+apollonian\
 atlantis\
 ball\
 bat\
@@ -713,6 +714,7 @@ marquee\
 matrix\
 maze\
 moebius\
+molecule\
 morph3d\
 mountain\
 munch\
