@@ -75,6 +75,7 @@ add("North", Panel3);
 
 add("Center",lst);
 lst.addItem("ant");
+lst.addItem("apollonian");
 lst.addItem("atlantis");
 lst.addItem("ball");
 lst.addItem("bat");
@@ -137,6 +138,7 @@ lst.addItem("marquee");
 lst.addItem("matrix");
 lst.addItem("maze");
 lst.addItem("moebius");
+lst.addItem("molecule");
 lst.addItem("morph3d");
 lst.addItem("mountain");
 lst.addItem("munch");
