@@ -12,19 +12,20 @@
 
 XCOMM !!!WARNING!!! Known security hole with MesaGL < 3.0 if setuid root
 XCOMM Define these now or down further below, see below for explaination.
-XCOMM  #define CPPCompiler
-XCOMM  #define XpmLibrary
-XCOMM  #define XmLibrary
-XCOMM  #define GLLibrary
-XCOMM  #define TtfLibrary
-XCOMM  #define GlttLibrary
-XCOMM  #define DtSaverLibrary
-XCOMM  #define DPMSLibrary
-XCOMM  #define RplayLibrary
+#define CPPCompiler
+#define XpmLibrary
+#define XmLibrary
+#define GLLibrary
+XCOMM #define TtfLibrary
+XCOMM #define GlttLibrary
+#define DtSaverLibrary
+#define DPMSLibrary
+XCOMM #define RplayLibrary
 XCOMM  #define NasLibrary
-XCOMM  #define Modules
+#define Modules
 XCOMM  #define Check
-XCOMM  #define Unstable
+#define Unstable
+XCOMM #define DisableInteractive
 
 N =
 O = .o
@@ -45,17 +46,14 @@ XCOMM  CC = CC
 XCOMM  CC = gcc -Wall
 XCOMM  CC = g++ -Wall
 XCOMM  CXX = g++ -Wall
-XCOMM  CXX = CC
+CC = CC
+CXX = CC
 
 LN_S = $(LN)
 
 XCOMM   *** BEGIN C++ CONFIG SECTION ***
 
-XCOMM Only the solitare, invert.c, and text3d.cc modes use this.
-XCOMM modes use this.
-XCOMM If your system has libXpm, remove the 'XCOMM  ' from the next line.
-XCOMM  #define CPPCompiler
-
+XCOMM Only the solitare.cc, invert.c, and text3d.cc modes use this.
 XCOMM If your system has C++, remove the 'XCOMM  ' from the next line.
 #ifdef CPPCompiler
 CPPDEF = -DHAVE_CXX
@@ -77,8 +75,9 @@ XCOMM   *** END C++ CONFIG SECTION ***
 
 XCOMM   *** BEGIN XPM CONFIG SECTION ***
 
-XCOMM Only the bat.c, flag.c, image.c, maze.c, and puzzle.c
-XCOMM modes use this.
+XCOMM Only the bat.c, bounce.c, decay.c, flag.c, image.c, life.c life1d.c
+XCOMM maze.c, puzzle.c, atlantis.c, fire.c, glplanet.c, and sballs modes
+XCOMM use this but they do not depend on it (they just look better).
 XCOMM If your system has libXpm, remove the 'XCOMM  ' from the next line.
 XCOMM  #define XpmLibrary
 
@@ -89,13 +88,13 @@ XCOMM  XPMDEF = -DUSE_XPMINC
 
 XCOMM If you get an error "Cannot find xpm.h" while compiling, set
 XCOMM XPMINC to the directory X11/xpm.h is in.  Below is a guess.
-XPMINC = -I/usr/local/include
+XPMINC = -I/usr/remote/include
 XCOMM SGI's ViewKit (use with -DUSE_XPMINC)
 XCOMM  XPMINC = -I/usr/include/Vk
 
 XCOMM If you get an error "Cannot find libXpm" while linking, set XPMLIBPATH
 XCOMM to the directory libXpm.* is in.  Below is a guess.
-XPMLIB = -L/usr/local/lib -lXpm
+XPMLIB = -L/usr/remote/lib -lXpm
 
 #endif
 
@@ -148,10 +147,10 @@ XCOMM !!!WARNING!!! Known security hole with MesaGL < 3.0 if setuid root
 GLLIB = -L/usr/local/lib -lGL -lGLU
 XCOMM   GLLIB = -L/usr/local/lib -lMesaGL -lMesaGLU
 
-#if SGIArchitecture
+#ifdef SGIArchitecture
 GLLIB = -lGL -lGLU -lgl
 #endif
-#if SunArchitecture
+#ifdef SunArchitecture
 XCOMM with OGL1.1
 GLDEF += -DSUN_OGL_NO_VERTEX_MACROS
 #endif
@@ -185,8 +184,11 @@ XCOMM  #define DPMSLibrary
 
 #ifdef DPMSLibrary
 DTSAVERDEF = -DUSE_DPMS
+XCOMM where are these include files anyway?
 XCOMM DPMSINC =
-DPMSLIB = -lXdpms
+XCOMM DPMSLIB = -lXdpms
+XCOMM -lXdpms may not be required
+XCOMM DPMSLIB =
 #endif
 
 XCOMM   *** END DPMS CONFIG SECTION ***
@@ -213,13 +215,13 @@ SOUNDLIB = -L/usr/X11R6/lib -laudio
 
 XCOMM system play (optional software)
 XCOMM SUNOS 4.1.3
-XCOMM  DEF_PLAY = "/usr/demo/SOUND/play /usr/local/share/sounds/xlock/"
+XCOMM  DEF_PLAY = "/usr/demo/SOUND/play /usr/lib/X11/xlock/sounds/"
 XCOMM IRIX 5.3
-XCOMM  DEF_PLAY = "/usr/sbin/sfplay /usr/local/share/sounds/xlock/"
+XCOMM  DEF_PLAY = "/usr/sbin/sfplay /usr/lib/X11/xlock/sounds/"
 XCOMM Digital Unix with Multimedia Services installed:
-XCOMM  DEF_PLAY = "/usr/bin/mme/decsound -play /usr/local/share/sounds/xlock/"
+XCOMM  DEF_PLAY = "/usr/bin/mme/decsound -play /usr/lib/X11/xlock/sounds/"
 XCOMM LINUX and others (see config directory)
-XCOMM  DEF_PLAY = "/usr/local/bin/play.sh /usr/local/share/sounds/xlock/"
+XCOMM  DEF_PLAY = "/usr/local/bin/play.sh /usr/lib/X11/xlock/sounds/"
 XCOMM Uncomment line below if you have one of the above
 XCOMM  SOUNDDEF = -DDEF_PLAY=\"$(DEF_PLAY)\"
 
@@ -269,7 +271,7 @@ XCOMM #define UseElfFormat YES
 
 XCOMM This is the default directory to look in for modules. It can be
 XCOMM a colon separated list of directories.
-DEF_MODULEPATH = $(USRLIBDIR)/X11/xlock_modules
+DEF_MODULEPATH = $(USRLIBDIR)/X11/xlock/modules
 
 #ifdef LinuxArchitecture
 XCOMM Flag to compile the main program so that global variables will be
@@ -299,13 +301,15 @@ XCOMM      *** END DEBUG CHECK SECTION ***
 
 XCOMM      *** BEGIN INTERACTIVE CHECK SECTION ***
 
-#define DisableInteractive
+XCOMM #define DisableInteractive
 
 #ifdef DisableInteractive
 XCOMM Can disable interactive modes for production environments
 INTERACTIVEDEF = -DDISABLE_INTERACTIVE
 #endif
 
+XCOMM      *** END INTERACTIVE CHECK SECTION ***
+
 XCOMM      *** BEGIN UNSTABLE CHECK SECTION ***
 
 XCOMM #define Unstable
@@ -367,7 +371,7 @@ XCOMM  #endif
 PASSWDDEF = -DHAVE_SHADOW
 
 XCOMM Problems finding libXext.so.0 when sticky bit is set
-EXTRA_LDOPTIONS = -R/usr/lib:/usr/openwin/lib:/usr/dt/lib:/usr/local/lib
+EXTRA_LDOPTIONS = -R/usr/lib:/usr/openwin/lib:/usr/dt/lib:/usr/remote/lib
 
 #if OSMajorVersion == 2 && OSMinorVersion < 7
 PIXMAPTYPE = sol
@@ -540,7 +544,7 @@ $(SOUNDDEF) $(PASSWDINC) $(XPMINC) $(GLINC) $(DTSAVERINC) $(DPMSINC) \
 $(SOUNDINC) $(XLOCKINC)
 
 DEPLIBS = $(DEPXLIB)
-#if SGIArchitecture
+#ifdef SGIArchitecture
 FIRSTLIB = -L/usr/lib32
 #endif
 LOCAL_LIBRARIES = $(FIRSTLIB) $(MODULELIB) $(XLIB) \
