@@ -118,12 +118,12 @@ ModeSpecOpt ant_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
-ModStruct   ant_description =
-{(char *) "ant",
- (char *) "init_ant", (char *) "draw_ant", (char *) "release_ant",
- (char *) "refresh_ant", (char *) "init_ant", NULL, &ant_opts,
- 1000, -3, 40000, -12, 64, 1.0, (char *) "",
- (char *) "Shows Langton's and Turk's generalized ants", 0, NULL};
+const ModStruct ant_description =
+{"ant",
+ "init_ant", "draw_ant", "release_ant",
+ "refresh_ant", "init_ant", (char *) NULL, &ant_opts,
+ 1000, -3, 40000, -12, 64, 1.0, "",
+ "Shows Langton's and Turk's generalized ants", 0, NULL};
 
 #endif
 
@@ -206,7 +206,7 @@ static char plots[] =
 #define STHL 10			/* Step then turn hard left */
 #define STL 11			/* Step then turn left */
 
-static antfarmstruct *antfarms = NULL;
+static antfarmstruct *antfarms = (antfarmstruct *) NULL;
 
 /* LANGTON'S ANT (10) Chaotic after 500, Builder after 10,000 (104p) */
 /* TURK'S 100 ANT Always chaotic?, tested past 150,000,000 */
@@ -983,15 +983,15 @@ free_ant(Display *display, antfarmstruct *ap)
 	ap->init_bits = 0;
 	if (ap->tape != NULL) {
 		(void) free((void *) ap->tape);
-		ap->tape = NULL;
+		ap->tape = (unsigned char *) NULL;
 	}
 	if (ap->ants != NULL) {
 		(void) free((void *) ap->ants);
-		ap->ants = NULL;
+		ap->ants = (antstruct *) NULL;
 	}
 	if (ap->truchet_state != NULL) {
 		(void) free((void *) ap->truchet_state);
-		ap->truchet_state = NULL;
+		ap->truchet_state = (unsigned char *) NULL;
 	}
 }
 
@@ -1036,7 +1036,7 @@ init_ant(ModeInfo * mi)
 		/* if ap->n is random ... the size can change */
 		if (ap->ants != NULL) {
 			(void) free((void *) ap->ants);
-			ap->ants = NULL;
+			ap->ants = (antstruct *) NULL;
 		}
 		ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;
 	} else if (ap->n < MINANTS)
@@ -1324,7 +1324,7 @@ release_ant(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_ant(MI_DISPLAY(mi), &antfarms[screen]);
 		(void) free((void *) antfarms);
-		antfarms = NULL;
+		antfarms = (antfarmstruct *) NULL;
 	}
 }
 
