@@ -44,12 +44,12 @@ static const char sccsid[] = "@(#)ball.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_ball
 
 ModeSpecOpt ball_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   ball_description =
+const ModStruct ball_description =
 {"ball", "init_ball", "draw_ball", "release_ball",
- "refresh_ball", "init_ball", NULL, &ball_opts,
+ "refresh_ball", "init_ball", (char *) NULL, &ball_opts,
  10000, 10, 20, -100, 64, 1.0, "",
  "Shows bouncing balls", 0, NULL};
 
@@ -91,7 +91,7 @@ typedef struct {
 	int         dispx, dispy;
 } ballstruct;
 
-static ballstruct *balls = NULL;
+static ballstruct *balls = (ballstruct *) NULL;
 
 static void
 collided(ModeInfo * mi, int i, int n, int *dx, int *dy, int td)
@@ -298,7 +298,7 @@ free_ball(Display *display, ballstruct *bp)
 			}
 		}
 		(void) free((void *) bp->bt);
-		bp->bt = NULL;
+		bp->bt = (balltype *) NULL;
 	}
 }
 
@@ -327,7 +327,7 @@ init_ball(ModeInfo * mi)
 		/* if bp->nballs is random ... the size can change */
 		if (bp->bt != NULL) {
 			(void) free((void *) bp->bt);
-			bp->bt = NULL;
+			bp->bt = (balltype *) NULL;
 		}
 		bp->nballs = NRAND(-bp->nballs - MINBALLS + 1) + MINBALLS;
 	} else if (bp->nballs < MINBALLS)
@@ -519,7 +519,7 @@ release_ball(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_ball(MI_DISPLAY(mi), &balls[screen]);
 		(void) free((void *) balls);
-		balls = NULL;
+		balls = (ballstruct *) NULL;
 	}
 }
 
