@@ -82,9 +82,9 @@ ModeSpecOpt bat_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   bat_description =
+const ModStruct bat_description =
 {"bat", "init_bat", "draw_bat", "release_bat",
- "refresh_bat", "init_bat", NULL, &bat_opts,
+ "refresh_bat", "init_bat", (char *) NULL, &bat_opts,
  100000, -8, 1, 0, 64, 1.0, "",
  "Shows bouncing flying bats", 0, NULL};
 
@@ -173,7 +173,7 @@ typedef struct {
 	XImage     *images[ORIENTS / 2 + 1];
 } bouncestruct;
 
-static bouncestruct *bounces = NULL;
+static bouncestruct *bounces = (bouncestruct *) NULL;
 
 static unsigned char *bits[] =
 {
@@ -380,7 +380,7 @@ free_bat(Display *display, bouncestruct *bp)
 	free_stuff(display, bp);
 	if (bp->bats != NULL) {
 		(void) free((void *) bp->bats);
-		bp->bats = NULL;
+		bp->bats = (batstruct *) NULL;
 	}
 	if (bp->pixmap != None) {
 		XFreePixmap(display, bp->pixmap);
@@ -530,7 +530,7 @@ init_bat(ModeInfo * mi)
 		/* if bp->nbats is random ... the size can change */
 		if (bp->bats != NULL) {
 			(void) free((void *) bp->bats);
-			bp->bats = NULL;
+			bp->bats = (batstruct *)NULL;
 		}
 		bp->nbats = NRAND(-bp->nbats - MINBATS + 1) + MINBATS;
 	} else if (bp->nbats < MINBATS)
@@ -685,7 +685,7 @@ release_bat(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bat(MI_DISPLAY(mi), &bounces[screen]);
 		(void) free((void *) bounces);
-		bounces = NULL;
+		bounces = (bouncestruct *) NULL;
 	}
 }
 
