@@ -59,12 +59,12 @@ static const char sccsid[] = "@(#)blot.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_blot
 
 ModeSpecOpt blot_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   blot_description =
+const ModStruct blot_description =
 {"blot", "init_blot", "draw_blot", "release_blot",
- "refresh_blot", "init_blot", NULL, &blot_opts,
+ "refresh_blot", "init_blot", (char *) NULL, &blot_opts,
  200000, 6, 30, 1, 64, 0.3, "",
  "Shows Rorschach's ink blot test", 0, NULL};
 
@@ -83,7 +83,7 @@ typedef struct {
 	unsigned int pointBufferSize;
 } blotstruct;
 
-static blotstruct *blots = NULL;
+static blotstruct *blots = (blotstruct *) NULL;
 
 void
 init_blot(ModeInfo * mi)
@@ -202,7 +202,7 @@ release_blot(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) blots);
-		blots = NULL;
+		blots = (blotstruct *) NULL;
 	}
 }
 
