@@ -65,9 +65,9 @@ ModeSpecOpt bomb_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   bomb_description =
+const ModStruct bomb_description =
 {"bomb", "init_bomb", "draw_bomb", "release_bomb",
- "refresh_bomb", "change_bomb", NULL, &bomb_opts,
+ "refresh_bomb", "change_bomb", (char *) NULL, &bomb_opts,
  100000, 10, 20, 1, 64, 1.0, "",
  "Shows a bomb and will autologout after a time", 0, NULL};
 
@@ -203,7 +203,7 @@ release_bomb(ModeInfo * mi)
 {
 	if (bombs != NULL) {
 		(void) free((void *) bombs);
-		bombs = NULL;
+		bombs = (bombstruct *) NULL;
 	}
 	free_font(MI_DISPLAY(mi));
 }
@@ -327,26 +327,24 @@ init_bomb(ModeInfo * mi)
 	bp->moveok = 0;
 }
 
-	/*
-	 *  Game Over
-	 */
+extern void logoutUser(Display * display);
+#ifdef SunCplusplus
+/* #include <signal.h> */
+extern int  kill(pid_t, int);
+#else
+#if 0
+extern int  kill(int, int);
+#endif
+#endif
+
+/*
+ *  Game Over
+ */
 static void
 explode(ModeInfo * mi)
 {
 	bombstruct *bp = &bombs[MI_SCREEN(mi)];
 	char        buff[NDIGITS + 2];
-	extern void logoutUser(Display * display);
-
-#ifdef SunCplusplus
-/* #include <signal.h> */
-	extern int  kill(pid_t, int);
-
-#else
-#if 0
-	extern int  kill(int, int);
-
-#endif
-#endif
 
 	/*
 	 *  ToDo:
