@@ -96,9 +96,9 @@ ModeSpecOpt bouboule_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   bouboule_description =
+const ModStruct bouboule_description =
 {"bouboule", "init_bouboule", "draw_bouboule", "release_bouboule",
- "refresh_bouboule", "init_bouboule", NULL, &bouboule_opts,
+ "refresh_bouboule", "init_bouboule", (char *) NULL, &bouboule_opts,
  10000, 100, 1, 15, 64, 1.0, "",
  "Shows Mimi's bouboule of moving stars", 0, NULL};
 
@@ -246,7 +246,7 @@ typedef struct StarFieldStruct
 #endif
 } StarField;
 
-static StarField *starfield = NULL;
+static StarField *starfield = (StarField *) NULL;
 
 /*********/
 static void
@@ -321,24 +321,24 @@ free_stars(StarField *sp)
 {
 	if (sp->star != NULL) {
 		(void) free((void *) sp->star);
-		sp->star = NULL;
+		sp->star = (Star *) NULL;
 	}
 	if (sp->xarc != NULL) {
 		(void) free((void *) sp->xarc);
-		sp->xarc = NULL;
+		sp->xarc = (XArc *) NULL;
 	}
 	if (sp->xarcleft != NULL) {
 		(void) free((void *) sp->xarcleft);
-		sp->xarcleft = NULL;
+		sp->xarcleft = (XArc *) NULL;
 	}
 #if ((USEOLDXARCS == 1) || (ADAPT_ERASE == 1))
 	if (sp->oldxarc != NULL) {
 		(void) free((void *) sp->oldxarc);
-		sp->oldxarc = NULL;
+		sp->oldxarc = (XArc *) NULL;
 	}
 	if (sp->oldxarcleft != NULL) {
 		(void) free((void *) sp->oldxarcleft);
-		sp->oldxarcleft = NULL;
+		sp->oldxarcleft = (XArc *) NULL;
 	}
 #endif
 }
@@ -525,10 +525,10 @@ init_bouboule(ModeInfo * mi)
 	}
 	for (i = 0; i < sp->NbStars; i++) {
 		Star       *star;
-		XArc       *arc, *arcleft = NULL;
+		XArc       *arc, *arcleft = (XArc *) NULL;
 
 #if ((USEOLDXARCS == 1) || (ADAPT_ERASE == 1))
-		XArc       *oarc, *oarcleft = NULL;
+		XArc       *oarc, *oarcleft = (XArc *) NULL;
 
 #endif
 
@@ -632,7 +632,7 @@ draw_bouboule(ModeInfo * mi)
 	int         i, diff = 0;
 	double      CX, CY, CZ, SX, SY, SZ;
 	Star       *star;
-	XArc       *arc, *arcleft = NULL;
+	XArc       *arc, *arcleft = (XArc *) NULL;
 	StarField  *sp;
 
 #if (ADAPT_ERASE == 1)
@@ -773,10 +773,10 @@ draw_bouboule(ModeInfo * mi)
 		    ADAPT_ARC_PREFERED * sp->rect_time) {
 			sp->hasbeenchecked = -2;	/* XFillRectangle mode */
 			(void) free((void *) sp->oldxarc);
-			sp->oldxarc = NULL;
+			sp->oldxarc = (XArc *) NULL;
 			if (MI_IS_USE3D(mi)) {
 				(void) free((void *) sp->oldxarcleft);
-				sp->oldxarcleft = NULL;
+				sp->oldxarcleft = (XArc *) NULL;
 			}
 		} else {
 			sp->hasbeenchecked = -1;	/* XFillArcs mode */
@@ -892,7 +892,7 @@ release_bouboule(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bouboule(&starfield[screen]);
 		(void) free((void *) starfield);
-		starfield = NULL;
+		starfield = (StarField *) NULL;
 	}
 }
 
