@@ -103,9 +103,9 @@ ModeSpecOpt bounce_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-ModStruct   bounce_description =
+const ModStruct bounce_description =
 {"bounce", "init_bounce", "draw_bounce", "release_bounce",
- "refresh_bounce", "init_bounce", NULL, &bounce_opts,
+ "refresh_bounce", "init_bounce", (char *) NULL, &bounce_opts,
  5000, -10, 1, 0, 64, 1.0, "",
  "Shows bouncing footballs", 0, NULL};
 
@@ -182,7 +182,7 @@ typedef struct {
 	ballwindow *windows;
 } bouncestruct;
 
-static bouncestruct *bounces = NULL;
+static bouncestruct *bounces = (bouncestruct *) NULL;
 
 static void
 checkCollision(bouncestruct * bp, int aball)
@@ -461,7 +461,7 @@ bounce_windows(ModeInfo * mi, bouncestruct * bp)
 			XFree((caddr_t) children);
 			bp->nwindow = 0;
 			(void) free((void *) bp->windows);
-			bp->windows = NULL;
+			bp->windows = (ballwindow *) NULL;
 			return;
 		}
 		if ((att.x < 0) || (att.x > bp->width) ||
@@ -517,7 +517,7 @@ free_bounce(Display *display, bouncestruct *bp)
 {
 	if (bp->balls != NULL) {
 		(void) free((void *) bp->balls);
-		bp->balls = NULL;
+		bp->balls = (ballstruct *) NULL;
 	}
 	free_stuff(display, bp);
 	if (bp->stippledGC != None) {
@@ -526,7 +526,7 @@ free_bounce(Display *display, bouncestruct *bp)
 	}
 	if (bp->windows != NULL) {
 		(void) free((void *) bp->windows);
-		bp->windows = NULL;
+		bp->windows = (ballwindow *) NULL;
 	}
 
 }
@@ -608,7 +608,7 @@ init_bounce(ModeInfo * mi)
 		/* if bp->nballs is random ... the size can change */
 		if (bp->balls != NULL) {
 			(void) free((void *) bp->balls);
-			bp->balls = NULL;
+			bp->balls = (ballstruct *) NULL;
 		}
 		bp->nballs = NRAND(-bp->nballs - MINBALLS + 1) + MINBALLS;
 	} else if (bp->nballs < MINBALLS)
@@ -754,7 +754,7 @@ release_bounce(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bounce(MI_DISPLAY(mi), &bounces[screen]);
 		(void) free((void *) bounces);
-		bounces = NULL;
+		bounces = (bouncestruct *) NULL;
 	}
 }
 
