@@ -56,7 +56,7 @@ ModeSpecOpt braid_opts =
 #ifdef USE_MODULES
 ModStruct   braid_description =
 {"braid", "init_braid", "draw_braid", "release_braid",
- "refresh_braid", "init_braid", NULL, &braid_opts,
+ "refresh_braid", "init_braid", (char *) NULL, &braid_opts,
  1000, 15, 100, 1, 64, 1.0, "",
  "Shows random braids and knots", 0, NULL};
 
@@ -103,7 +103,7 @@ typedef struct {
 	int         color_direction;
 } braidtype;
 
-static braidtype *braids = NULL;
+static braidtype *braids = (braidtype *) NULL;
 
 static int
 applyword(braidtype * braid, int string, int position)
@@ -437,7 +437,7 @@ release_braid(ModeInfo * mi)
 {
 	if (braids != NULL) {
 		(void) free((void *) braids);
-		braids = NULL;
+		braids = (braidtype *) NULL;
 	}
 }
 
