@@ -69,7 +69,7 @@ ModeSpecOpt bubble_opts =
 #ifdef USE_MODULES
 ModStruct   bubble_description =
 {"bubble", "init_bubble", "draw_bubble", "release_bubble",
- "refresh_bubble", "init_bubble", NULL, &bubble_opts,
+ "refresh_bubble", "init_bubble", (char *) NULL, &bubble_opts,
  100000, 25, 1, 100, 64, 0.6, "",
  "Shows popping bubbles", 0, NULL};
 
@@ -94,7 +94,7 @@ typedef struct {
 	GC          dbuf_gc;
 } bubblestruct;
 
-static bubblestruct *bubbles = NULL;
+static bubblestruct *bubbles = (bubblestruct *) NULL;
 
 static void
 updateBubble(ModeInfo * mi, int i)
@@ -178,7 +178,7 @@ free_bubble(Display *display, bubblestruct *bp)
 	}
 	if (bp->bubble != NULL) {
 		(void) free((void *) bp->bubble);
-		bp->bubble = NULL;
+		bp->bubble = (bubbletype *) NULL;
 	}
 }
 
@@ -299,7 +299,7 @@ release_bubble(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bubble(MI_DISPLAY(mi), &bubbles[screen]);
 		(void) free((void *) bubbles);
-		bubbles = NULL;
+		bubbles = (bubblestruct *) NULL;
 	}
 }
 
