@@ -84,7 +84,7 @@ ModeSpecOpt bug_opts =
 #ifdef USE_MODULES
 ModStruct   bug_description =
 {"bug", "init_bug", "draw_bug", "release_bug",
- "refresh_bug", "init_bug", NULL, &bug_opts,
+ "refresh_bug", "init_bug", (char *) NULL, &bug_opts,
  75000, 10, 32767, -4, 64, 1.0, "",
  "Shows Palmiter's bug evolution and garden of Eden", 0, NULL};
 
@@ -175,7 +175,7 @@ static char plots[] =
 
 #define NEIGHBORKINDS (long) (sizeof plots / sizeof *plots)
 
-static bugfarmstruct *bugfarms = NULL;
+static bugfarmstruct *bugfarms = (bugfarmstruct *) NULL;
 
 #if 0
 static void
@@ -772,19 +772,19 @@ free_buglist(bugfarmstruct *bp)
 	if (bp->firstbug != NULL) {
 		flush_buglist(bp);
 		(void) free((void *) bp->firstbug);
-		bp->firstbug = NULL;
+		bp->firstbug = (BugList *) NULL;
 	}
 	if (bp->lastbug != NULL) {
 		(void) free((void *) bp->lastbug);
-		bp->lastbug = NULL;
+		bp->lastbug = (BugList *) NULL;
 	}
 	if (bp->lasttemp != NULL) {
 		(void) free((void *) bp->lasttemp);
-		bp->lasttemp = NULL;
+		bp->lasttemp = (BugList *) NULL;
 	}
 	if (bp->firsttemp != NULL) {
 		(void) free((void *) bp->firsttemp);
-		bp->firsttemp = NULL;
+		bp->firsttemp = (BugList *) NULL;
 	}
 }
 
@@ -801,8 +801,8 @@ init_buglist(bugfarmstruct * bp)
 		free_buglist(bp);
 		return False;
 	}
-	bp->firstbug->previous = bp->lastbug->next = NULL;
-	bp->firstbug->next = bp->lastbug->previous = NULL;
+	bp->firstbug->previous = bp->lastbug->next = (struct _BugList *) NULL;
+	bp->firstbug->next = bp->lastbug->previous = (struct _BugList *) NULL;
 	bp->firstbug->next = bp->lastbug;
 	bp->lastbug->previous = bp->firstbug;
 
@@ -814,8 +814,8 @@ init_buglist(bugfarmstruct * bp)
 		free_buglist(bp);
 		return False;
 	}
-	bp->firsttemp->previous = bp->lasttemp->next = NULL;
-	bp->firsttemp->next = bp->lasttemp->previous = NULL;
+	bp->firsttemp->previous = bp->lasttemp->next = (struct _BugList *) NULL;
+	bp->firsttemp->next = bp->lasttemp->previous = (struct _BugList *) NULL;
 	bp->firsttemp->next = bp->lasttemp;
 	bp->lasttemp->previous = bp->firsttemp;
 	return True;
@@ -1018,27 +1018,27 @@ free_bug(Display *display, bugfarmstruct *bp)
 	if (bp->firstbug != NULL) {
 		flush_buglist(bp);
 		(void) free((void *) bp->firstbug);
-		bp->firstbug = NULL;
+		bp->firstbug = (BugList *) NULL;
 	}
 	if (bp->lastbug != NULL) {
 		(void) free((void *) bp->lastbug);
-		bp->lastbug = NULL;
+		bp->lastbug = (BugList *) NULL;
 	}
 	if (bp->lasttemp != NULL) {
 		(void) free((void *) bp->lasttemp);
-		bp->lasttemp = NULL;
+		bp->lasttemp = (BugList *) NULL;
 	}
 	if (bp->firsttemp != NULL) {
 		(void) free((void *) bp->firsttemp);
-		bp->firsttemp = NULL;
+		bp->firsttemp = (BugList *) NULL;
 	}
 	if (bp->arr != NULL) {
 		(void) free((void *) bp->arr);
-		bp->arr = NULL;
+		bp->arr = (BugList **) NULL;
 	}
 	if (bp->bacteria != NULL) {
 		(void) free((void *) bp->bacteria);
-		bp->bacteria = NULL;
+		bp->bacteria = (char *) NULL;
 	}
 }
 
@@ -1404,7 +1404,7 @@ release_bug(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bug(MI_DISPLAY(mi), &bugfarms[screen]);
 		(void) free((void *) bugfarms);
-		bugfarms = NULL;
+		bugfarms = (bugfarmstruct *) NULL;
 	}
 }
 
