@@ -57,7 +57,7 @@ ModeSpecOpt clock_opts =
 #ifdef USE_MODULES
 ModStruct   clock_description =
 {"clock", "init_clock", "draw_clock", "release_clock",
- "refresh_clock", "init_clock", NULL, &clock_opts,
+ "refresh_clock", "init_clock", (char *) NULL, &clock_opts,
  100000, -16, 200, -200, 64, 1.0, "",
  "Shows Packard's clock", 0, NULL};
 
@@ -115,7 +115,7 @@ typedef struct {
 	int         redrawing;
 } clockstruct;
 
-static clockstruct *clocks = NULL;
+static clockstruct *clocks = (clockstruct *) NULL;
 
 static int
 myrand(int minimum, int maximum)
@@ -369,7 +369,7 @@ init_clock(ModeInfo * mi)
 		/* if cp->nclocks is random ... the size can change */
 		if (cp->oclocks != NULL) {
 			(void) free((void *) cp->oclocks);
-			cp->oclocks = NULL;
+			cp->oclocks = (oclock *) NULL;
 		}
 		cp->nclocks = NRAND(-cp->nclocks - MINCLOCKS + 1) + MINCLOCKS;
 	} else if (cp->nclocks < MINCLOCKS)
@@ -452,11 +452,11 @@ release_clock(ModeInfo * mi)
 
 			if (cp->oclocks != NULL) {
 				(void) free((void *) cp->oclocks);
-				/* cp->oclocks = NULL; */
+				/* cp->oclocks = (oclock *) NULL; */
 			}
 		}
 		(void) free((void *) clocks);
-		clocks = NULL;
+		clocks = (clockstruct *) NULL;
 	}
 }
 
