@@ -150,7 +150,7 @@ ModeSpecOpt crystal_opts =
 #ifdef USE_MODULES
 ModStruct   crystal_description =
 {"crystal", "init_crystal", "draw_crystal", "release_crystal",
- "refresh_crystal", "init_crystal", NULL, &crystal_opts,
+ "refresh_crystal", "init_crystal", (char *) NULL, &crystal_opts,
  60000, -40, 200, -15, 64, 1.0, "",
  "Shows polygons in 2D plane groups", 0, NULL};
 
@@ -273,7 +273,7 @@ typedef struct {
 	ModeInfo   *mi;
 } crystalstruct;
 
-static crystalstruct *crystals = NULL;
+static crystalstruct *crystals = (crystalstruct *) NULL;
 
 static void
 trans_coor(XPoint * xyp, XPoint * new_xyp, int num_points,
@@ -578,7 +578,7 @@ free_crystal(Display *display, crystalstruct *cryst)
 			if (cryst->ncolors && !cryst->no_colors)
 				free_colors(display, cryst->cmap, cryst->colors, cryst->ncolors);
 			(void) free((void *) cryst->colors);
-			cryst->colors = NULL;
+			cryst->colors = (XColor *) NULL;
 		}
 		if (cryst->cmap != None) {
 			XFreeColormap(display, cryst->cmap);
@@ -591,258 +591,14 @@ free_crystal(Display *display, crystalstruct *cryst)
 	}
 	if (cryst->atom != NULL) {
 		(void) free((void *) cryst->atom);
-		cryst->atom = NULL;
+		cryst->atom = (crystalatom *) NULL;
 	}
 }
 
-void
-draw_crystal(ModeInfo * mi)
-{
-	Display    *display = MI_DISPLAY(mi);
-	int         i;
-	crystalstruct *cryst;
-
-	if (crystals == NULL)
-		return;
-	cryst = &crystals[MI_SCREEN(mi)];
-	if (cryst->atom == NULL)
-		return;
-
-	if (cryst->no_colors) {
-		free_crystal(display, cryst);
-		init_crystal(mi);
-		return;
-	}
-	cryst->painted = True;
-	MI_IS_DRAWN(mi) = True;
-	XSetFunction(display, cryst->gc, GXxor);
-
-/* Rotate colours */
-	if (cryst->cycle_p) {
-		rotate_colors(display, cryst->cmap, cryst->colors, cryst->ncolors,
-			      cryst->direction);
-		if (!(LRAND() % 1000))
-			cryst->direction = -cryst->direction;
-	}
-	for (i = 0; i < cryst->num_atom; i++) {
-		crystalatom *atom0;
-
-		atom0 = &cryst->atom[i];
-		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
-			XSetForeground(display, cryst->gc, cryst->colors[atom0->colour].pixel);
-		} else {
-			XSetForeground(display, cryst->gc, atom0->colour);
-		}
-		crystal_drawatom(mi, atom0);
-		atom0->velocity[0] += NRAND(3) - 1;
-		atom0->velocity[0] = MAX(-20, MIN(20, atom0->velocity[0]));
-		atom0->velocity[1] += NRAND(3) - 1;
-		atom0->velocity[1] = MAX(-20, MIN(20, atom0->velocity[1]));
-		atom0->x0 += atom0->velocity[0];
-		/*if (cryst->gamma == 90.0) { */
-		if (atom0->x0 < 0)
-			atom0->x0 += cryst->a;
-		else if (atom0->x0 >= cryst->a)
-			atom0->x0 -= cryst->a;
-		atom0->y0 += atom0->velocity[1];
-		if (atom0->y0 < 0)
-			atom0->y0 += cryst->b;
-		else if (atom0->y0 >= cryst->b)
-			atom0->y0 -= cryst->b;
-		/*} */
-		atom0->velocity_a += ((float) NRAND(1001) - 500.0) / 2000.0;
-		atom0->angle += atom0->velocity_a;
-		crystal_setupatom(atom0, cryst->gamma);
-		crystal_drawatom(mi, atom0);
-	}
-	XSetFunction(display, cryst->gc, GXcopy);
-}
-
-void
-refresh_crystal(ModeInfo * mi)
-{
-	Display    *display = MI_DISPLAY(mi);
-	Window      window = MI_WINDOW(mi);
-	int         i;
-	crystalstruct *cryst;
-
-	if (crystals == NULL)
-		return;
-	cryst = &crystals[MI_SCREEN(mi)];
-	if (cryst->atom == NULL)
-		return;
-
-	if (!cryst->painted)
-		return;
-	MI_CLEARWINDOW(mi);
-
-	if (cryst->unit_cell) {
-	   int y_coor1 , y_coor2;
-
-		if (MI_NPIXELS(mi) > 2)
-			XSetForeground(display, cryst->gc, MI_PIXEL(mi, NRAND(MI_NPIXELS(mi))));
-		else
-			XSetForeground(display, cryst->gc, MI_WHITE_PIXEL(mi));
-		if (cryst->grid_cell) {
-			int         inx, iny;
-
-		   if ( cryst->invert )
-		     y_coor1 = y_coor2 = cryst->win_height - cryst->offset_h;
-		   else
-		     y_coor1 = y_coor2 = cryst->offset_h;
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
-				  y_coor1, cryst->offset_w + cryst->nx * cryst->a,
-				  y_coor2);
-		   if ( cryst->invert )
-		     {
-			y_coor1 = cryst->win_height - cryst->offset_h;
-			y_coor2 = cryst->win_height - (int) (cryst->ny *
-							     cryst->b *
-					 cos((cryst->gamma - 90) * PI_RAD)) -
-			  cryst->offset_h;
-		     }
-		   else
-		     {
-			y_coor1 = cryst->offset_h;
-			y_coor2 = (int) (cryst->ny * cryst->b *
-					 cos((cryst->gamma - 90) * PI_RAD)) +
-			  cryst->offset_h;
-		     }
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
-				  y_coor1, (int) (cryst->offset_w - cryst->ny * cryst->b *
-					  sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor2);
-			inx = cryst->nx;
-			for (iny = 1; iny <= cryst->ny; iny++) {
-		   if ( cryst->invert )
-		     {
-			y_coor1 = cryst->win_height -
-			  (int) (iny * cryst->b * cos((cryst->gamma - 90) *
-						  PI_RAD)) - cryst->offset_h;
-			y_coor2 = cryst->win_height -
-			  (int) (iny * cryst->b * cos((cryst->gamma - 90) *
-						      PI_RAD)) -
-			  cryst->offset_h;
-		     }
-		   else
-		     {
-			y_coor1 = (int) (iny * cryst->b * cos((cryst->gamma - 90) *
-						  PI_RAD)) + cryst->offset_h;
-			y_coor2 = (int) (iny * cryst->b * cos((cryst->gamma - 90) * PI_RAD)) +
-					  cryst->offset_h;
-		     }
-				XDrawLine(display, window, cryst->gc,
-					  (int) (cryst->offset_w +
-				     inx * cryst->a - (int) (iny * cryst->b *
-					 sin((cryst->gamma - 90) * PI_RAD))),
-					  y_coor1,
-				    (int) (cryst->offset_w - iny * cryst->b *
-					   sin((cryst->gamma - 90) * PI_RAD)),
-					  y_coor2);
-			}
-			iny = cryst->ny;
-			for (inx = 1; inx <= cryst->nx; inx++) {
-			   if ( cryst->invert )
-			     {
-				y_coor1 =cryst->win_height -
-				  (int) (iny * cryst->b *
-						cos((cryst->gamma - 90) *
-						    PI_RAD)) - cryst->offset_h;
-				y_coor2 =cryst->win_height - cryst->offset_h;
-			     }
-			   else
-			     {
-				y_coor1 =(int) (iny * cryst->b *
-						cos((cryst->gamma - 90) *
-						    PI_RAD)) + cryst->offset_h;
-				y_coor2 =cryst->offset_h;
-			     }
-				XDrawLine(display, window, cryst->gc,
-					  (int) (cryst->offset_w +
-				     inx * cryst->a - (int) (iny * cryst->b *
-					 sin((cryst->gamma - 90) * PI_RAD))),
-					  y_coor1,
-					  cryst->offset_w + inx * cryst->a,
-					  y_coor2);
-			}
-		} else {
-			int         inx, iny;
-
-			inx = NRAND(cryst->nx);
-			iny = NRAND(cryst->ny);
-		   if ( cryst->invert )
-		     {
-			y_coor1 =cryst->win_height -
-			  (int) (iny * cryst->b *
-						  cos((cryst->gamma - 90) *
-						      PI_RAD)) -
-			  cryst->offset_h;
-			y_coor2 =cryst->win_height -
-			  (int) ( ( iny + 1 ) * cryst->b *
-						  cos((cryst->gamma - 90) *
-						      PI_RAD)) -
-			  cryst->offset_h;
-		     }
-		   else
-		     {
-			y_coor1 =(int) (iny * cryst->b *
-						  cos((cryst->gamma - 90) *
-						      PI_RAD)) +
-			  cryst->offset_h;
-			y_coor2 =(int) (( iny + 1 ) * cryst->b *
-						  cos((cryst->gamma - 90) *
-						      PI_RAD)) +
-			  cryst->offset_h;
-		     }
-			XDrawLine(display, window, cryst->gc,
-				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor1,
-				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor1);
-			XDrawLine(display, window, cryst->gc,
-				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor1,
-				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
-				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor1,
-				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
-				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor2,
-				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
-				  y_coor2);
-		}
-	}
-	XSetFunction(display, cryst->gc, GXxor);
-	for (i = 0; i < cryst->num_atom; i++) {
-		crystalatom *atom0;
-
-		atom0 = &cryst->atom[i];
-		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
-			XSetForeground(display, cryst->gc, cryst->colors[atom0->colour].pixel);
-		} else {
-			XSetForeground(display, cryst->gc, atom0->colour);
-		}
-		crystal_drawatom(mi, atom0);
-	}
-	XSetFunction(display, cryst->gc, GXcopy);
-}
-
-void
-release_crystal(ModeInfo * mi)
-{
-	if (crystals != NULL) {
-		int         screen;
-
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_crystal(MI_DISPLAY(mi), &crystals[screen]);
-		(void) free((void *) crystals);
-		crystals = NULL;
-	}
-}
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
 
 void
 init_crystal(ModeInfo * mi)
@@ -869,9 +625,6 @@ init_crystal(ModeInfo * mi)
 			XColor      color;
 
 #ifndef STANDALONE
-			extern char *background;
-			extern char *foreground;
-
 			cryst->fg = MI_FG_PIXEL(mi);
 			cryst->bg = MI_BG_PIXEL(mi);
 #endif
@@ -897,7 +650,7 @@ init_crystal(ModeInfo * mi)
 			(void) XAllocColor(display, cryst->cmap, &color);
 			MI_FG_PIXEL(mi) = color.pixel;
 #endif
-			cryst->colors = NULL;
+			cryst->colors = (XColor *) NULL;
 			cryst->ncolors = 0;
 		}
 		if ((cryst->gc = XCreateGC(display, MI_WINDOW(mi),
@@ -1199,7 +952,7 @@ init_crystal(ModeInfo * mi)
 			if (cryst->ncolors && !cryst->no_colors)
 				free_colors(display, cryst->cmap, cryst->colors, cryst->ncolors);
 			(void) free((void *) cryst->colors);
-			cryst->colors = NULL;
+			cryst->colors = (XColor *) NULL;
 		}
 		cryst->ncolors = MI_NCOLORS(mi);
 		if (cryst->ncolors < 2)
@@ -1210,7 +963,7 @@ init_crystal(ModeInfo * mi)
 			cryst->mono_p = False;
 
 		if (cryst->mono_p)
-			cryst->colors = NULL;
+			cryst->colors = (XColor *) NULL;
 		else
 			if ((cryst->colors = (XColor *) malloc(sizeof (*cryst->colors) *
 					(cryst->ncolors + 1))) == NULL) {
@@ -1312,4 +1065,253 @@ init_crystal(ModeInfo * mi)
 	XSetFunction(display, cryst->gc, GXcopy);
 }
 
+void
+draw_crystal(ModeInfo * mi)
+{
+	Display    *display = MI_DISPLAY(mi);
+	int         i;
+	crystalstruct *cryst;
+
+	if (crystals == NULL)
+		return;
+	cryst = &crystals[MI_SCREEN(mi)];
+	if (cryst->atom == NULL)
+		return;
+
+	if (cryst->no_colors) {
+		free_crystal(display, cryst);
+		init_crystal(mi);
+		return;
+	}
+	cryst->painted = True;
+	MI_IS_DRAWN(mi) = True;
+	XSetFunction(display, cryst->gc, GXxor);
+
+/* Rotate colours */
+	if (cryst->cycle_p) {
+		rotate_colors(display, cryst->cmap, cryst->colors, cryst->ncolors,
+			      cryst->direction);
+		if (!(LRAND() % 1000))
+			cryst->direction = -cryst->direction;
+	}
+	for (i = 0; i < cryst->num_atom; i++) {
+		crystalatom *atom0;
+
+		atom0 = &cryst->atom[i];
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XSetForeground(display, cryst->gc, cryst->colors[atom0->colour].pixel);
+		} else {
+			XSetForeground(display, cryst->gc, atom0->colour);
+		}
+		crystal_drawatom(mi, atom0);
+		atom0->velocity[0] += NRAND(3) - 1;
+		atom0->velocity[0] = MAX(-20, MIN(20, atom0->velocity[0]));
+		atom0->velocity[1] += NRAND(3) - 1;
+		atom0->velocity[1] = MAX(-20, MIN(20, atom0->velocity[1]));
+		atom0->x0 += atom0->velocity[0];
+		/*if (cryst->gamma == 90.0) { */
+		if (atom0->x0 < 0)
+			atom0->x0 += cryst->a;
+		else if (atom0->x0 >= cryst->a)
+			atom0->x0 -= cryst->a;
+		atom0->y0 += atom0->velocity[1];
+		if (atom0->y0 < 0)
+			atom0->y0 += cryst->b;
+		else if (atom0->y0 >= cryst->b)
+			atom0->y0 -= cryst->b;
+		/*} */
+		atom0->velocity_a += ((float) NRAND(1001) - 500.0) / 2000.0;
+		atom0->angle += atom0->velocity_a;
+		crystal_setupatom(atom0, cryst->gamma);
+		crystal_drawatom(mi, atom0);
+	}
+	XSetFunction(display, cryst->gc, GXcopy);
+}
+
+void
+refresh_crystal(ModeInfo * mi)
+{
+	Display    *display = MI_DISPLAY(mi);
+	Window      window = MI_WINDOW(mi);
+	int         i;
+	crystalstruct *cryst;
+
+	if (crystals == NULL)
+		return;
+	cryst = &crystals[MI_SCREEN(mi)];
+	if (cryst->atom == NULL)
+		return;
+
+	if (!cryst->painted)
+		return;
+	MI_CLEARWINDOW(mi);
+
+	if (cryst->unit_cell) {
+	   int y_coor1 , y_coor2;
+
+		if (MI_NPIXELS(mi) > 2)
+			XSetForeground(display, cryst->gc, MI_PIXEL(mi, NRAND(MI_NPIXELS(mi))));
+		else
+			XSetForeground(display, cryst->gc, MI_WHITE_PIXEL(mi));
+		if (cryst->grid_cell) {
+			int         inx, iny;
+
+		   if ( cryst->invert )
+		     y_coor1 = y_coor2 = cryst->win_height - cryst->offset_h;
+		   else
+		     y_coor1 = y_coor2 = cryst->offset_h;
+			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+				  y_coor1, cryst->offset_w + cryst->nx * cryst->a,
+				  y_coor2);
+		   if ( cryst->invert )
+		     {
+			y_coor1 = cryst->win_height - cryst->offset_h;
+			y_coor2 = cryst->win_height - (int) (cryst->ny *
+							     cryst->b *
+					 cos((cryst->gamma - 90) * PI_RAD)) -
+			  cryst->offset_h;
+		     }
+		   else
+		     {
+			y_coor1 = cryst->offset_h;
+			y_coor2 = (int) (cryst->ny * cryst->b *
+					 cos((cryst->gamma - 90) * PI_RAD)) +
+			  cryst->offset_h;
+		     }
+			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+				  y_coor1, (int) (cryst->offset_w - cryst->ny * cryst->b *
+					  sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor2);
+			inx = cryst->nx;
+			for (iny = 1; iny <= cryst->ny; iny++) {
+		   if ( cryst->invert )
+		     {
+			y_coor1 = cryst->win_height -
+			  (int) (iny * cryst->b * cos((cryst->gamma - 90) *
+						  PI_RAD)) - cryst->offset_h;
+			y_coor2 = cryst->win_height -
+			  (int) (iny * cryst->b * cos((cryst->gamma - 90) *
+						      PI_RAD)) -
+			  cryst->offset_h;
+		     }
+		   else
+		     {
+			y_coor1 = (int) (iny * cryst->b * cos((cryst->gamma - 90) *
+						  PI_RAD)) + cryst->offset_h;
+			y_coor2 = (int) (iny * cryst->b * cos((cryst->gamma - 90) * PI_RAD)) +
+					  cryst->offset_h;
+		     }
+				XDrawLine(display, window, cryst->gc,
+					  (int) (cryst->offset_w +
+				     inx * cryst->a - (int) (iny * cryst->b *
+					 sin((cryst->gamma - 90) * PI_RAD))),
+					  y_coor1,
+				    (int) (cryst->offset_w - iny * cryst->b *
+					   sin((cryst->gamma - 90) * PI_RAD)),
+					  y_coor2);
+			}
+			iny = cryst->ny;
+			for (inx = 1; inx <= cryst->nx; inx++) {
+			   if ( cryst->invert )
+			     {
+				y_coor1 =cryst->win_height -
+				  (int) (iny * cryst->b *
+						cos((cryst->gamma - 90) *
+						    PI_RAD)) - cryst->offset_h;
+				y_coor2 =cryst->win_height - cryst->offset_h;
+			     }
+			   else
+			     {
+				y_coor1 =(int) (iny * cryst->b *
+						cos((cryst->gamma - 90) *
+						    PI_RAD)) + cryst->offset_h;
+				y_coor2 =cryst->offset_h;
+			     }
+				XDrawLine(display, window, cryst->gc,
+					  (int) (cryst->offset_w +
+				     inx * cryst->a - (int) (iny * cryst->b *
+					 sin((cryst->gamma - 90) * PI_RAD))),
+					  y_coor1,
+					  cryst->offset_w + inx * cryst->a,
+					  y_coor2);
+			}
+		} else {
+			int         inx, iny;
+
+			inx = NRAND(cryst->nx);
+			iny = NRAND(cryst->ny);
+		   if ( cryst->invert )
+		     {
+			y_coor1 =cryst->win_height -
+			  (int) (iny * cryst->b *
+						  cos((cryst->gamma - 90) *
+						      PI_RAD)) -
+			  cryst->offset_h;
+			y_coor2 =cryst->win_height -
+			  (int) ( ( iny + 1 ) * cryst->b *
+						  cos((cryst->gamma - 90) *
+						      PI_RAD)) -
+			  cryst->offset_h;
+		     }
+		   else
+		     {
+			y_coor1 =(int) (iny * cryst->b *
+						  cos((cryst->gamma - 90) *
+						      PI_RAD)) +
+			  cryst->offset_h;
+			y_coor2 =(int) (( iny + 1 ) * cryst->b *
+						  cos((cryst->gamma - 90) *
+						      PI_RAD)) +
+			  cryst->offset_h;
+		     }
+			XDrawLine(display, window, cryst->gc,
+				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor1,
+				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor1);
+			XDrawLine(display, window, cryst->gc,
+				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor1,
+				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor2);
+			XDrawLine(display, window, cryst->gc,
+				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor1,
+				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor2);
+			XDrawLine(display, window, cryst->gc,
+				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor2,
+				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
+				  y_coor2);
+		}
+	}
+	XSetFunction(display, cryst->gc, GXxor);
+	for (i = 0; i < cryst->num_atom; i++) {
+		crystalatom *atom0;
+
+		atom0 = &cryst->atom[i];
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XSetForeground(display, cryst->gc, cryst->colors[atom0->colour].pixel);
+		} else {
+			XSetForeground(display, cryst->gc, atom0->colour);
+		}
+		crystal_drawatom(mi, atom0);
+	}
+	XSetFunction(display, cryst->gc, GXcopy);
+}
+
+void
+release_crystal(ModeInfo * mi)
+{
+	if (crystals != NULL) {
+		int         screen;
+
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_crystal(MI_DISPLAY(mi), &crystals[screen]);
+		(void) free((void *) crystals);
+		crystals = (crystalstruct *) NULL;
+	}
+}
+
 #endif /* MODE_crystal */
