@@ -266,7 +266,7 @@ ModeSpecOpt dclock_opts =
 #ifdef USE_MODULES
 ModStruct   dclock_description =
 {"dclock", "init_dclock", "draw_dclock", "release_dclock",
- "refresh_dclock", "init_dclock", NULL, &dclock_opts,
+ "refresh_dclock", "init_dclock", (char *) NULL, &dclock_opts,
  10000, 1, 10000, 1, 64, 0.3, "",
  "Shows a floating digital clock or message", 0, NULL};
 
@@ -406,7 +406,7 @@ typedef struct {
 	XPoint      parallelogram[4];
 } dclockstruct;
 
-static dclockstruct *dclocks = NULL;
+static dclockstruct *dclocks = (dclockstruct *) NULL;
 
 
 static unsigned long
@@ -888,20 +888,21 @@ release_dclock(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dclock(MI_DISPLAY(mi), &dclocks[screen]);
 		(void) free((void *) dclocks);
-		dclocks = NULL;
+		dclocks = (dclockstruct *) NULL;
 	}
 	free_font(MI_DISPLAY(mi));
 }
 
+#if defined(HAVE_TZSET) && !(defined(BSD) && BSD >= 199306) && !(defined(__CYGWIN__))
+extern long timezone;
+#endif
+
 void
 init_dclock(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	dclockstruct *dp;
 	long timeNow, timeLocal;
-#if defined(HAVE_TZSET) && (!defined(HAVE_TIMELOCAL) || (defined(BSD) && BSD >= 199306))
-	extern long timezone;
-#endif
 
 	if (dclocks == NULL) {
 #ifndef HAVE_SNPRINTF
