@@ -72,7 +72,7 @@ ModeSpecOpt decay_opts =
 #ifdef USE_MODULES
 ModStruct   decay_description =
 {"decay", "init_decay", "draw_decay", "release_decay",
- "refresh_decay", "init_decay", NULL, &decay_opts,
+ "refresh_decay", "init_decay", (char *) NULL, &decay_opts,
  200000, 6, 30, 1, 64, 0.3, "",
  "Shows a decaying screen", 0, NULL};
 
@@ -103,7 +103,7 @@ typedef struct
 	Bool     hide;
 } decaystruct;
 
-static decaystruct *	decay_info = NULL;
+static decaystruct *decay_info = (decaystruct *) NULL;
 
 #define SHUFFLE 0
 #define UP 1
@@ -276,7 +276,7 @@ draw_decay (ModeInfo * mi)
     static int downleft_bias[]  = { L,L,L,L, L,R,R,R, U,U,U,D, D,D,D,D };
     static int upright_bias[]   = { L,L,L,R, R,R,R,R, U,U,U,U, U,D,D,D };
     static int downright_bias[] = { L,L,L,R, R,R,R,R, U,U,U,D, D,D,D,D };
-    static int *bias;
+    int *bias, side;
     decaystruct * dp;
 
 	if (decay_info == NULL)
@@ -297,7 +297,11 @@ draw_decay (ModeInfo * mi)
       case DOWNRIGHT:	bias = downright_bias; break;
       case IN:		bias = no_bias; break;
       case OUT:		bias = no_bias; break;
-      default: abort();
+      default: bias = no_bias;
+	 if (MI_IS_VERBOSE(mi)) {
+             (void) fprintf(stderr, "Weirdness in draw_decay()\n");
+             (void) fprintf(stderr, "dp->mode = %d\n", dp->mode);
+         }
     }
 
     left = NRAND(dp->windowsize.x - 1);
@@ -326,12 +330,17 @@ draw_decay (ModeInfo * mi)
       }
     }
 
-    switch (bias[LRAND() % (sizeof(no_bias)/sizeof(*no_bias))]) {
+    side = bias[LRAND() % (sizeof(no_bias)/sizeof(*no_bias))];
+    switch (side) {
       case L: toleft = left-DEGREE; break;
       case R: toleft = left+DEGREE; break;
       case U: totop = top-DEGREE; break;
       case D: totop = top+DEGREE; break;
-      default: abort(); break;
+      default:
+	 if (MI_IS_VERBOSE(mi)) {
+             (void) fprintf(stderr, "Weirdness in draw_decay()\n");
+             (void) fprintf(stderr, "side = %d\n", side);
+         }
     }
 
     XCopyArea (MI_DISPLAY(mi), MI_WINDOW(mi), MI_WINDOW(mi),
@@ -369,7 +378,7 @@ release_decay(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_decay(MI_DISPLAY(mi), &decay_info[screen]);
 		(void) free((void *) decay_info);
-		decay_info = NULL;
+		decay_info = (decaystruct *) NULL;
 	}
 }
 
