@@ -95,7 +95,7 @@ ModeSpecOpt demon_opts =
 #ifdef USE_MODULES
 ModStruct   demon_description =
 {"demon", "init_demon", "draw_demon", "release_demon",
- "refresh_demon", "init_demon", NULL, &demon_opts,
+ "refresh_demon", "init_demon", (char *) NULL, &demon_opts,
  50000, 0, 1000, -7, 64, 1.0, "",
  "Shows Griffeath's cellular automata", 0, NULL};
 
@@ -146,7 +146,7 @@ static char plots[2][NEIGHBORKINDS] =
 	{12, 16, 18, 20, 22, 24}	/* Number of states */
 };
 
-static demonstruct *demons = NULL;
+static demonstruct *demons = (demonstruct *) NULL;
 
 static void
 drawcell(ModeInfo * mi, int col, int row, unsigned char state)
@@ -256,7 +256,7 @@ free_state(demonstruct * dp, int state)
 		dp->cellList[state] = dp->cellList[state]->next;
 		(void) free((void *) current);
 	}
-	dp->cellList[state] = NULL;
+	dp->cellList[state] = (CellList *) NULL;
 	if (dp->ncells != NULL)
 		dp->ncells[state] = 0;
 }
@@ -270,7 +270,7 @@ free_list(demonstruct * dp)
 	for (state = 0; state < dp->states; state++)
 		free_state(dp, state);
 	(void) free((void *) dp->cellList);
-	dp->cellList = NULL;
+	dp->cellList = (CellList **) NULL;
 }
 
 static void
@@ -281,15 +281,15 @@ free_struct(demonstruct * dp)
 	}
 	if (dp->ncells != NULL) {
 		(void) free((void *) dp->ncells);
-		dp->ncells = NULL;
+		dp->ncells = (int *) NULL;
 	}
 	if (dp->oldcell != NULL) {
 		(void) free((void *) dp->oldcell);
-		dp->oldcell = NULL;
+		dp->oldcell = (unsigned char *) NULL;
 	}
 	if (dp->newcell != NULL) {
 		(void) free((void *) dp->newcell);
-		dp->newcell = NULL;
+		dp->newcell = (unsigned char *) NULL;
 	}
 }
 
@@ -947,7 +947,7 @@ release_demon(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_demon(MI_DISPLAY(mi), &demons[screen]);
 		(void) free((void *) demons);
-		demons = NULL;
+		demons = (demonstruct *) NULL;
 	}
 }
 
