@@ -121,7 +121,7 @@ ModeSpecOpt dilemma_opts =
 #ifdef USE_MODULES
 ModStruct   dilemma_description =
 {"dilemma", "init_dilemma", "draw_dilemma", "release_dilemma",
- "refresh_dilemma", "init_dilemma", NULL, &dilemma_opts,
+ "refresh_dilemma", "init_dilemma", (char *) NULL, &dilemma_opts,
  200000, -2, 1000, 0, 64, 1.0, "",
  "Shows Lloyd's Prisoner's Dilemma simulation", 0, NULL};
 
@@ -190,7 +190,7 @@ static char plots[NEIGHBORKINDS] =
 	3, 4, 6, 8, 9, 12	/* Neighborhoods */
 };
 
-static dilemmastruct *dilemmas = NULL;
+static dilemmastruct *dilemmas = (dilemmastruct *) NULL;
 static int  icon_width, icon_height;
 
 static void
@@ -335,7 +335,7 @@ free_state(dilemmastruct * dp, int state)
 		dp->cellList[state] = dp->cellList[state]->next;
 		(void) free((void *) current);
 	}
-	dp->cellList[state] = NULL;
+	dp->cellList[state] = (CellList *) NULL;
 }
 
 
@@ -354,15 +354,15 @@ free_dilemma(dilemmastruct *dp)
 	free_list(dp);
 	if (dp->sn != NULL) {
 		(void) free((void *) dp->sn);
-		dp->sn = NULL;
+		dp->sn = (char *) NULL;
 	}
 	if (dp->s != NULL) {
 		(void) free((void *) dp->s);
-		dp->s = NULL;
+		dp->s = (char *) NULL;
 	}
 	if (dp->payoff != NULL) {
 		(void) free((void *) dp->payoff);
-		dp->payoff = NULL;
+		dp->payoff = (float *) NULL;
 	}
 }
 
@@ -934,7 +934,7 @@ release_dilemma(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dilemma(&dilemmas[screen]);
 		(void) free((void *) dilemmas);
-		dilemmas = NULL;
+		dilemmas = (dilemmastruct *) NULL;
 	}
 }
 
