@@ -55,7 +55,7 @@ ModeSpecOpt discrete_opts =
 #ifdef USE_MODULES
 ModStruct   discrete_description =
 {"discrete", "init_discrete", "draw_discrete", "release_discrete",
- "refresh_discrete", "init_discrete", NULL, &discrete_opts,
+ "refresh_discrete", "init_discrete", (char *) NULL, &discrete_opts,
  1000, 4096, 2500, 1, 64, 1.0, "",
  "Shows various discrete maps", 0, NULL};
 
@@ -100,7 +100,7 @@ typedef struct {
 	XPoint     *pointBuffer;	/* pointer for XDrawPoints */
 } discretestruct;
 
-static discretestruct *discretes = NULL;
+static discretestruct *discretes = (discretestruct *) NULL;
 
 void
 init_discrete(ModeInfo * mi)
@@ -409,7 +409,7 @@ release_discrete(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) discretes);
-		discretes = NULL;
+		discretes = (discretestruct *) NULL;
 	}
 }
 
