@@ -62,7 +62,7 @@ ModeSpecOpt dragon_opts =
 #ifdef USE_MODULES
 ModStruct   dragon_description =
 {"dragon", "init_dragon", "draw_dragon", "release_dragon",
- "refresh_dragon", "init_dragon", NULL, &dragon_opts,
+ "refresh_dragon", "init_dragon", (char *) NULL, &dragon_opts,
  2000000, 1, 16, -24, 64, 1.0, "",
  "Shows Deventer's Hexagonal Dragons Maze", 0, NULL};
 
@@ -99,7 +99,7 @@ typedef struct {
 	XPoint      hexagon[6];
 } dragonstruct;
 
-static dragonstruct *dragons = NULL;
+static dragonstruct *dragons = (dragonstruct *) NULL;
 
 static void
 drawcell(ModeInfo * mi, int col, int row, unsigned char state)
@@ -189,7 +189,7 @@ free_alist(dragonstruct * dp, int list)
 		dp->cellList[list] = dp->cellList[list]->next;
 		(void) free((void *) current);
 	}
-	dp->cellList[list] = NULL;
+	dp->cellList[list] = (CellList *) NULL;
 	if (dp->ncells != NULL)
 		dp->ncells[list] = 0;
 }
@@ -203,10 +203,10 @@ free_list(dragonstruct * dp)
 	for (list = 0; list < LISTS; list++)
 		free_alist(dp, list);
 	(void) free((void *) dp->cellList);
-	dp->cellList = NULL;
+	dp->cellList = (CellList **) NULL;
 	if (dp->ncells != NULL) {
 		(void) free((void *) dp->ncells);
-		dp->ncells = NULL;
+		dp->ncells = (int *) NULL;
 	}
 }
 
@@ -218,7 +218,7 @@ free_struct(dragonstruct * dp)
 	}
 	if (dp->oldcell != NULL) {
 		(void) free((void *) dp->oldcell);
-		dp->oldcell = NULL;
+		dp->oldcell = (unsigned char *) NULL;
 	}
 }
 
@@ -513,7 +513,7 @@ release_dragon(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dragon(MI_DISPLAY(mi), &dragons[screen]);
 		(void) free((void *) dragons);
-		dragons = NULL;
+		dragons = (dragonstruct *) NULL;
 	}
 }
 
