@@ -83,7 +83,7 @@ ModeSpecOpt drift_opts =
 #ifdef USE_MODULES
 ModStruct   drift_description =
 {"drift", "init_drift", "draw_drift", "release_drift",
- "refresh_drift", "init_drift", NULL, &drift_opts,
+ "refresh_drift", "init_drift", (char *) NULL, &drift_opts,
  10000, 30, 1, 1, 64, 1.0, "",
  "Shows cosmic drifting flame fractals", 0, NULL};
 
@@ -135,7 +135,7 @@ typedef struct {
 	int         nbits;
 } driftstruct;
 
-static driftstruct *drifts = NULL;
+static driftstruct *drifts = (driftstruct *) NULL;
 
 static short
 halfrandom(driftstruct * dp, int mv)
@@ -267,11 +267,11 @@ free_drift(driftstruct *dp)
 {
 	if (dp->ncpoints != NULL) {
 		(void) free((void *) dp->ncpoints);
-		dp->ncpoints = NULL;
+		dp->ncpoints = (int *) NULL;
 	}
 	if (dp->cpts != NULL) {
 		(void) free((void *) dp->cpts);
-		dp->cpts = NULL;
+		dp->cpts = (XPoint *) NULL;
 	}
 }
 
@@ -659,7 +659,7 @@ release_drift(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_drift(&drifts[screen]);
 		(void) free((void *) drifts);
-		drifts = NULL;
+		drifts = (driftstruct *) NULL;
 	}
 }
 
