@@ -93,7 +93,7 @@ ModeSpecOpt euler2d_opts =
 #ifdef USE_MODULES
 ModStruct   euler2d_description = {
 	"euler2d", "init_euler2d", "draw_euler2d", "release_euler2d",
-	"refresh_euler2d", "init_euler2d", NULL, &euler2d_opts,
+	"refresh_euler2d", "init_euler2d", (char *) NULL, &euler2d_opts,
 	1000, 1024, 3000, 1, 64, 1.0, "",
 	"Simulates 2D incompressible invisid fluid.", 0, NULL
 };
@@ -167,7 +167,7 @@ typedef struct {
 
 } euler2dstruct;
 
-static euler2dstruct *euler2ds = NULL;
+static euler2dstruct *euler2ds = (euler2dstruct *) NULL;
 
 /*
   If variable_boundary == 1, then we make a variable boundary.
@@ -481,29 +481,29 @@ ode_solve(euler2dstruct *sp)
   }
 }
 
-#define deallocate(p) if (p != NULL) {(void) free((void *) p); p = NULL; }
+#define deallocate(p,t) if (p!=NULL) {(void) free((void *) p); p=(t*)NULL; }
 #define allocate(p,t,s) if ((p=(t*)malloc(sizeof(t)*s))==NULL)\
 {free_euler2d(sp);return;}
 
 static void
 free_euler2d(euler2dstruct *sp)
 {
-	deallocate(sp->csegs);
-	deallocate(sp->old_segs);
-	deallocate(sp->nold_segs);
-	deallocate(sp->lastx);
-	deallocate(sp->x);
-	deallocate(sp->diffx);
-	deallocate(sp->w);
-	deallocate(sp->olddiffx);
-	deallocate(sp->tempdiffx);
-	deallocate(sp->tempx);
-	deallocate(sp->dead);
-	deallocate(sp->boundary);
-	deallocate(sp->xs);
-	deallocate(sp->x_is_zero);
-	deallocate(sp->p);
-	deallocate(sp->mod_dp2);
+	deallocate(sp->csegs, XSegment);
+	deallocate(sp->old_segs, XSegment);
+	deallocate(sp->nold_segs, int);
+	deallocate(sp->lastx, short);
+	deallocate(sp->x, double);
+	deallocate(sp->diffx, double);
+	deallocate(sp->w, double);
+	deallocate(sp->olddiffx, double);
+	deallocate(sp->tempdiffx, double);
+	deallocate(sp->tempx, double);
+	deallocate(sp->dead, short);
+	deallocate(sp->boundary, XSegment);
+	deallocate(sp->xs, double);
+	deallocate(sp->x_is_zero, short);
+	deallocate(sp->p, double);
+	deallocate(sp->mod_dp2, double);
 }
 
 void
@@ -864,7 +864,7 @@ release_euler2d(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_euler2d(&euler2ds[screen]);
 		(void) free((void *) euler2ds);
-		euler2ds = NULL;
+		euler2ds = (euler2dstruct *) NULL;
 	}
 }
 
