@@ -26,6 +26,7 @@ static const char sccsid[] = "@(#)flag.c	5.00 2000/11/01 xlockmore";
  *
  * Revision History:
  * 01-Nov-2000: Allocation checks.
+ * 22-Jan-1998: jwz: made the flag wigglier; added xpm support.
  * 24-Oct-1997: xpm and ras capability added.
  * 13-May-1997: jwz@jwz.org: turned into a standalone program.
  *              Made it able to animate arbitrary (runtime) text or bitmaps
@@ -56,13 +57,7 @@ static const char sccsid[] = "@(#)flag.c	5.00 2000/11/01 xlockmore";
 #include "color.h"
 #endif /* STANDALONE */
 
-/* This makes me laugh :) */
 #ifdef JWZ
-/*-
- * 22-Jan-98: jwz: made the flag wigglier; added xpm support.
- *            (I tried to do this by re-porting from xlockmore, but the
- *            current xlockmore version is completely inscrutable.)
- */
 
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -112,7 +107,7 @@ ModeSpecOpt flag_opts =
 #ifdef USE_MODULES
 ModStruct   flag_description =
 {"flag", "init_flag", "draw_flag", "release_flag",
- "refresh_flag", "init_flag", NULL, &flag_opts,
+ "refresh_flag", "init_flag", (char *) NULL, &flag_opts,
  50000, 1, 1000, -7, 64, 1.0, "",
  "Shows a waving flag image", 0, NULL};
 
@@ -182,7 +177,7 @@ typedef struct {
 
 static XFontStruct *messagefont = None;
 
-static flagstruct *flags = NULL;
+static flagstruct *flags = (flagstruct *) NULL;
 
 extern XFontStruct *getFont(Display * display);
 
@@ -450,17 +445,34 @@ free_flag(Display * display, flagstruct * fp)
 		XFreePixmap(display, fp->cache);
 		fp->cache = None;
 	}
-	if (fp->image) {
+	if (fp->image != None) {
 		if (fp->choice == IMAGE_FLAG)
 			XFree((caddr_t) fp->image); /* Do not destroy data */
 		else
 			(void) XDestroyImage(fp->image);
-		fp->image = NULL;
+		fp->image = None;
 	}
 	free_stuff(display, fp);
-	if (fp->logo) {
+	if (fp->logo != None) {
 		destroyImage(&fp->logo, &fp->graphics_format);
-		fp->logo = NULL;
+		fp->logo = None;
+	}
+}
+
+void
+release_flag(ModeInfo * mi)
+{
+	if (flags != NULL) {
+		int         screen;
+
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_flag(MI_DISPLAY(mi), &flags[screen]);
+		(void) free((void *) flags);
+		flags = (flagstruct *) NULL;
+	}
+	if (messagefont != None) {
+		XFreeFont(MI_DISPLAY(mi), messagefont);
+		messagefont = None;
 	}
 }
 
@@ -493,12 +505,12 @@ init_flag(ModeInfo * mi)
 	fp->width = MI_WIDTH(mi);
 	fp->height = MI_HEIGHT(mi);
 
-	if (fp->image) {
+	if (fp->image != None) {
 		if (fp->choice == IMAGE_FLAG)
 			XFree((caddr_t) fp->image);	/* Do not destroy data */
 		else
 			(void) XDestroyImage(fp->image);
-		fp->image = NULL;
+		fp->image = None;
 	}
 	if (MI_IS_FULLRANDOM(mi) ||
 	    (MI_BITMAP(mi) && *(MI_BITMAP(mi)) && message && *message) ||
@@ -618,23 +630,6 @@ draw_flag(ModeInfo * mi)
 		init_flag(mi);
 }
 
-void
-release_flag(ModeInfo * mi)
-{
-	if (flags != NULL) {
-		int         screen;
-
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_flag(MI_DISPLAY(mi), &flags[screen]);
-		(void) free((void *) flags);
-		flags = NULL;
-	}
-	if (messagefont != None) {
-		XFreeFont(MI_DISPLAY(mi), messagefont);
-		messagefont = None;
-	}
-}
-
 void
 refresh_flag(ModeInfo * mi)
 {
