@@ -58,7 +58,7 @@ ModeSpecOpt flame_opts =
 #ifdef USE_MODULES
 ModStruct   flame_description =
 {"flame", "init_flame", "draw_flame", "release_flame",
- "refresh_flame", "init_flame", NULL, &flame_opts,
+ "refresh_flame", "init_flame", (char *) NULL, &flame_opts,
  750000, 20, 10000, 1, 64, 1.0, "",
  "Shows cosmic flame fractals", 0, NULL};
 
@@ -85,7 +85,7 @@ typedef struct {
 	short       lasthalf;
 } flamestruct;
 
-static flamestruct *flames = NULL;
+static flamestruct *flames = (flamestruct *) NULL;
 
 static short
 halfrandom(flamestruct * fp, int mv)
@@ -340,7 +340,7 @@ release_flame(ModeInfo * mi)
 {
 	if (flames != NULL) {
 		(void) free((void *) flames);
-		flames = NULL;
+		flames = (flamestruct *) NULL;
 	}
 }
 
