@@ -93,7 +93,7 @@ ModeSpecOpt galaxy_opts =
 #ifdef USE_MODULES
 ModStruct   galaxy_description =
 {"galaxy", "init_galaxy", "draw_galaxy", "release_galaxy",
- "refresh_galaxy", "init_galaxy", NULL, &galaxy_opts,
+ "refresh_galaxy", "init_galaxy", (char *) NULL, &galaxy_opts,
  100, -5, 250, -3, 64, 1.0, "",
  "Shows crashing spiral galaxies", 0, NULL};
 
@@ -179,7 +179,7 @@ typedef struct {
 	Pixmap pixmap;
 } unistruct;
 
-static unistruct *universes = NULL;
+static unistruct *universes = (unistruct *) NULL;
 
 static void
 free_galaxies(unistruct * gp)
@@ -194,7 +194,7 @@ free_galaxies(unistruct * gp)
 				(void) free((void *) gt->stars);
 		}
 		(void) free((void *) gp->galaxies);
-		gp->galaxies = NULL;
+		gp->galaxies = (Galaxy *) NULL;
 	}
 }
 
@@ -247,7 +247,7 @@ startover(ModeInfo * mi)
 
 		if (gt->stars != NULL) {
 			(void) free((void *) gt->stars);
-			gt->stars = NULL;
+			gt->stars = (Star *) NULL;
 		}
 		gt->nstars = (NRAND(MAX_STARS / 2)) + MAX_STARS / 2;
 		if ((gt->stars = (Star *) malloc(gt->nstars *
@@ -579,7 +579,7 @@ release_galaxy(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_galaxy(MI_DISPLAY(mi), &universes[screen]);
 		(void) free((void *) universes);
-		universes = NULL;
+		universes = (unistruct *) NULL;
 	}
 }
 
