@@ -127,6 +127,8 @@ static const char sccsid[] = "@(#)atlantis.c	5.01 2001/04/17 xlockmore";
 
 #include "atlantis.h"
 #include <GL/glu.h>
+
+#if defined( USE_XPM ) || defined( USE_XPMINC )
 #include "xpm-ximage.h"
 
 #ifdef STANDALONE
@@ -134,6 +136,7 @@ static const char sccsid[] = "@(#)atlantis.c	5.01 2001/04/17 xlockmore";
 #else /* !STANDALONE */
 #include "pixmaps/sea-texture.xpm"
 #endif /* !STANDALONE */
+#endif
 
 #define DEF_WHALESPEED  "250"
 #define DEF_TEXTURE     "True"
@@ -166,7 +169,7 @@ ModeSpecOpt atlantis_opts =
 #ifdef USE_MODULES
 ModStruct   atlantis_description =
 {"atlantis", "init_atlantis", "draw_atlantis", "release_atlantis",
- "refresh_atlantis", "change_atlantis", NULL, &atlantis_opts,
+ "refresh_atlantis", "change_atlantis", (char *) NULL, &atlantis_opts,
  18000, NUM_SHARKS, SHARKSPEED, SHARKSIZE, 64, 1.0, "",
  "Shows moving sharks/whales/dolphin", 0, NULL};
 
@@ -177,11 +180,17 @@ static atlantisstruct *atlantis = (atlantisstruct *) NULL;
 static void
 parse_image_data(ModeInfo *mi)
 {
+#if defined( USE_XPM ) || defined( USE_XPMINC )
   atlantisstruct *ap = &atlantis[MI_SCREEN(mi)];
-  ap->texture = xpm_to_ximage (MI_DISPLAY(mi),
+
+  if ((ap->texture = xpm_to_ximage (MI_DISPLAY(mi),
                                MI_VISUAL(mi),
                                MI_COLORMAP(mi),
-                               sea_texture);
+                               sea_texture)) == None)
+    do_texture = False;
+#else
+  do_texture = False;
+#endif
 }
 
 static void
@@ -278,6 +287,8 @@ Init(ModeInfo * mi)
             glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT, mat_ambient);
           }
 
+        if (!ap->wire && do_texture && !ap->texture)
+              parse_image_data (mi);
         if (ap->wire || !do_texture)
           {
             glDisable(GL_TEXTURE_2D);
@@ -288,8 +299,6 @@ Init(ModeInfo * mi)
             GLfloat t_plane[] = { 0, 0, 1, 0 };
             GLfloat scale = 0.0005;
 
-            if (!ap->texture)
-              parse_image_data (mi);
 
             clear_gl_error();
             glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA,
