@@ -71,7 +71,7 @@ ModStruct   bubble3d_description =
 {(char *) "bubble3d", (char *) "init_bubble3d",
  (char *) "draw_bubble3d", (char *) "release_bubble3d",
  (char *) "draw_bubble3d", (char *) "change_bubble3d",
- NULL, &bubble3d_opts,
+ (char *) NULL, &bubble3d_opts,
  1000, 1, 2, 1, 64, 1.0, (char *) "",
  (char *) "Richard Jones's GL bubbles", 0, NULL};
 
