@@ -39,7 +39,7 @@ static const char sccsid[] = "@(#)cage.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Jun-01-1997)
  *
@@ -77,6 +77,11 @@ static const char sccsid[] = "@(#)cage.c	5.01 2001/03/01 xlockmore";
  * In real OpenGL, PseudoColor DO NOT support texture map (as far as I know).
  */
 
+/*-
+ * due to a Bug/feature in VMS X11/Intrinsic.h has to be placed before xlock.
+ * otherwise caddr_t is not defined correctly
+ */
+
 #include <X11/Intrinsic.h>
 
 #ifdef STANDALONE
@@ -96,7 +101,6 @@ static const char sccsid[] = "@(#)cage.c	5.01 2001/03/01 xlockmore";
 
 #ifdef MODE_cage
 
-
 #include <GL/glu.h>
 #include "e_textures.h"
 
@@ -106,7 +110,7 @@ ModeSpecOpt cage_opts =
 #ifdef USE_MODULES
 ModStruct   cage_description =
 {"cage", "init_cage", "draw_cage", "release_cage",
- "draw_cage", "change_cage", NULL, &cage_opts,
+ "draw_cage", "change_cage", (char *) NULL, &cage_opts,
  25000, 1, 1, 1, 1.0, 4, "",
  "Shows the Impossible Cage, an Escher-like GL scene", 0, NULL};
 
