@@ -2,7 +2,7 @@
 /* fire --- 3D fire or rain landscape */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
+static const char sccsid[] = "@(#)fire.c	5.02 2001/09/26 xlockmore";
 #endif
 
 /* Copyright (c) E. Lassauge, 2001. */
@@ -30,6 +30,10 @@ static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
  *
  * REVISION HISTORY:
  *
+ * E.Lassauge - 26-Sep-2001:
+ *      - add wander option and code 
+ *      - cleanups for xscreensaver
+ *
  * E.Lassauge - 09-Mar-2001:
  *      - get rid of my framerate options to use showfps
  *
@@ -67,29 +71,33 @@ static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
  *	- random number of trees ? change trees at change_fire ?
  *	- fix wireframe mode: it's too CPU intensive.
  *	- look how we can get the Wheel events (Button4&5).
- *	- perhaps use an observer programmed movement:
- *        watch out for the trees !!!
  */
 
-#ifdef STANDALONE
-#define PROGCLASS "Fire"
-#define HACK_INIT init_fire
-#define HACK_DRAW draw_fire
-#define fire xlockmore_opts
-#define DEFAULTS "*delay: 10000 \n" \
- "*count: 800 \n" \
- "*size: 0 \n" \
- "*trees: 5 \n" \
- "*showfps: False \n" \
- "*trackmouse: False \n" \
- "*wireframe:  False \n"	/* still needs some work */
 
+#ifdef STANDALONE	/* xscreensaver mode */
+#define PROGCLASS 	"Fire"
+#define HACK_INIT 	init_fire
+#define HACK_DRAW 	draw_fire
+#define HACK_RESHAPE 	reshape_fire
+#define fire_opts 	xlockmore_opts
+#define DEFAULTS "*delay:     10000 \n" \
+		"*count: 	800 \n" \
+		"*size:           0 \n" \
+		"*trees:          5 \n" \
+		"*showFPS:    False \n" \
+		"*trackmouse: False \n" \
+		"*wander:      True \n" \
+		"*wireframe:  False \n"	\
+		"*fog:        False \n"	\
+		"*shadows:     True \n"	\
+		"*texture:     True \n"
+
+#define MODE_fire
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else				/* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
 #include "visgl.h"
 #endif				/* !STANDALONE */
-#include "iostuff.h"		/* getFont() */
 
 #ifdef MODE_fire
 
@@ -99,7 +107,10 @@ static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
 #include <GL/glx.h>
 #include <GL/glu.h>
 
+#if defined( USE_XPM ) || defined( USE_XPMINC ) || defined( HAVE_XPM )
+/* USE_XPM & USE_XPMINC in xlock mode ; HAVE_XPM in xscreensaver mode */
 #include "xpm-ximage.h"
+#define I_HAVE_XPM
 
 #ifdef STANDALONE
 #include "../images/ground.xpm"
@@ -108,6 +119,7 @@ static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
 #include "pixmaps/ground.xpm"
 #include "pixmaps/tree.xpm"
 #endif /* !STANDALONE */
+#endif /* HAVE_XPM */
 
 /* vector utility macros */
 #define vinit(a,i,j,k) {\
@@ -155,13 +167,16 @@ static const char sccsid[] = "@(#)fire.c	5.01 2001/03/09 xlockmore";
 #define DEF_SHADOWS	"True"
 #define DEF_FRAMERATE	"False"
 #define DEF_TRACKMOUSE  "False"
+#define DEF_WANDER	"True"
 #define DEF_TREES	"5"
 #define MAX_TREES	20
 static Bool do_texture;
 static Bool do_fog;
 static Bool do_shadows;
 static Bool do_trackmouse;
-static int  num_trees;
+static Bool do_wander;
+static int num_trees;
+static int frame = 0;
 static XFontStruct *mode_font = None;
 
 static XrmOptionDescRec opts[] = {
@@ -173,6 +188,8 @@ static XrmOptionDescRec opts[] = {
     {(char *) "+shadows", (char *) ".fire.shadows", XrmoptionNoArg, (caddr_t) "off"},
     {(char *) "-trackmouse", (char *) ".fire.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
     {(char *) "+trackmouse", (char *) ".fire.trackmouse", XrmoptionNoArg, (caddr_t) "off"},
+    {(char *) "-wander", (char *) ".fire.wander", XrmoptionNoArg, (caddr_t) "on"},
+    {(char *) "+wander", (char *) ".fire.wander", XrmoptionNoArg, (caddr_t) "off"},
     {(char *) "-trees", (char *) ".fire.trees", XrmoptionSepArg, (caddr_t) NULL},
 
 };
@@ -182,6 +199,7 @@ static argtype vars[] = {
     {(caddr_t *) & do_fog, (char *) "fog", (char *) "Fog", (char *) DEF_FOG, t_Bool},
     {(caddr_t *) & do_shadows, (char *) "shadows", (char *) "Shadows", (char *) DEF_SHADOWS, t_Bool},
     {(caddr_t *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
+    {(caddr_t *) & do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
     {(caddr_t *) & num_trees, (char *) "trees", (char *) "Trees", (char *) DEF_TREES, t_Int},
 };
 
@@ -190,6 +208,7 @@ static OptionStruct desc[] = {
     {(char *) "-/+fog", (char *) "turn on/off fog"},
     {(char *) "-/+shadows", (char *) "turn on/off shadows"},
     {(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"},
+    {(char *) "-/+wander", (char *) "turn on/off wandering"},
     {(char *) "-trees num", (char *) "number of trees (0 disables)"},
 };
 
@@ -199,7 +218,7 @@ ModeSpecOpt fire_opts =
 #ifdef USE_MODULES
 ModStruct fire_description =
     { "fire", "init_fire", "draw_fire", "release_fire",
-    "draw_fire", "change_fire", NULL, &fire_opts,
+    "draw_fire", "change_fire", (char *) NULL, &fire_opts,
     10000, 800, 1, 400, 64, 1.0, "",
     "Shows a 3D fire-like image", 0, NULL
 };
@@ -259,7 +278,7 @@ static float qt[4][2] = {
 };
 
 /* default values for observer */
-static const float DEF_OBS[3] = { 2.0, 1.0, 0.0 };
+static const float DEF_OBS[3] = { 2.0f, 1.0f, 0.0f };
 #define DEV_V		0.0
 #define DEF_ALPHA	-90.0
 #define DEF_BETA	90.0
@@ -301,10 +320,6 @@ typedef struct {
     float v;			/* observer velocity */
     float alpha;		/* observer angles */
     float beta;
-
-    clock_t told;		/* frame timetag */
-    int frcount;		/* frame counter */
-    char frbuf[80];		/* frame value string */
 } firestruct;
 
 /* array of firestruct indexed by screen number */
@@ -319,7 +334,7 @@ static firestruct *fire = (firestruct *) NULL;
  */
 
 /* utility function for the rain particles */
-static float gettimerain()
+static float gettimerain(void)
 {
   static clock_t told=0;
   clock_t tnew,ris;
@@ -547,6 +562,8 @@ static void trackmouse(ModeInfo * mi)
 static void inittextures(ModeInfo * mi)
 {
     firestruct *fs = &fire[MI_SCREEN(mi)];
+
+#if defined( I_HAVE_XPM )
     if (do_texture) {
 
 	glGenTextures(1, &fs->groundid);
@@ -610,6 +627,11 @@ static void inittextures(ModeInfo * mi)
 	fs->groundid = 0;	/* default textures */
 	fs->treeid   = 0;
     }
+#else /* !I_HAVE_XPM */
+  do_texture = False;
+  fs->groundid = 0;       /* default textures */
+  fs->treeid = 0;
+#endif /* !I_HAVE_XPM */
 }
 
 /* init tree array and positions */
@@ -643,7 +665,11 @@ static Bool inittree(ModeInfo * mi)
  *-----------------------------------------------------------------------------
  */
 
+#ifndef STANDALONE
 static void Reshape(ModeInfo * mi)
+#else
+void reshape_fire(ModeInfo * mi, int width, int height)
+#endif
 {
 
     firestruct *fs = &fire[MI_SCREEN(mi)];
@@ -677,6 +703,25 @@ static void DrawFire(ModeInfo * mi)
 
     if (do_trackmouse && !MI_IS_ICONIC(mi))
 	trackmouse(mi);
+
+    if (do_wander)
+    {
+	GLfloat x, y, z;
+
+#       define SINOID(SCALE,SIZE) \
+        ((((1 + sin((frame * (SCALE)) / 2 * M_PI)) / 2.0) * (SIZE)) - (SIZE)/2)
+
+        x = SINOID(0.031, 0.85);
+        y = SINOID(0.017, 0.25);
+        z = SINOID(0.023, 0.85);
+        frame++;
+        fs->obs[0] = x + DEF_OBS[0];
+        fs->obs[1] = y + DEF_OBS[1];
+        fs->obs[2] = z + DEF_OBS[2];
+        fs->dir[1] = y;
+        fs->dir[2] = z;
+    }
+
     glEnable(GL_DEPTH_TEST);
 
     if (fs->fog)
@@ -805,7 +850,6 @@ static Bool Init(ModeInfo * mi)
     fs->eject_vl = 1;
     fs->ridtri = 0.1 + NRAND(10) * 0.005;
     fs->maxage = 1.0 / fs->dt;
-    fs->frcount = 0;
     vinit(fs->obs, DEF_OBS[0], DEF_OBS[1], DEF_OBS[2]);
     fs->v = 0.0;
     fs->alpha = DEF_ALPHA;
@@ -957,10 +1001,17 @@ init_fire(ModeInfo * mi)
     else
     	fs->num_trees = 0;
 
+    /* check wander/trackmouse */
+    if (do_trackmouse && do_wander) do_wander = 0;
+
     /* xlock GL stuff */
     if ((fs->glx_context = init_GL(mi)) != NULL) {
 
-	Reshape(mi);
+#ifndef STANDALONE
+	Reshape(mi); /* xlock mode */
+#else
+	reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
+#endif
 	glDrawBuffer(GL_BACK);
 	if (!Init(mi)) {
 		free_fire(fs);
@@ -990,7 +1041,11 @@ void draw_fire(ModeInfo * mi)
 
     glXMakeCurrent(display, window, *(fs->glx_context));
     DrawFire(mi);
-    Reshape(mi);
+#ifndef STANDALONE
+    Reshape(mi); /* xlock mode */
+#else
+    reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
+#endif
 
     glFinish();
     glXSwapBuffers(display, window);
@@ -1038,6 +1093,7 @@ void change_fire(ModeInfo * mi)
     if (do_shadows)
 	fs->shadows = LRAND() & 1;
     /* reset observer position */
+    frame = 0;
     vinit(fs->obs, DEF_OBS[0], DEF_OBS[1], DEF_OBS[2]);
     fs->v = 0.0;
     /* particle randomisation */
