@@ -53,6 +53,7 @@ static const char sccsid[] = "@(#)gears.c	5.01 2001/02/22 xlockmore";
 # define DEFAULTS			"*count:		1       \n"	\
 					"*cycles:		2       \n"	\
 					"*delay:		20000   \n"	\
+					"*size:			0 	\n"	\
 					"*planetary:		False   \n"	\
 					"*showFps:      	False   \n"	\
 					"*wireframe:		False	\n"
@@ -64,24 +65,31 @@ static const char sccsid[] = "@(#)gears.c	5.01 2001/02/22 xlockmore";
 
 #ifdef MODE_gears
 
+#define MINSIZE         32      /* minimal viewport size */
+
 #undef countof
 #define countof(x) (sizeof((x))/sizeof((*x)))
 
 #define DEF_PLANETARY "False"
+#define DEF_PLANETSIZE "400"
 
-static int planetary;
+static Bool planetary;
+static int planetsize;
 
 static XrmOptionDescRec opts[] = {
   {(char *) "-planetary", (char *) ".gears.planetary", XrmoptionNoArg, (caddr_t) "true" },
   {(char *) "+planetary", (char *) ".gears.planetary", XrmoptionNoArg, (caddr_t) "false" },
+ {(char *) "-planetsize", (char *) ".gears.planetsize", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] = {
   {(caddr_t *) &planetary, (char *) "planetary", (char *) "Planetary", DEF_PLANETARY, t_Bool},
+  {(caddr_t *) & planetsize, (char *) "planetsize", (char *) "PlanetSize", (char *) DEF_PLANETSIZE, t_Int}
 };
 
 static OptionStruct desc[] = {
-    {(char *) "-/+planetary", (char *) "turn on/off \"Planetary\" gear system"},
+  {(char *) "-/+planetary", (char *) "turn on/off \"Planetary\" gear system"},
+  {(char *) "-planetsize num", (char *) "size of screen for \"Planetary\" gear system"}
 };
 
 ModeSpecOpt gears_opts = {countof(opts), opts, countof(vars), vars, desc};
@@ -89,8 +97,8 @@ ModeSpecOpt gears_opts = {countof(opts), opts, countof(vars), vars, desc};
 #ifdef USE_MODULES
 ModStruct   gears_description =
 {"gears", "init_gears", "draw_gears", "release_gears",
- "draw_gears", "init_gears", NULL, &gears_opts,
- 1000, 1, 2, 1, 64, 1.0, "",
+ "draw_gears", "init_gears", (char *) NULL, &gears_opts,
+ 1000, 1, 2, 0, 64, 1.0, "",
  "Shows GL's gears", 0, NULL};
 
 #endif
@@ -109,9 +117,10 @@ typedef struct {
   GLXContext *glx_context;
   Window      window;
   Bool        planetary;
+  int         planetsize;
 } gearsstruct;
 
-static gearsstruct *gears = NULL;
+static gearsstruct *gears = (gearsstruct *) NULL;
 
 /*-
  * Draw a gear wheel.  You'll probably want to call this function when
@@ -590,12 +599,29 @@ draw(ModeInfo * mi)
 static void
 reshape_gears(ModeInfo *mi, int width, int height)
 {
-	GLfloat     h = (GLfloat) height / (GLfloat) width;
+	gearsstruct *gp = &gears[MI_SCREEN(mi)];
+	int size = MI_SIZE(mi), w, h;
+	GLfloat     r = (GLfloat) height / (GLfloat) width;
 
-	glViewport(0, 0, (GLint) width, (GLint) height);
+        if (gp->planetary && !size)
+		size = planetsize;
+
+	/* Viewport is specified size if size >= MINSIZE && size < screensize */
+	if (size <= 1) {
+		w = MI_WIDTH(mi);
+		h = MI_HEIGHT(mi);
+	} else if (size < MINSIZE) {
+		w = MINSIZE;
+		h = MINSIZE;
+	} else {
+		w = (size > MI_WIDTH(mi)) ? MI_WIDTH(mi) : size;
+		h = (size > MI_HEIGHT(mi)) ? MI_HEIGHT(mi) : size;
+	}
+
+	glViewport((MI_WIDTH(mi) - w) / 2, (MI_HEIGHT(mi) - h) / 2, w, h);
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
-	glFrustum(-1.0, 1.0, -h, h, 5.0, 60.0);
+	glFrustum(-1.0, 1.0, -r, r, 5.0, 60.0);
 	glMatrixMode(GL_MODELVIEW);
 	glLoadIdentity();
 	glTranslatef(0.0, 0.0, -40.0);
@@ -637,7 +663,7 @@ free_gears(Display *display, gearsstruct *gp)
 			glDeleteLists(gp->armature, 1);
 			gp->armature = 0;
 		}
-		gp->glx_context = NULL;
+		gp->glx_context = (GLXContext *) NULL;
 	}
 }
 
@@ -989,7 +1015,7 @@ pinit(ModeInfo * mi)
 #define FLOATRAND(a) (((double)LRAND() / (double)MAXRAND) * a)
 
 static void
-rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
+rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
 {
   double ppos = *pos;
 
@@ -1001,11 +1027,16 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
 
   if (ppos > 1.0)
     ppos -= 1.0;
-  else if (ppos < 0)
+  else if (ppos < 0.0)
     ppos += 1.0;
 
-  if (ppos < 0) abort();
-  if (ppos > 1.0) abort();
+  if ((ppos < 0.0) || (ppos > 1.0)) {
+    if (verbose) {
+      (void) fprintf(stderr, "Weirdness in rotate()\n");
+      (void) fprintf(stderr, "ppos = %g\n", ppos);
+    }
+    return;
+  }
   *pos = (*pos > 0 ? ppos : -ppos);
 
   /* accelerate */
@@ -1133,9 +1164,9 @@ draw_gears(ModeInfo * mi)
 	/* let's do something so we don't get bored */
 	gp->angle = (int) (gp->angle + angle_incr) % 360;
 
-    rotate(&gp->rotx, &gp->dx, &gp->ddx, gp->d_max);
-    rotate(&gp->roty, &gp->dy, &gp->ddy, gp->d_max);
-    rotate(&gp->rotz, &gp->dz, &gp->ddz, gp->d_max);
+    rotate(&gp->rotx, &gp->dx, &gp->ddx, gp->d_max, MI_IS_VERBOSE(mi));
+    rotate(&gp->roty, &gp->dy, &gp->ddy, gp->d_max, MI_IS_VERBOSE(mi));
+    rotate(&gp->rotz, &gp->dz, &gp->ddz, gp->d_max, MI_IS_VERBOSE(mi));
 
     if (MI_IS_FPS(mi)) do_fps (mi);
 	glFinish();
@@ -1151,7 +1182,7 @@ release_gears(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_gears(MI_DISPLAY(mi), &gears[screen]);
 		(void) free((void *) gears);
-		gears = NULL;
+		gears = (gearsstruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
