@@ -154,13 +154,20 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &do_rotate,   (char *) "rotate",  (char *) "Rotate",  DEF_ROTATE,  t_Bool},
-  {(caddr_t *) &do_roll,     (char *) "roll",    (char *) "Roll",    DEF_ROLL,    t_Bool},
-  {(caddr_t *) &do_bounce,   (char *) "bounce",  (char *) "Bounce",  DEF_BOUNCE,  t_Bool},
-  {(caddr_t *) &do_texture,  (char *) "texture", (char *) "Texture", DEF_TEXTURE, t_Bool},
-  {(caddr_t *) &do_stars,  (char *) "stars", (char *) "Stars", DEF_STARS, t_Bool},
-  {(caddr_t *) &do_light,    (char *) "light",   (char *) "Light",   DEF_LIGHT,   t_Bool},
-  {(caddr_t *) &which_image, (char *) "pimage",   (char *) "Pimage",   DEF_IMAGE,   t_String},
+  {(caddr_t *) &do_rotate,   (char *) "rotate",  (char *) "Rotate",
+    (char *) DEF_ROTATE,  t_Bool},
+  {(caddr_t *) &do_roll,     (char *) "roll",    (char *) "Roll",
+    (char *) DEF_ROLL,    t_Bool},
+  {(caddr_t *) &do_bounce,   (char *) "bounce",  (char *) "Bounce",
+    (char *) DEF_BOUNCE,  t_Bool},
+  {(caddr_t *) &do_texture,  (char *) "texture", (char *) "Texture",
+    (char *) DEF_TEXTURE, t_Bool},
+  {(caddr_t *) &do_stars,    (char *) "stars",   (char *) "Stars",
+    (char *) DEF_STARS,   t_Bool},
+  {(caddr_t *) &do_light,    (char *) "light",   (char *) "Light",
+    (char *) DEF_LIGHT,   t_Bool},
+  {(caddr_t *) &which_image, (char *) "pimage",  (char *) "Pimage",
+    (char *) DEF_IMAGE,   t_String},
 };
 
 static OptionStruct desc[] = {
@@ -178,7 +185,7 @@ ModeSpecOpt glplanet_opts = {countof(opts), opts, countof(vars), vars, desc};
 #ifdef USE_MODULES
 ModStruct   glplanet_description =
 {"glplanet", "init_glplanet", "draw_glplanet", "release_glplanet",
- "draw_glplanet", "init_glplanet", NULL, &glplanet_opts,
+ "draw_glplanet", "init_glplanet", (char *) NULL, &glplanet_opts,
  1000, 1, 2, 1, 64, 1.0, "",
  "Animates texture mapped sphere (planet)", 0, NULL};
 #endif
@@ -295,10 +302,6 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
 static void
 setup_file_texture (ModeInfo *mi, char *filename)
 {
-  Display *dpy = MI_DISPLAY(mi);
-  Visual *visual = MI_VISUAL(mi);
-  Colormap cmap = MI_COLORMAP(mi);
-
 #if defined( USE_XPM ) || defined( USE_XPMINC )
   {
 	char **xpm_data = 0;
@@ -306,7 +309,8 @@ setup_file_texture (ModeInfo *mi, char *filename)
 	switch (result) {
 	case XpmSuccess:
 	  {
-		XImage *image = xpm_to_ximage (dpy, visual, cmap, xpm_data);
+		XImage *image = xpm_to_ximage (MI_DISPLAY(mi), MI_VISUAL(mi),
+			 MI_COLORMAP(mi), xpm_data);
 
         clear_gl_error();
 		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA,
@@ -347,7 +351,7 @@ setup_file_texture (ModeInfo *mi, char *filename)
 	  break;
 	}
   }
-#endif /* HAVE_XPM */
+#endif /* USE_XPM */
 
 #ifdef USE_XMU
   {
@@ -651,11 +655,11 @@ init_glplanet(ModeInfo * mi)
    {
 /*	char *f = get_string_resource("imageForeground", "Foreground");
 	char *b = get_string_resource("imageBackground", "Background"); */
-        char *f = strdup("Green");
-	char *b = strdup("Blue");
+        char *f = (char *) strdup("Green");
+	char *b = (char *) strdup("Blue");
 	char *s;
-	if (!f) f = strdup("white");
-	if (!b) b = strdup("black");
+	if (!f) f = (char *) strdup("white");
+	if (!b) b = (char *) strdup("black");
 
 	for (s = f + strlen(f)-1; s > f; s--)
 	  if (*s == ' ' || *s == '\t')
