@@ -2,12 +2,13 @@
 /* Xlib.h for VMS is not (yet) compatible with C++ *
  * The resulting warnings are switched off here    */
 #pragma message disable nosimpint
-#endif
 #include <X11/Intrinsic.h>
-#ifdef VMS
 #pragma message enable nosimpint
 #endif
 #include "xlock.h"
+#ifndef VMS
+#include <X11/Intrinsic.h>
+#endif
 
 #include "i_linkage.h"
 #include "i_threejetvec.h"
@@ -22,7 +23,7 @@ char *parse_parts(char *parts);
 double scale = M_PI;
 int scene = 0;
 int bezier = 0;
-char *parts = NULL;
+char *parts = (char *) NULL;
 int n_strips = N_STRIPS;
 
 Bool
