@@ -54,7 +54,7 @@ ModStruct invert_description =
 {(char *) "invert", (char *) "init_invert",
  (char *) "draw_invert", (char *) "release_invert",
  (char *) "draw_invert", (char *) "init_invert",
- NULL, &invert_opts,
+ (char *) NULL, &invert_opts,
  100, 1, 1, 1, 64, 1.0, (char *) "",
  (char *) "Shows a sphere inverted without wrinkles", 0, NULL};
 
