@@ -146,12 +146,13 @@ ModeSpecOpt lament_opts =
 #ifdef USE_MODULES
 ModStruct   lament_description =
 {"lament", "init_lament", "draw_lament", "release_lament",
- "draw_lament", "change_lament", NULL, &lament_opts,
+ "draw_lament", "change_lament", (char *) NULL, &lament_opts,
  10000, 1, 1, 1, 64, 1.0, "",
  "Shows Lemarchand's Box", 0, NULL};
 
 #endif
 
+#if defined( USE_XPM ) || defined( USE_XPMINC )
 #include "xpm-ximage.h"
 
 #ifdef STANDALONE
@@ -159,6 +160,7 @@ ModStruct   lament_description =
 #else
 #include "pixmaps/lament.xpm"
 #endif
+#endif
 
 #define RANDSIGN() ((LRAND() & 1) ? 1 : -1)
 #define FLOATRAND(a) (((double)LRAND() / (double)MAXRAND) * a)
@@ -217,7 +219,7 @@ typedef struct {
 	Window      window;
 } lament_configuration;
 
-static lament_configuration *lcs = NULL;
+static lament_configuration *lcs = (lament_configuration *) NULL;
 
 #define FACE_N 3
 #define FACE_S 2
@@ -1764,7 +1766,15 @@ draw(ModeInfo * mi)
 								tz = 1.0;
 								break;
 							default:
-								abort();
+		magic = lc->tetra_une;
+		tx = 1.0;
+		ty = 1.0;
+		tz = 1.0;
+		if (MI_IS_VERBOSE(mi)) {
+			(void) fprintf(stderr, "Weirdness in draw()\n");
+			(void) fprintf(stderr, "type = %d\n", lc->type);
+		}
+
 								break;
 						}
 						glCallList(lc->tetra_mid);
@@ -1834,7 +1844,10 @@ draw(ModeInfo * mi)
 					break;
 
 				default:
-					abort();
+		if (MI_IS_VERBOSE(mi)) {
+			(void) fprintf(stderr, "Weirdness in draw()\n");
+			(void) fprintf(stderr, "type = %d\n", lc->type);
+		}
 					break;
 			}
 		}
@@ -2062,14 +2075,17 @@ animate(ModeInfo * mi)
 			break;
 
 		default:
-			abort();
+		if (MI_IS_VERBOSE(mi)) {
+			(void) fprintf(stderr, "Weirdness in animate()\n");
+			(void) fprintf(stderr, "type = %d\n", lc->type);
+		}
 			break;
 	}
 }
 
 
 static void
-rotate(GLfloat * pos, GLfloat * v, GLfloat * dv, GLfloat max_v)
+rotate(GLfloat * pos, GLfloat * v, GLfloat * dv, GLfloat max_v, Bool verbose)
 {
 	double      ppos = *pos;
 
@@ -2084,10 +2100,14 @@ rotate(GLfloat * pos, GLfloat * v, GLfloat * dv, GLfloat max_v)
 	else if (ppos < 0)
 		ppos += 1.0;
 
-	if (ppos < 0)
-		abort();
-	if (ppos > 1.0)
-		abort();
+	if ((ppos < 0) || (ppos > 1.0)) {
+		if (verbose) {
+			(void) fprintf(stderr, "Weirdness in rotate()\n");
+			(void) fprintf(stderr, "ppos = %g\n", ppos);
+		}
+		return;
+	}
+
 	*pos = (*pos > 0 ? ppos : -ppos);
 
 	/* accelerate */
@@ -2191,7 +2211,7 @@ free_lament(Display *display, lament_configuration *lc)
 		for (i = 0; i < 6; i++)
 			glDeleteTextures(1, &lc->texids[i]);
 		XDestroyImage(lc->texture);
-		lc->texture = NULL;
+		lc->texture = None;
 	}
 }
 
@@ -2246,7 +2266,7 @@ gl_init(ModeInfo * mi)
 	if (do_texture) {
 #ifdef HAVE_GLBINDTEXTURE
 		int         i;
-#if ((MESA_MAJOR_VERSION < 3 ) || (( MESA_MAJOR_VERSION == 3 ) && (MESA_MINOR_VERSION == 0 )))
+#if ((XMESA_MAJOR_VERSION < 3 ) || (( XMESA_MAJOR_VERSION == 3 ) && (XMESA_MINOR_VERSION == 0 )))
 		/* E.Lassauge - 11/23/98
 		 * It looks like there's a bug in MESA (up to 3.1beta1) for the
 		 * "Default" texture (named '0'). For this texture
@@ -2414,9 +2434,9 @@ draw_lament(ModeInfo * mi)
 	glXSwapBuffers(display, window);
 
 	if (lc->type != LAMENT_LID_ZOOM) {
-		rotate(&lc->rotx, &lc->dx, &lc->ddx, lc->d_max);
-		rotate(&lc->roty, &lc->dy, &lc->ddy, lc->d_max);
-		rotate(&lc->rotz, &lc->dz, &lc->ddz, lc->d_max);
+		rotate(&lc->rotx, &lc->dx, &lc->ddx, lc->d_max, MI_IS_VERBOSE(mi));
+		rotate(&lc->roty, &lc->dy, &lc->ddy, lc->d_max, MI_IS_VERBOSE(mi));
+		rotate(&lc->rotz, &lc->dz, &lc->ddz, lc->d_max, MI_IS_VERBOSE(mi));
 	}
 	if (lc->anim_pause)
 		lc->anim_pause--;
@@ -2452,7 +2472,7 @@ release_lament(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_lament(MI_DISPLAY(mi), &lcs[screen]);
 		(void) free((void *) lcs);
-		lcs = NULL;
+		lcs = (lament_configuration *) NULL;
 	}
 	FreeAllGL(mi);
 }
