@@ -39,7 +39,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Jun-01-1997)
  *
@@ -133,7 +133,7 @@ ModeSpecOpt moebius_opts =
 #ifdef USE_MODULES
 ModStruct   moebius_description =
 {"moebius", "init_moebius", "draw_moebius", "release_moebius",
- "draw_moebius", "change_moebius", NULL, &moebius_opts,
+ "draw_moebius", "change_moebius", (char *) NULL, &moebius_opts,
  1000, 1, 1, 1, 4, 1.0, "",
  "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL};
 
@@ -654,7 +654,7 @@ pinit(void)
 #define FLOATRAND(a) (((double)LRAND() / (double)MAXRAND) * a)
 
 static void
-rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
+rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
 {
   double ppos = *pos;
 
@@ -669,8 +669,14 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
   else if (ppos < 0)
     ppos += 1.0;
 
-  if (ppos < 0) abort();
-  if (ppos > 1.0) abort();
+  if ((ppos < 0.0) || (ppos > 1.0)) {
+    if (verbose) {
+      (void) fprintf(stderr, "Weirdness in rotate()\n");
+      (void) fprintf(stderr, "ppos = %g\n", ppos);
+    }
+    return;
+  }
+
   *pos = (*pos > 0 ? ppos : -ppos);
 
   /* accelerate */
@@ -719,6 +725,19 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
     }
 }
 
+void
+release_moebius(ModeInfo * mi)
+{
+	if (moebius != NULL) {
+		(void) free((void *) moebius);
+		moebius = (moebiusstruct *) NULL;
+	}
+	if (glIsList(objects)) {
+		glDeleteLists(objects, MaxObj);
+		objects = 0;
+	}
+	FreeAllGL(mi);
+}
 
 void
 init_moebius(ModeInfo * mi)
@@ -820,9 +839,9 @@ draw_moebius(ModeInfo * mi)
 
 	glPopMatrix();
 
-    rotate(&mp->rotx, &mp->dx, &mp->ddx, mp->d_max);
-    rotate(&mp->roty, &mp->dy, &mp->ddy, mp->d_max);
-    rotate(&mp->rotz, &mp->dz, &mp->ddz, mp->d_max);
+    rotate(&mp->rotx, &mp->dx, &mp->ddx, mp->d_max, MI_IS_VERBOSE(mi));
+    rotate(&mp->roty, &mp->dy, &mp->ddy, mp->d_max, MI_IS_VERBOSE(mi));
+    rotate(&mp->rotz, &mp->dz, &mp->ddz, mp->d_max, MI_IS_VERBOSE(mi));
 
     if (MI_IS_FPS(mi)) do_fps (mi);
 	glFlush();
@@ -844,18 +863,4 @@ change_moebius(ModeInfo * mi)
 	pinit();
 }
 
-void
-release_moebius(ModeInfo * mi)
-{
-	if (moebius != NULL) {
-		(void) free((void *) moebius);
-		moebius = (moebiusstruct *) NULL;
-	}
-	if (glIsList(objects)) {
-		glDeleteLists(objects, MaxObj);
-		objects = 0;
-	}
-	FreeAllGL(mi);
-}
-
 #endif
