@@ -18,6 +18,8 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
  *
  *
  * Revision History:
+ * 16-May-01:  tschmidt@micron.com
+ *                              Fix remaining memory leaks. Fix occasional SEGV.
  * 19-Apr-01:  tschmidt@micron.com
  *                              Fixed most memory leaks
  * 19-Apr-01:  rolf@groppe.de   fixed some allocation problems
@@ -88,7 +90,6 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
 #else  /* !STANDALONE */
 # include "xlock.h"					/* from the xlockmore distribution */
 # include "visgl.h"
-#include "color.h"
 #endif /* !STANDALONE */
 #include "sphere.h"
 #include "tube.h"
@@ -198,8 +199,8 @@ typedef struct {
 } molecule_configuration;
 
 
-static molecule_configuration *mcs = NULL;
-static molecule *mols = NULL;
+static molecule_configuration *mcs = (molecule_configuration *) NULL;
+static molecule *mols = (molecule *) NULL;
 
 static int timeout;
 static char *molecule_str;
@@ -221,33 +222,33 @@ static XrmOptionDescRec opts[] = {
   {(char *) "-timeout", (char *) ".molecule.timeout",XrmoptionSepArg, 0 },
 #endif
   {(char *) "-spin",   (char *) ".molecule.spin",   XrmoptionSepArg, 0 },
-  {(char *) "+spin",   (char *) ".molecule.spin",   XrmoptionNoArg, "" },
-  {(char *) "-wander", (char *) ".molecule.wander", XrmoptionNoArg, "on" },
-  {(char *) "+wander", (char *) ".molecule.wander", XrmoptionNoArg, "off" },
-  {(char *) "-labels", (char *) ".molecule.labels", XrmoptionNoArg, "on" },
-  {(char *) "+labels", (char *) ".molecule.labels", XrmoptionNoArg, "off" },
-  {(char *) "-titles", (char *) ".molecule.titles", XrmoptionNoArg, "on" },
-  {(char *) "+titles", (char *) ".molecule.titles", XrmoptionNoArg, "off" },
-  {(char *) "-atoms",  (char *) ".molecule.atoms",  XrmoptionNoArg, "on" },
-  {(char *) "+atoms",  (char *) ".molecule.atoms",  XrmoptionNoArg, "off" },
-  {(char *) "-bonds",  (char *) ".molecule.bonds",  XrmoptionNoArg, "on" },
-  {(char *) "+bonds",  (char *) ".molecule.bonds",  XrmoptionNoArg, "off" },
-  {(char *) "-bbox",   (char *) ".molecule.bbox",  XrmoptionNoArg, "on" },
-  {(char *) "+bbox",   (char *) ".molecule.bbox",  XrmoptionNoArg, "off" },
+  {(char *) "+spin",   (char *) ".molecule.spin",   XrmoptionNoArg, (caddr_t) NULL},
+  {(char *) "-wander", (char *) ".molecule.wander", XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+wander", (char *) ".molecule.wander", XrmoptionNoArg, (caddr_t) "off" },
+  {(char *) "-labels", (char *) ".molecule.labels", XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+labels", (char *) ".molecule.labels", XrmoptionNoArg, (caddr_t) "off" },
+  {(char *) "-titles", (char *) ".molecule.titles", XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+titles", (char *) ".molecule.titles", XrmoptionNoArg, (caddr_t) "off" },
+  {(char *) "-atoms",  (char *) ".molecule.atoms",  XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+atoms",  (char *) ".molecule.atoms",  XrmoptionNoArg, (caddr_t) "off" },
+  {(char *) "-bonds",  (char *) ".molecule.bonds",  XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+bonds",  (char *) ".molecule.bonds",  XrmoptionNoArg, (caddr_t) "off" },
+  {(char *) "-bbox",   (char *) ".molecule.bbox",  XrmoptionNoArg, (caddr_t) "on" },
+  {(char *) "+bbox",   (char *) ".molecule.bbox",  XrmoptionNoArg, (caddr_t) "off" },
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &molecule_str, (char *) "molecule",   (char *) "Molecule", DEF_MOLECULE,t_String},
+  {(caddr_t *) &molecule_str, (char *) "molecule",   (char *) "Molecule", (char *) DEF_MOLECULE,t_String},
 #ifdef STANDALONE
-  {(caddr_t *) &timeout,   (char *) "timeout",(char *) "Seconds",DEF_TIMEOUT,t_Int},
+  {(caddr_t *) &timeout,   (char *) "timeout",(char *) "Seconds", (char *) DEF_TIMEOUT,t_Int},
 #endif
-  {(caddr_t *) &do_spin,   (char *) "spin",   (char *) "Spin",   DEF_SPIN,   t_String},
-  {(caddr_t *) &do_wander, (char *) "wander", (char *) "Wander", DEF_WANDER, t_Bool},
-  {(caddr_t *) &do_labels, (char *) "labels", (char *) "Labels", DEF_LABELS, t_Bool},
-  {(caddr_t *) &do_titles, (char *) "titles", (char *) "Titles", DEF_TITLES, t_Bool},
-  {(caddr_t *) &do_atoms,  (char *) "atoms",  (char *) "Atoms",  DEF_ATOMS,  t_Bool},
-  {(caddr_t *) &do_bonds,  (char *) "bonds",  (char *) "Bonds",  DEF_BONDS,  t_Bool},
-  {(caddr_t *) &do_bbox,   (char *) "bbox",   (char *) "BBox",   DEF_BBOX,   t_Bool},
+  {(caddr_t *) &do_spin,   (char *) "spin",   (char *) "Spin",   (char *) DEF_SPIN,   t_String},
+  {(caddr_t *) &do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
+  {(caddr_t *) &do_labels, (char *) "labels", (char *) "Labels", (char *) DEF_LABELS, t_Bool},
+  {(caddr_t *) &do_titles, (char *) "titles", (char *) "Titles", (char *) DEF_TITLES, t_Bool},
+  {(caddr_t *) &do_atoms,  (char *) "atoms",  (char *) "Atoms",  (char *) DEF_ATOMS,  t_Bool},
+  {(caddr_t *) &do_bonds,  (char *) "bonds",  (char *) "Bonds",  (char *) DEF_BONDS,  t_Bool},
+  {(caddr_t *) &do_bbox,   (char *) "bbox",   (char *) "BBox",   (char *) DEF_BBOX,   t_Bool},
 };
 
 static OptionStruct desc[] = {
@@ -269,7 +270,7 @@ ModeSpecOpt molecule_opts = {countof(opts), opts, countof(vars), vars, desc};
 #ifdef USE_MODULES
 ModStruct   molecule_description =
 {"molecule", "init_molecule", "draw_molecule", "release_molecule",
- "reshape_molecule", "init_molecule", NULL, &molecule_opts,
+ "draw_molecule", "init_molecule", (char *) NULL, &molecule_opts,
  50000, 1, 20, 1, 64, 1.0, "",
  "Draws molecules", 0, NULL};
 #endif
@@ -334,14 +335,52 @@ load_fonts (ModeInfo *mi)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
 #ifdef STANDALONE
-  load_font (mi, "atomFont",  &mc->xfont1, &mc->font1_dlist);
-  load_font (mi, "titleFont", &mc->xfont2, &mc->font2_dlist);
+  load_font (mi, (char *) "atomFont",  &mc->xfont1, &mc->font1_dlist);
+  load_font (mi, (char *) "titleFont", &mc->xfont2, &mc->font2_dlist);
 #else
-  load_font (mi, "-*-times-bold-r-normal-*-240-*",  &mc->xfont1, &mc->font1_dlist);
-  load_font (mi, "-*-times-bold-r-normal-*-180-*", &mc->xfont2, &mc->font2_dlist);
+  load_font (mi, (char *) "-*-times-bold-r-normal-*-240-*",  &mc->xfont1, &mc->font1_dlist);
+  load_font (mi, (char *) "-*-times-bold-r-normal-*-180-*", &mc->xfont2, &mc->font2_dlist);
 #endif
 }
 
+static void
+free_fonts (ModeInfo *mi)
+{
+  molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
+
+  clear_gl_error ();
+  if (glIsList(mc->molecule_dlist)) {
+	glDeleteLists(mc->molecule_dlist, 1);
+	check_gl_error ("glDeleteLists");
+	mc->molecule_dlist = 0;
+  }
+  if (mc->xfont1) {
+	int last;
+
+	last = mc->xfont1->max_char_or_byte2;
+	clear_gl_error ();
+	if (glIsList(mc->font1_dlist)) {
+		glDeleteLists (mc->font1_dlist,(GLuint) last+1);
+		check_gl_error ("glDeleteLists");
+		mc->font1_dlist = 0;
+	}
+	XFreeFont(MI_DISPLAY(mi),mc->xfont1);
+	mc->xfont1 = (XFontStruct *) NULL;
+  }
+  if (mc->xfont2) {
+	int last;
+
+	last = mc->xfont2->max_char_or_byte2;
+	clear_gl_error ();
+	if (glIsList(mc->font2_dlist)) {
+		glDeleteLists (mc->font2_dlist,(GLuint) last+1);
+		check_gl_error ("glDeleteLists");
+		mc->font2_dlist = 0;
+	}
+	XFreeFont(MI_DISPLAY(mi),mc->xfont2);
+	mc->xfont2 = (XFontStruct *) NULL;
+  }
+}
 
 static int
 string_width (XFontStruct *f, const char *c)
@@ -364,16 +403,16 @@ get_atom_data (const char *atom_name)
 {
   int i;
   atom_data *d = 0;
-  char *n = strdup (atom_name);
+  char *n = (char *) strdup (atom_name);
   char *n2 = n;
   int L;
 
-  while (!isalpha(*n)) n++;
+  while (!isalpha((int) *n)) n++;
   L = strlen(n);
-  while (L > 0 && !isalpha(n[L-1]))
+  while (L > 0 && !isalpha((int) n[L-1]))
     n[--L] = 0;
 
-  for (i = 0; i < countof(all_atom_data); i++)
+  for (i = 0; i < (int) countof(all_atom_data); i++)
     {
       d = &all_atom_data[i];
       if (!strcmp (n, all_atom_data[i].name))
@@ -408,7 +447,7 @@ set_atom_color (ModeInfo *mi, molecule_atom *a, Bool font_p)
       XColor xcolor;
       if (!XParseColor (MI_DISPLAY(mi), MI_COLORMAP(mi), string, &xcolor))
         {
-          fprintf (stderr, "molecule: unparsable color in %s: %s\n",
+          (void) fprintf (stderr, "molecule: unparsable color in %s: %s\n",
                    (a ? a->label : d->name), string);
           /* exit (1); */
         }
@@ -452,7 +491,7 @@ atom_size (molecule_atom *a)
 
 
 static molecule_atom *
-get_atom (molecule_atom *atoms, int natoms, int id)
+get_atom (molecule_atom *atoms, int natoms, int id, Bool verbose)
 {
   int i;
 
@@ -471,8 +510,10 @@ get_atom (molecule_atom *atoms, int natoms, int id)
     if (id == atoms[i].id)
       return &atoms[i];
 
-  fprintf (stderr, "molecule: no atom %d\n", id);
-  /* abort(); */
+  if (verbose) {
+    (void) fprintf (stderr, "molecule: no atom %d\n", id);
+  }
+  return (molecule_atom *) NULL;
 }
 
 
@@ -645,7 +686,7 @@ print_title_string (ModeInfo *mi, const char *string,
         set_atom_color (mi, 0, True);
 
         glRasterPos2f (x, y);
-        for (i = 0; i < strlen(string); i++)
+        for (i = 0; i < (int) strlen(string); i++)
           {
             char c = string[i];
             if (c == '\n')
@@ -702,8 +743,10 @@ build_molecule (ModeInfo *mi)
     for (i = 0; i < m->nbonds; i++)
       {
         molecule_bond *b = &m->bonds[i];
-        molecule_atom *from = get_atom (m->atoms, m->natoms, b->from);
-        molecule_atom *to   = get_atom (m->atoms, m->natoms, b->to);
+        molecule_atom *from = get_atom(m->atoms, m->natoms, b->from,
+		MI_IS_VERBOSE(mi));
+        molecule_atom *to   = get_atom(m->atoms, m->natoms, b->to,
+		MI_IS_VERBOSE(mi));
 
         if (wire)
           {
@@ -775,7 +818,7 @@ build_molecule (ModeInfo *mi)
             glRasterPos3f (wx, wy, wz);
           }
 
-          for (i = 0; i < strlen(a->label); i++)
+          for (i = 0; i < (int) strlen(a->label); i++)
             glCallList (mc->font1_dlist + (int)(a->label[i]));
 
           glPopAttrib();
@@ -855,31 +898,32 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
       if ((!m->label || !*m->label) &&
           (!strncmp (s, "HEADER", 6) || !strncmp (s, "COMPND", 6)))
         {
-          char *name = calloc (1, 100);
+          char *name = (char *) calloc (1, 100);
           char *n2 = name;
           int L = strlen(s);
+          
           if (L > 99) L = 99;
 
-          strncpy (n2, s, L);
+          strncpy(n2, s, L);
           n2 += 7;
-          while (isspace(*n2)) n2++;
+          while (isspace((int) *n2)) n2++;
 
           ss = strchr (n2, '\n');
           if (ss) *ss = 0;
           ss = strchr (n2, '\r');
           if (ss) *ss = 0;
 
-          ss = n2+strlen(n2)-1;
-          while (isspace(*ss) && ss > n2)
+          ss = n2 + strlen(n2)-1;
+          while (isspace((int) *ss) && ss > n2)
             *ss-- = 0;
 
-          if (strlen (n2) > 4 &&
+          if (strlen(n2) > 4 &&
               !strcmp (n2 + strlen(n2) - 4, ".pdb"))
             n2[strlen(n2)-4] = 0;
 
           if (m->label) free ((char *) m->label);
-          m->label = strdup (n2);
-          free (name);
+          m->label = (char *) strdup (n2);
+          free(name);
         }
       else if (!strncmp (s, "TITLE ", 6) ||
                !strncmp (s, "HEADER", 6) ||
@@ -930,13 +974,13 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           sscanf (s+7, " %d ", &id);
 
           strncpy (name, s+12, 3);
-          while (isspace(*name)) name++;
+          while (isspace((int) *name)) name++;
           ss = name + strlen(name)-1;
-          while (isspace(*ss) && ss > name)
+          while (isspace((int) *ss) && ss > name)
             *ss-- = 0;
           sscanf (s + 32, " %f %f %f ", &x, &y, &z);
 /*
-          fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
+          (void) fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
                    filename, line,
                    id, name, x, y, z);
 */
@@ -952,13 +996,13 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           sscanf (s+7, " %d ", &id);
 
           strncpy (name, s+12, 3);
-          while (isspace(*name)) name++;
+          while (isspace((int) *name)) name++;
           ss = name + strlen(name)-1;
-          while (isspace(*ss) && ss > name)
+          while (isspace((int) *ss) && ss > name)
             *ss-- = 0;
           sscanf (s + 30, " %f %f %f ", &x, &y, &z);
 /*
-          fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
+          (void) fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
                    filename, line,
                    id, name, x, y, z);
 */
@@ -967,7 +1011,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
       else if (!strncmp (s, "CONECT ", 7))
         {
           int atoms[11];
-          int i = sscanf (s + 8, " %d %d %d %d %d %d %d %d %d %d %d ",
+          int i = sscanf (s + 8, " %d %d %d %d %d %d %d %d %d %d %d %d ",
                           &atoms[0], &atoms[1], &atoms[2], &atoms[3], 
                           &atoms[4], &atoms[5], &atoms[6], &atoms[7], 
                           &atoms[8], &atoms[9], &atoms[10], &atoms[11]);
@@ -976,7 +1020,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
             if (atoms[j] > 0)
               {
 /*
-                fprintf (stderr, "molecule: %s: %d: bond: %d %d\n",
+                (void) fprintf (stderr, "molecule: %s: %d: bond: %d %d\n",
                          filename, line, atoms[0], atoms[j]);
 */
                 push_bond (m, atoms[0], atoms[j]);
@@ -984,11 +1028,11 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
         }
       else
         {
-          char *s1 = strdup (s);
+          char *s1 = (char *) strdup (s);
           for (ss = s1; *ss && *ss != '\n'; ss++)
             ;
           *ss = 0;
-          fprintf (stderr, "molecule: %s: %d: unrecognised line: %s\n",
+          (void) fprintf (stderr, "molecule: %s: %d: unrecognised line: %s\n",
                    filename, line, s1);
         }
 
@@ -1013,7 +1057,7 @@ parse_pdb_file (molecule *m, const char *name)
   if (!in)
     {
       char *buf = (char *) malloc(1024 + strlen(name));
-      sprintf(buf, "molecule: error reading \"%s\"", name);
+      (void) sprintf(buf, "molecule: error reading \"%s\"", name);
       perror(buf);
       /* exit (1); */
     }
@@ -1033,14 +1077,14 @@ parse_pdb_file (molecule *m, const char *name)
 
   if (!m->natoms)
     {
-      fprintf (stderr, "molecule: file %s contains no atomic coordinates!\n",
+      (void) fprintf (stderr, "molecule: file %s contains no atomic coordinates!\n",
                name);
       /* exit (1); */
     }
 
   if (!m->nbonds && do_bonds)
     {
-      fprintf (stderr, "molecule: warning: file %s contains no atomic bond info.\n",
+      (void) fprintf (stderr, "molecule: warning: file %s contains no atomic bond info.\n",
                name);
       do_bonds = 0;
     }
@@ -1061,9 +1105,9 @@ generate_molecule_formula (molecule *m)
       int j = 0;
       char *a = (char *) m->atoms[i].label;
       char *e;
-      while (!isalpha(*a)) a++;
-      a = strdup (a);
-      for (e = a; isalpha(*e); e++);
+      while (!isalpha((int) *a)) a++;
+      a = (char *) strdup (a);
+      for (e = a; isalpha((int) *e); e++);
       *e = 0;
       while (counts[j].atom && !!strcmp(a, counts[j].atom))
         j++;
@@ -1081,12 +1125,12 @@ generate_molecule_formula (molecule *m)
       free (counts[i].atom);
       s += strlen (s);
       if (counts[i].count > 1)
-        sprintf (s, "(%d)", counts[i].count);
+        (void) sprintf (s, "(%d)", counts[i].count);
       s += strlen (s);
       i++;
     }
 
-  if (!m->label) m->label = strdup("");
+  if (!m->label) m->label = (char *) strdup("");
   s = (char *) malloc (strlen (m->label) + strlen (buf) + 2);
   strcpy (s, m->label);
   strcat (s, "\n");
@@ -1130,7 +1174,7 @@ load_molecules (ModeInfo *mi)
         for (i = 0; i < mc->nmolecules; i++)
           {
             char name[100];
-            sprintf (name, "<builtin-%d>", i);
+            (void) sprintf (name, "<builtin-%d>", i);
             parse_pdb_data (&mols[i], builtin_pdb_data[i], name, 1);
             generate_molecule_formula (&mols[i]);
             insert_vertical_whitespace ((char *) mols[i].label);
@@ -1155,7 +1199,7 @@ load_molecules (ModeInfo *mi)
             /* If we're not drawing atoms (e.g., wireframe mode), and
                there is no bond info, then make sure labels are turned on,
                or we'll be looking at a black screen... */
-            fprintf (stderr, "molecule: no bonds: turning -label on.\n");
+            (void) fprintf (stderr, "molecule: no bonds: turning -label on.\n");
             do_labels = 1;
           }
        }
@@ -1210,7 +1254,7 @@ gl_init (ModeInfo *mi)
 #define RANDSIGN() ((LRAND() & 1) ? 1 : -1)
 
 static void
-rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
+rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
 {
   double ppos = *pos;
 
@@ -1225,13 +1269,12 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v)
   else if (ppos < 0)
     ppos += 1.0;
 
-  if (ppos < 0) {
-    /* abort(); */
-    fprintf (stderr, "ppos = %g\n", ppos);
-  }
-  if (ppos > 1.0) {
-     /* abort(); */
-    fprintf (stderr, "ppos = %g\n", ppos);
+  if ((ppos < 0.0) || (ppos > 1.0)) {
+    if (verbose) {
+      (void) fprintf(stderr, "Weirdness in rotate()\n");
+      (void) fprintf(stderr, "ppos = %g\n", ppos);
+    }
+    return;
   }
   *pos = (*pos > 0 ? ppos : -ppos);
 
@@ -1301,7 +1344,6 @@ init_molecule (ModeInfo *mi)
 {
   molecule_configuration *mc;
   int wire;
-  int screen;
 
 #ifndef STANDALONE
   timeout = MI_CYCLES(mi);
@@ -1316,20 +1358,8 @@ init_molecule (ModeInfo *mi)
 
   mc = &mcs[MI_SCREEN(mi)];
   if (mc->glx_context) {
-	/* Display lists MUST be freed while their glXContext is current. */
-	glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(mc->glx_context));
-	if (glIsList(mc->font1_dlist)) {
-	  glDeleteLists(mc->font1_dlist, 1);
-	  mc->font1_dlist = 0;
-	}
-	if (glIsList(mc->font2_dlist)) {
-	  glDeleteLists(mc->font2_dlist, 1);
-	  mc->font2_dlist = 0;
-	}
-	if (glIsList(mc->molecule_dlist)) {
-	  glDeleteLists(mc->molecule_dlist, 1);
-	  mc->molecule_dlist = 0;
-	}
+	/* Free font stuff */
+	free_fonts (mi);
   }
 
   if ((mc->glx_context = init_GL(mi)) != NULL) {
@@ -1368,7 +1398,7 @@ init_molecule (ModeInfo *mi)
         else if (*s == 'z' || *s == 'Z') mc->spin_z = 1;
         else
           {
-            fprintf (stderr,
+            (void) fprintf (stderr,
          "molecule: spin must contain only the characters X, Y, or Z (not \"%s\")\n",
                      do_spin);
             /* exit (1); */
@@ -1493,9 +1523,9 @@ draw_molecule (ModeInfo *mi)
         if (mc->spin_y) glRotatef(y * 360, 0.0, 1.0, 0.0);
         if (mc->spin_z) glRotatef(z * 360, 0.0, 0.0, 1.0);
 
-        rotate(&mc->rotx, &mc->dx, &mc->ddx, mc->d_max);
-        rotate(&mc->roty, &mc->dy, &mc->ddy, mc->d_max);
-        rotate(&mc->rotz, &mc->dz, &mc->ddz, mc->d_max);
+        rotate(&mc->rotx, &mc->dx, &mc->ddx, mc->d_max, MI_IS_VERBOSE(mi));
+        rotate(&mc->roty, &mc->dy, &mc->ddy, mc->d_max, MI_IS_VERBOSE(mi));
+        rotate(&mc->rotz, &mc->dz, &mc->ddz, mc->d_max, MI_IS_VERBOSE(mi));
       }
   }
 
@@ -1514,75 +1544,44 @@ release_molecule(ModeInfo * mi)
 {
   if (mcs != NULL) {
 	int         screen;
-	int         i;
 
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 	  molecule_configuration *mc = &mcs[screen];
 
-/*
+#if 0
+	int         i;
+
 	  for (i = 0; i < mc->nmolecules; i++) {
 	    molecule *m = &mc->molecules[i];
 
 	    if (m->atoms) {
-		(void) free ((char *) m->atoms);
-		m->atoms = NULL;
+		(void) free ((void *) m->atoms);
+		m->atoms = (molecule_atom *) NULL;
 	    }
 	    if (m->bonds) {
-		(void) free ((char *) m->bonds);
-		m->bonds = NULL;
+		(void) free ((void *) m->bonds);
+		m->bonds = (molecule_bond *) NULL;
 	    }
 	    if (m->label) {
-		(void) free ((char *) m->label);
-		m->label = NULL;
+		(void) free ((void *) m->label);
+		m->label = (char *) NULL;
 	    }
 	  }
 	  if (mc->molecules) {
-		(void) free ((char *) mc->molecules);
-		mc->molecules = NULL;
+		(void) free ((void *) mc->molecules);
+		mc->molecules = (molecule *) NULL;
 	  }
-*/
+#endif
 
 	  if (mc->glx_context) {
 		/* Display lists MUST be freed while their glXContext is current. */
 		glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(mc->glx_context));
-		clear_gl_error ();
-		if (glIsList(mc->molecule_dlist)) {
-			glDeleteLists(mc->molecule_dlist, 1);
-			check_gl_error ("glDeleteLists");
-			mc->molecule_dlist = 0;
-		}
-
 		/* Free font stuff */
-		if (mc->xfont1) {
-			int last;
-
-			last = mc->xfont1->max_char_or_byte2;
-			clear_gl_error ();
-			if (glIsList(mc->font1_dlist)) {
-				glDeleteLists (mc->font1_dlist,(GLuint) last+1);
-				check_gl_error ("glDeleteLists");
-				mc->font1_dlist = 0;
-			}
-			XFreeFont(MI_DISPLAY(mi),mc->xfont1);
-			mc->xfont1 = (XFontStruct *) NULL;
-		}
-		if (mc->xfont2) {
-			int last;
-
-			last = mc->xfont2->max_char_or_byte2;
-			clear_gl_error ();
-			if (glIsList(mc->font2_dlist)) {
-				glDeleteLists (mc->font2_dlist,(GLuint) last+1);
-				check_gl_error ("glDeleteLists");
-				mc->font2_dlist = 0;
-			}
-			XFreeFont(MI_DISPLAY(mi),mc->xfont2);
-			mc->xfont2 = (XFontStruct *) NULL;
-	  	}
+		free_fonts (mi);
 	  }
 	}
 	(void) free((void *) mcs);
-	mcs = NULL;
+	mcs = (molecule_configuration *) NULL;
   }
   FreeAllGL(mi);
 }
