@@ -40,7 +40,7 @@ static const char sccsid[] = "@(#)morph3d.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Feb-13-1997)
  *
@@ -85,7 +85,7 @@ ModeSpecOpt morph3d_opts =
 #ifdef USE_MODULES
 ModStruct   morph3d_description =
 {"morph3d", "init_morph3d", "draw_morph3d", "release_morph3d",
- "draw_morph3d", "change_morph3d", NULL, &morph3d_opts,
+ "draw_morph3d", "change_morph3d", (char *) NULL, &morph3d_opts,
  1000, 0, 1, 1, 4, 1.0, "",
  "Shows GL morphing polyhedra", 0, NULL};
 
