@@ -34,7 +34,7 @@ static const char sccsid[] = "@(#)pipes.c	5.00 2000/11/01 xlockmore";
  * mistakes.
  *
  * My e-mail addresses is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Apr-09-1997)
  *
@@ -120,7 +120,7 @@ ModStruct   pipes_description =
 #else
  "change_pipes",
 #endif
- "change_pipes", NULL, &pipes_opts,
+ "change_pipes", (char *) NULL, &pipes_opts,
  1000, 2, 5, 500, 4, 1.0, "",
  "Shows a selfbuilding pipe system", 0, NULL};
 
