@@ -32,7 +32,7 @@ static const char sccsid[] = "@(#)rubik.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Jul-31-1997)
  *
@@ -176,7 +176,7 @@ ModeSpecOpt rubik_opts =
 #ifdef USE_MODULES
 ModStruct   rubik_description =
 {"rubik", "init_rubik", "draw_rubik", "release_rubik",
- "draw_rubik", "change_rubik", NULL, &rubik_opts,
+ "draw_rubik", "change_rubik", (char *) NULL, &rubik_opts,
  10000, -30, 5, -6, 64, 1.0, "",
  "Shows an auto-solving Rubik's Cube", 0, NULL};
 
