@@ -1,7 +1,7 @@
-/* sballs --- 8 balls spinning like crazy in GL */
+/* sballs --- balls spinning like crazy in GL */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)sballs.c	5.01 2001/03/09 xlockmore";
+static const char sccsid[] = "@(#)sballs.c	5.02 2001/03/10 xlockmore";
 #endif
 
 /* Copyright (c) E. Lassauge, 2001. */
@@ -28,6 +28,8 @@ static const char sccsid[] = "@(#)sballs.c	5.01 2001/03/09 xlockmore";
  *
  * REVISION HISTORY:
  *
+ * E.Lassauge - 03-Oct-2001:
+ *      - minor bugfixes - get ready for xscreensaver
  * E.Lassauge - 09-Mar-2001:
  *      - get rid of my framerate options to use showfps
  * E.Lassauge - 28-Nov-2000:
@@ -38,24 +40,27 @@ static const char sccsid[] = "@(#)sballs.c	5.01 2001/03/09 xlockmore";
  *
  */
 
-#ifdef STANDALONE
-#define PROGCLASS "Sballs"
-#define HACK_INIT init_sballs
-#define HACK_DRAW draw_sballs
-#define sballs xlockmore_opts
-#define DEFAULTS "*delay: 10000 \n" \
- "*size: 0 \n" \
- "*object: 0\n" \	/* random object */
- "*trackmouse: False \n" \
- "*showfps: False \n" \
- "*wireframe:  False \n"
+#ifdef STANDALONE	/* xscreensaver mode */
+#define PROGCLASS 	"Sballs"
+#define HACK_INIT 	init_sballs
+#define HACK_DRAW 	draw_sballs
+#define HACK_RESHAPE 	reshape_sballs
+#define sballs_opts 	xlockmore_opts
+#define DEFAULTS 	"*delay: 	10000 \n" \
+ 			"*size: 	    0 \n" \
+			"*cycles:	   10 \n" \
+ 			"*object: 	    0 \n" \
+ 			"*trackmouse: 	False \n" \
+ 			"*showFPS: 	False \n" \
+ 			"*wireframe:  	False \n" \
+ 			"*texture:  	True  \n"
 
+#define MODE_sballs
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else				/* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
 #include "visgl.h"
 #endif				/* !STANDALONE */
-#include "iostuff.h"            /* getFont() */
 
 #ifdef MODE_sballs
 
@@ -67,7 +72,10 @@ static const char sccsid[] = "@(#)sballs.c	5.01 2001/03/09 xlockmore";
 #include <GL/glx.h>
 #include <GL/glu.h>
 
+#if defined( USE_XPM ) || defined( USE_XPMINC ) || defined( HAVE_XPM )
+/* USE_XPM & USE_XPMINC in xlock mode ; HAVE_XPM in xscreensaver mode */
 #include "xpm-ximage.h"
+#define I_HAVE_XPM
 
 #ifdef STANDALONE
 #include "../images/face.xpm"
@@ -76,6 +84,7 @@ static const char sccsid[] = "@(#)sballs.c	5.01 2001/03/09 xlockmore";
 #include "pixmaps/face.xpm"
 #include "pixmaps/back.xpm"
 #endif /* !STANDALONE */
+#endif /* HAVE_XPM */
 
 /* Manage option vars */
 #define DEF_TEXTURE	"True"
@@ -86,7 +95,6 @@ static Bool do_texture;
 static Bool do_trackmouse;
 static int  object;
 static int  spheres;
-static XFontStruct *mode_font = None;
 
 static XrmOptionDescRec opts[] = {
     {(char *) "-texture", (char *) ".sballs.texture", XrmoptionNoArg, (caddr_t) "on"},
@@ -118,7 +126,7 @@ ModeSpecOpt sballs_opts =
 #ifdef USE_MODULES
 ModStruct sballs_description =
     { "sballs", "init_sballs", "draw_sballs", "release_sballs",
-    "draw_sballs", "change_sballs", NULL, &sballs_opts,
+    "draw_sballs", "change_sballs", (char *) NULL, &sballs_opts,
     /*
     delay,count,cycles,size,ncolors,sat
      */
@@ -148,7 +156,6 @@ typedef struct {
     XImage *ftexture;		/* face texture image bits */
     GLuint backid;		/* back texture id: GL world */
     GLuint faceid;		/* face texture id: GL world */
-    GLuint fontbase;            /* fontbase id: GL world */
 
     vec3_t eye;
     vec3_t rot;
@@ -156,9 +163,6 @@ typedef struct {
     int speed;
     float radius[MAX_BALLS];
 
-    clock_t told;		/* frame timetag */
-    int frcount;		/* frame counter */
-    char frbuf[80];		/* frame value string */
 } sballsstruct;
 
 /* array of sballsstruct indexed by screen number */
@@ -171,8 +175,8 @@ static float LightPosition[]=  { 0.0f, 0.0f, 4.0f, 1.0f };
 
 /* structure of the polyhedras */
 typedef struct {
-        char       *longname;   /* long name of object */
-        char       *shortname;  /* short name of object */
+        const char *longname;   /* long name of object */
+        const char *shortname;  /* short name of object */
         int         numverts;   /* number of vertices */
         float	    radius;     /* radius */
         vec3_t      v[MAX_BALLS];/* the vertices */
@@ -200,7 +204,7 @@ static Polyinfo polygons[] =
 /* 1: objcube - structure values for cube */
 
         {
-                "hexahedron", "cube",   	/* long and short names */
+                "hexahedron", "cube",           /* long and short names */
                 8,       			/* number of vertices, edges, and faces */
 		0.6,
                 {               		/* vertices (x,y,z) */
@@ -411,6 +415,8 @@ static void trackmouse(ModeInfo * mi)
 static void inittextures(ModeInfo * mi)
 {
     sballsstruct *sb = &sballs[MI_SCREEN(mi)];
+
+#if defined( I_HAVE_XPM )
     if (do_texture) {
 
 	glGenTextures(1, &sb->backid);
@@ -478,7 +484,11 @@ static void inittextures(ModeInfo * mi)
         sb->faceid = 0;       /* default textures */
         sb->backid = 0;
     }
-
+#else /* !I_HAVE_XPM */
+  do_texture = False;
+  sb->faceid = 0;       /* default textures */
+  sb->backid = 0;
+#endif /* !I_HAVE_XPM */
 }
 
 static void drawSphere(ModeInfo * mi,int sphere_num)
@@ -536,7 +546,11 @@ static void drawSphere(ModeInfo * mi,int sphere_num)
  *-----------------------------------------------------------------------------
  */
 
+#ifndef STANDALONE
 static void Reshape(ModeInfo * mi)
+#else
+void reshape_sballs(ModeInfo * mi, int width, int height)
+#endif
 {
 
     sballsstruct *sb = &sballs[MI_SCREEN(mi)];
@@ -729,7 +743,11 @@ void init_sballs(ModeInfo * mi)
 
     if ((sb->glx_context = init_GL(mi)) != NULL) {
 
-	Reshape(mi);
+#ifndef STANDALONE
+	Reshape(mi); /* xlock mode */
+#else
+        reshape_sballs(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
+#endif
 	glDrawBuffer(GL_BACK);
 	Init(mi);
 
@@ -759,7 +777,11 @@ void draw_sballs(ModeInfo * mi)
 
     glXMakeCurrent(display, window, *(sb->glx_context));
     Draw(mi);
-    Reshape(mi);
+#ifndef STANDALONE
+    Reshape(mi); /* xlock mode */
+#else
+    reshape_sballs(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
+#endif
 
     glFinish();
     glXSwapBuffers(display, window);
@@ -781,13 +803,6 @@ void release_sballs(ModeInfo * mi)
     if (sballs != NULL) {
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 	    sballsstruct *sb = &sballs[screen];
-            if (mode_font != None)
-	    {
-        	unsigned int first, last;
-        	first = mode_font->min_char_or_byte2;
-        	last  = mode_font->max_char_or_byte2;
-		glDeleteLists(sb->fontbase,last - first + 1);
-	    }
 	    if (sb->btexture)
 	    {
 		glDeleteTextures(1,&sb->backid);
@@ -802,12 +817,6 @@ void release_sballs(ModeInfo * mi)
 	(void) free((void *) sballs);
 	sballs = (sballsstruct *) NULL;
     }
-    if (mode_font != None)
-    {
-	/* only free-ed when there is no more screens used */
-	XFreeFont(MI_DISPLAY(mi), mode_font);
-	mode_font = None;
-    }
     FreeAllGL(mi);
 }
 
