@@ -133,7 +133,7 @@ ModeSpecOpt skewb_opts =
 #ifdef USE_MODULES
 ModStruct   skewb_description =
 {"skewb", "init_skewb", "draw_skewb", "release_skewb",
- "draw_skewb", "change_skewb", NULL, &skewb_opts,
+ "draw_skewb", "change_skewb", (char *) NULL, &skewb_opts,
  10000, -30, 5, 1, 64, 1.0, "",
  "Shows an auto-solving Skewb", 0, NULL};
 
