@@ -78,7 +78,7 @@ ModeSpecOpt sproingies_opts =
 #ifdef USE_MODULES
 ModStruct   sproingies_description =
 {"sproingies", "init_sproingies", "draw_sproingies", "release_sproingies",
- "refresh_sproingies", "init_sproingies", NULL, &sproingies_opts,
+ "refresh_sproingies", "init_sproingies", (char *) NULL, &sproingies_opts,
  1000, 5, 0, 400, 64, 1.0, "",
  "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL};
 
