@@ -34,7 +34,7 @@ static const char sccsid[] = "@(#)stairs.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * m-vianna@usa.net
+ * mfvianna@centroin.com.br
  *
  * Marcelo F. Vianna (Jun-01-1997)
  *
@@ -84,7 +84,7 @@ ModeSpecOpt stairs_opts =
 #ifdef USE_MODULES
 ModStruct   stairs_description =
 {"stairs", "init_stairs", "draw_stairs", "release_stairs",
- "draw_stairs", "change_stairs", NULL, &stairs_opts,
+ "draw_stairs", "change_stairs", (char *) NULL, &stairs_opts,
  1000, 1, 1, 1, 4, 1.0, "",
  "Shows Infinite Stairs, an Escher-like scene", 0, NULL};
 
