@@ -128,7 +128,7 @@ ModeSpecOpt superquadrics_opts =
 #ifdef USE_MODULES
 ModStruct   superquadrics_description =
 {"superquadrics", "init_superquadrics", "draw_superquadrics", "release_superquadrics",
- "refresh_superquadrics", "init_superquadrics", NULL, &superquadrics_opts,
+ "refresh_superquadrics", "init_superquadrics", (char *) NULL, &superquadrics_opts,
  1000, 25, 40, 1, 4, 1.0, "",
  "Shows 3D mathematical shapes", 0, NULL};
 
