@@ -120,19 +120,20 @@ extern "C" { void refresh_text3d(ModeInfo * mi); }
 /* Windows95 in c:\windows\fonts\arial.ttf */
 
 #ifndef DEF_TTFONT
-#if defined (SOLARIS2) || defined (SUNOS4)
 #if 0
-#define DEF_TTFONT "/usr/share/fonts/xlockmore/arial.ttf"
+#if 1
+#define DEF_TTFONT "/usr/lib/X11/xlock/fonts/arial.ttf"
 #else
-/* Directory of only *.ttf */
-#define DEF_TTFONT "/usr/share/fonts/xlockmore/"
+#define DEF_TTFONT "@PREFIX@/lib/X11/xlock/fonts/arial.ttf"
 #endif
 #else
-#if 0
-#define DEF_TTFONT "/usr/X11R6/lib/X11/fonts/TTF/arial.ttf"
-#else
 /* Directory of only *.ttf */
-#define DEF_TTFONT "/usr/X11R6/lib/X11/fonts/TTF/"
+/* symbol.ttf and wingding.ttf should be excluded or it may core dump */
+/* can be excluded if gltt is modified see README */
+#if 1
+#define DEF_TTFONT "/usr/lib/X11/xlock/fonts/"
+#else
+#define DEF_TTFONT "@PREFIX@/lib/X11/xlock/fonts/"
 #endif
 #endif
 #endif
@@ -189,7 +190,7 @@ ModeSpecOpt text3d_opts =
 #ifdef USE_MODULES
 ModStruct text3d_description =
 {"text3d", "init_text3d", "draw_text3d", "release_text3d",
- "refresh_text3d", "change_text3d", NULL, &text3d_opts,
+ "refresh_text3d", "change_text3d", (char *) NULL, &text3d_opts,
  100000, 1, 1, 1, 64, 1.0, "",
  "Shows 3D text", 0, NULL};
 #endif
@@ -1122,8 +1123,6 @@ void
     tp->face = new FTFace;
     if (!tp->face || !tp->face->open(fontfile)) {
 		(void) fprintf(stderr, "%s: unable to open True Type font %s !\n", MI_NAME(mi), fontfile);
-    	if (tp->face)
-			delete tp->face;
 		release_text3d(mi);
 #ifdef USE_BLANK
 		(void) fprintf(stderr,
