@@ -104,7 +104,7 @@ ModeSpecOpt goop_opts =
 #ifdef USE_MODULES
 ModStruct   goop_description =
 {"goop", "init_goop", "draw_goop", "release_goop",
- "init_goop", "init_goop", NULL, &goop_opts,
+ "init_goop", "init_goop", (char *) NULL, &goop_opts,
  10000, -12, 1, 1, 64, 1.0, "",
  "Shows goop from a lava lamp", 0, NULL};
 
@@ -155,7 +155,7 @@ typedef struct {
 	GC          pixmap_gc;
 } goopstruct;
 
-static goopstruct *goops = NULL;
+static goopstruct *goops = (goopstruct *) NULL;
 
 static Bool
 make_blob(blob * b, int maxx, int maxy, int size)
@@ -387,7 +387,7 @@ free_goop(Display * display, goopstruct * gp)
 				XFreePixmap(display, gp->layers[l].pixmap);
 		}
 		(void) free((void *) gp->layers);
-		gp->layers = NULL;
+		gp->layers = (layer *) NULL;
 	}
 	if (gp->pixmap_gc != None) {
 		XFreeGC(display, gp->pixmap_gc);
@@ -591,7 +591,12 @@ draw_goop(ModeInfo * mi)
 			break;
 
 		default:
-			abort();
+			if (MI_IS_VERBOSE(mi)) {
+				(void) fprintf(stderr,
+					"Weirdness in draw_goop()\n");
+				(void) fprintf(stderr,
+					"gp->mode = %d\n", gp->mode);
+			}
 			break;
 	}
 }
@@ -605,7 +610,7 @@ release_goop(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_goop(MI_DISPLAY(mi), &goops[screen]);
 		(void) free((void *) goops);
-		goops = NULL;
+		goops = (goopstruct *) NULL;
 	}
 }
 
