@@ -7,7 +7,7 @@ static const char sccsid[] = "@(#)grav.c	5.00 2000/11/01 xlockmore";
 #endif
 
 /*-
- * Copyright (c) 1993 by Greg Boewring <greg@smug.student.adelaide.edu.au>
+ * Copyright (c) 1993 by Greg Boewring <gb@pobox.com>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -22,10 +22,10 @@ static const char sccsid[] = "@(#)grav.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 01-Nov-2000: Compatible with xscreensaver
+ * 01-Nov-2000: Allocation checks
  * 10-May-1997: Compatible with xscreensaver
  * 11-Jul-1994: color version
- * 06-Oct-1993: Written by Greg Bowering <greg@smug.student.adelaide.edu.au>
+ * 06-Oct-1993: Written by Greg Bowering <gb@pobox.com>
  */
 
 #ifdef STANDALONE
@@ -75,7 +75,7 @@ ModeSpecOpt grav_opts =
 #ifdef USE_MODULES
 ModStruct   grav_description =
 {"grav", "init_grav", "draw_grav", "release_grav",
- "refresh_grav", "init_grav", NULL, &grav_opts,
+ "refresh_grav", "init_grav", (char *) NULL, &grav_opts,
  10000, -12, 1, 1, 64, 1.0, "",
  "Shows orbiting planets", 0, NULL};
 
@@ -135,7 +135,7 @@ typedef struct {
 	planetstruct *planets;
 } gravstruct;
 
-static gravstruct *gravs = NULL;
+static gravstruct *gravs = (gravstruct *) NULL;
 
 static void
 init_planet(ModeInfo * mi, planetstruct * planet)
@@ -256,7 +256,7 @@ init_grav(ModeInfo * mi)
 	if (gp->nplanets < 0) {
 		if (gp->planets) {
 			(void) free((void *) gp->planets);
-			gp->planets = NULL;
+			gp->planets = (planetstruct *) NULL;
 		}
 		gp->nplanets = NRAND(-gp->nplanets) + 1;	/* Add 1 so its not too boring */
 	}
@@ -337,7 +337,7 @@ release_grav(ModeInfo * mi)
 				(void) free((void *) gp->planets);
 		}
 		(void) free((void *) gravs);
-		gravs = NULL;
+		gravs = (gravstruct *) NULL;
 	}
 }
 
