@@ -86,7 +86,7 @@ ModeSpecOpt helix_opts =
 #ifdef USE_MODULES
 ModStruct   helix_description =
 {"helix", "init_helix", "draw_helix", "release_helix",
- "refresh_helix", "init_helix", NULL, &helix_opts,
+ "refresh_helix", "init_helix", (char *) NULL, &helix_opts,
  25000, 1, 100, 1, 64, 1.0, "",
  "Shows string art", 0, NULL};
 
@@ -113,7 +113,7 @@ typedef struct {
 	int         count;
 } helixstruct;
 
-static helixstruct *helixes = NULL;
+static helixstruct *helixes = (helixstruct *) NULL;
 
 static int
 gcd(int a, int b)
@@ -355,7 +355,7 @@ release_helix(ModeInfo * mi)
 {
 	if (helixes != NULL) {
 		(void) free((void *) helixes);
-		helixes = NULL;
+		helixes = (helixstruct *) NULL;
 	}
 }
 
