@@ -155,7 +155,7 @@ ModeSpecOpt hop_opts =
 #ifdef USE_MODULES
 ModStruct   hop_description =
 {"hop", "init_hop", "draw_hop", "release_hop",
- "refresh_hop", "init_hop", NULL, &hop_opts,
+ "refresh_hop", "init_hop", (char *) NULL, &hop_opts,
  10000, 1000, 2500, 1, 64, 1.0, "",
  "Shows real plane iterated fractals", 0, NULL};
 
@@ -190,7 +190,7 @@ typedef struct {
 	XPoint     *pointBuffer;	/* pointer for XDrawPoints */
 } hopstruct;
 
-static hopstruct *hops = NULL;
+static hopstruct *hops = (hopstruct *) NULL;
 
 void
 init_hop(ModeInfo * mi)
@@ -549,7 +549,7 @@ release_hop(ModeInfo * mi)
 				(void) free((void *) hp->pointBuffer);
 		}
 		(void) free((void *) hops);
-		hops = NULL;
+		hops = (hopstruct *) NULL;
 	}
 }
 
