@@ -124,7 +124,7 @@ ModeSpecOpt hyper_opts =
 #ifdef USE_MODULES
 ModStruct   hyper_description =
 {"hyper", "init_hyper", "draw_hyper", "release_hyper",
- "refresh_hyper", "change_hyper", NULL, &hyper_opts,
+ "refresh_hyper", "change_hyper", (char *) NULL, &hyper_opts,
  100000, -6, 300, 1, 64, 1.0, "",
  "Shows spinning n-dimensional hypercubes", 0, NULL};
 
@@ -218,7 +218,7 @@ typedef struct hyper {
 } hyperstruct;
 
 
-static hyperstruct *hypers = NULL;
+static hyperstruct *hypers = (hyperstruct *) NULL;
 
 #define allocarray(P,T,N) if((P=(T*)malloc((N)*sizeof(T)))==NULL) \
  {free_hyper(display,hp);return False;}
@@ -348,75 +348,75 @@ free_hyperstuff(hyperstruct * hp)
 {
 	if (hp->axis_points) {
 		(void) free((void *) hp->axis_points);
-		hp->axis_points = NULL;
+		hp->axis_points = (int *) NULL;
 	}
 	if (hp->points) {
 		(void) free((void *) hp->points);
-		hp->points = NULL;
+		hp->points = (vector *) NULL;
 	}
 	if (hp->pointsleft) {
 		(void) free((void *) hp->pointsleft);
-		hp->pointsleft = NULL;
+		hp->pointsleft = (vector *) NULL;
 	}
 	if (hp->lines) {
 		XFree(hp->lines);
-		hp->lines = NULL;
+		hp->lines = (line_segment *) NULL;
 	}
 	if (hp->planes) {
 		XFree(hp->planes);
-		hp->planes = NULL;
+		hp->planes = (plane_section *) NULL;
 	}
 	if (hp->rotation_planes) {
 		XFree(hp->rotation_planes);
-		hp->rotation_planes = NULL;
+		hp->rotation_planes = (XPoint *) NULL;
 	}
 	if (hp->rotations) {
 		(void) free((void *) hp->rotations);
-		hp->rotations = NULL;
+		hp->rotations = (double *) NULL;
 	}
 	if (hp->d_rotations) {
 		(void) free((void *) hp->d_rotations);
-		hp->d_rotations = NULL;
+		hp->d_rotations = (double *) NULL;
 	}
 	if (hp->dd_rotations) {
 		(void) free((void *) hp->dd_rotations);
-		hp->dd_rotations = NULL;
+		hp->dd_rotations = (double *) NULL;
 	}
 	if (hp->cdd_rotations) {
 		(void) free((void *) hp->cdd_rotations);
-		hp->cdd_rotations = NULL;
+		hp->cdd_rotations = (int *) NULL;
 	}
 	if (hp->Trotations) {
 		(void) free((void *) hp->Trotations);
-		hp->Trotations = NULL;
+		hp->Trotations = (matrix *) NULL;
 	}
 	if (hp->Trotationsleft) {
 		(void) free((void *) hp->Trotationsleft);
-		hp->Trotationsleft = NULL;
+		hp->Trotationsleft = (matrix *) NULL;
 	}
 	if (hp->Tall) {
 		(void) free((void *) hp->Tall);
-		hp->Tall = NULL;
+		hp->Tall = (matrix *) NULL;
 	}
 	if (hp->Tallleft) {
 		(void) free((void *) hp->Tallleft);
-		hp->Tallleft = NULL;
+		hp->Tallleft = (matrix *) NULL;
 	}
 	if (hp->xpoints[0]) {
 		XFree(hp->xpoints[0]);
-		hp->xpoints[0] = NULL;
+		hp->xpoints[0] = (XPoint *) NULL;
 	}
 	if (hp->xpoints[1]) {
 		XFree(hp->xpoints[1]);
-		hp->xpoints[1] = NULL;
+		hp->xpoints[1] = (XPoint *) NULL;
 	}
 	if (hp->xpointsleft[0]) {
 		XFree(hp->xpointsleft[0]);
-		hp->xpointsleft[0] = NULL;
+		hp->xpointsleft[0] = (XPoint *) NULL;
 	}
 	if (hp->xpointsleft[1]) {
 		XFree(hp->xpointsleft[1]);
-		hp->xpointsleft[1] = NULL;
+		hp->xpointsleft[1] = (XPoint *) NULL;
 	}
 }
 
@@ -959,7 +959,7 @@ calc_transformation(ModeInfo * mi)
 	double      cosb = 0.0, sinb = 0.0;
 	int         p1, p2;
 	matrix     *Ttmp;
-	matrix     *Tpre, *Tuser, *Tuserleft = NULL;
+	matrix     *Tpre, *Tuser, *Tuserleft = (matrix *) NULL;
 	matrix     *Tpretranspose, *Tscale, *Tposttranspose;
 	int         i;
 	dpoint      scale, range, offset;
@@ -1055,7 +1055,7 @@ calc_transformation(ModeInfo * mi)
 	/*
 	 * Calculate the best scale of the two axes.
 	 * Multiply by 0.9 to use 90% of the display.
-	 * Divide by the sqrt(2.0) because it's bigest when
+	 * Divide by the sqrt(2.0) because it's biggest when
 	 * rotated by 45 degrees.
 	 *
 	 * This principle generalizes to sqrt(hp->num_d).
@@ -1253,7 +1253,7 @@ release_hyper(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_hyper(MI_DISPLAY(mi), &hypers[screen]);
 		(void) free((void *) hypers);
-		hypers = NULL;
+		hypers = (hyperstruct *) NULL;
 	}
 }
 
