@@ -144,7 +144,7 @@ ModeSpecOpt ico_opts =
 #ifdef USE_MODULES
 ModStruct   ico_description =
 {"ico", "init_ico", "draw_ico", "release_ico",
- "refresh_ico", "change_ico", NULL, &ico_opts,
+ "refresh_ico", "change_ico", (char *) NULL, &ico_opts,
  200000, 0, 400, 0, 64, 1.0, "",
  "Shows a bouncing polyhedron", 0, NULL};
 
@@ -519,7 +519,7 @@ typedef struct {
 	Pixmap      pixmaps[NUMSTIPPLES - 1];
 } icostruct;
 
-static icostruct *icos = NULL;
+static icostruct *icos = (icostruct *) NULL;
 
 /*-
  * variables that are not set except maybe in initialization before
@@ -975,13 +975,14 @@ init_ico(ModeInfo * mi)
 		}
 	}
 
-	ip->edges = edges;
-	ip->faces = faces;
-	ip->opaque = opaque;
 	if (MI_IS_FULLRANDOM(mi)) {
 		ip->faces = (Bool) (LRAND() & 1);
 		ip->edges = (Bool) (LRAND() & 1);
 		ip->opaque = (!(NRAND(4) == 0));
+	} else {
+		ip->edges = edges;
+		ip->faces = faces;
+		ip->opaque = opaque;
 	}
 
 	if (size < -MINSIZE)
@@ -1118,7 +1119,7 @@ release_ico(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_ico(MI_DISPLAY(mi), &icos[screen]);
 		(void) free((void *) icos);
-		icos = NULL;
+		icos = (icostruct *) NULL;
 	}
 }
 
