@@ -55,7 +55,7 @@ ModeSpecOpt image_opts =
 #ifdef USE_MODULES
 ModStruct   image_description =
 {"image", "init_image", "draw_image", "release_image",
- "refresh_image", "init_image", NULL, &image_opts,
+ "refresh_image", "init_image", (char *) NULL, &image_opts,
  2000000, -10, 1, 1, 64, 1.0, "",
  "Shows randomly appearing logos", 0, NULL};
 
@@ -94,7 +94,7 @@ typedef struct {
 	unsigned long black;
 } imagestruct;
 
-static imagestruct *ims = NULL;
+static imagestruct *ims = (imagestruct *) NULL;
 
 static void
 free_stuff(Display * display, imagestruct * ip)
@@ -115,7 +115,7 @@ free_image(Display * display, imagestruct * ip)
 {
 	if (ip->icons != NULL) {
 		(void) free((void *) ip->icons);
-		ip->icons = NULL;
+		ip->icons = (imagetype *) NULL;
 	}
 	free_stuff(display, ip);
 	if (ip->logo != None) {
@@ -274,7 +274,7 @@ release_image(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_image(MI_DISPLAY(mi), &ims[screen]);
 		(void) free((void *) ims);
-		ims = NULL;
+		ims = (imagestruct *) NULL;
 	}
 }
 
