@@ -174,7 +174,7 @@ ModeSpecOpt juggle_opts =
 #ifdef USE_MODULES
 ModStruct   juggle_description = {
 	"juggle", "init_juggle", "draw_juggle", "release_juggle",
-	"draw_juggle", "init_juggle", NULL, &juggle_opts,
+	"draw_juggle", "init_juggle", (char *) NULL, &juggle_opts,
 	10000, 150, 30, 1, 64, 1.0, "",
 	"Shows a Juggler, juggling", 0, NULL
 };
@@ -296,7 +296,7 @@ typedef struct {
   Bool        solid, uni;	
 } jugglestruct;
 
-static jugglestruct *juggles = NULL;
+static jugglestruct *juggles = (jugglestruct *) NULL;
 
 typedef struct {
   char * pattern;
@@ -311,7 +311,7 @@ typedef struct {
   int number;
 } PatternIndex;
 
-static PatternIndex* patternindex = NULL;
+static PatternIndex* patternindex = (PatternIndex *) NULL;
 
 /* List of popular patterns, in any order */
 static patternstruct portfolio[] = {
@@ -393,7 +393,7 @@ free_pattern(jugglestruct *sp) {
 			REMOVE(t); /* don't eliminate t */
 		}
 		(void) free((void *) sp->head);
-  		sp->head = NULL;
+  		sp->head = (Trajectory *) NULL;
 	}
 }
 
@@ -402,7 +402,7 @@ free_juggle(jugglestruct *sp)
 {
 	if (sp->trace != NULL) {
 		(void) free((void *) sp->trace);
-		sp->trace = NULL;
+		sp->trace = (XPoint *) NULL;
 	}
 	free_pattern(sp);
 }
@@ -1110,11 +1110,11 @@ release_juggle(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_juggle(&juggles[screen]);
 		(void) free((void *) juggles);
-		juggles = NULL;
+		juggles = (jugglestruct *) NULL;
 	}
 	if (patternindex != NULL) {
 		(void) free((void *) patternindex);
-		patternindex = NULL;
+		patternindex = (PatternIndex *) NULL;
 	}
 }
 
