@@ -89,7 +89,7 @@ ModeSpecOpt julia_opts =
 #ifdef USE_MODULES
 ModStruct   julia_description =
 {"julia", "init_julia", "draw_julia", "release_julia",
- "refresh_julia", "init_julia", NULL, &julia_opts,
+ "refresh_julia", "init_julia", (char *) NULL, &julia_opts,
  10000, 1000, 20, 1, 64, 1.0, "",
  "Shows the Julia set", 0, NULL};
 
@@ -117,7 +117,7 @@ typedef struct {
 	Cursor      cursor;
 } juliastruct;
 
-static juliastruct *julias = NULL;
+static juliastruct *julias = (juliastruct *) NULL;
 
 /* How many segments to draw per cycle when redrawing */
 #define REDRAWSTEP 3
@@ -194,7 +194,7 @@ free_julia(Display *display, juliastruct *jp)
 			if (jp->pointBuffer[buffer] != NULL)
 				(void) free((void *) jp->pointBuffer[buffer]);
 		(void) free((void *) jp->pointBuffer);
-		jp->pointBuffer = NULL;
+		jp->pointBuffer = (XPoint **) NULL;
 	}
 	if (jp->stippledGC != None) {
 		XFreeGC(display, jp->stippledGC);
@@ -446,7 +446,7 @@ release_julia(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_julia(MI_DISPLAY(mi), &julias[screen]);
 		(void) free((void *) julias);
-		julias = NULL;
+		julias = (juliastruct *) NULL;
 	}
 }
 
