@@ -162,7 +162,7 @@ ModeSpecOpt kaleid_opts =
 ModStruct   kaleid_description =
 {
 	"kaleid", "init_kaleid", "draw_kaleid", "release_kaleid",
-	"refresh_kaleid", "init_kaleid", NULL, &kaleid_opts,
+	"refresh_kaleid", "init_kaleid", (char *) NULL, &kaleid_opts,
 	80000, 4, 40, -9, 64, 0.6, "",
 	"Shows Brewster's Kaleidoscope", 0, NULL
 };
@@ -215,7 +215,6 @@ typedef struct {
 typedef struct {
 	penstruct  *pen;
 
-
 	int         PercentBlack;
 	int         PenCount;
 	int         maxlwidth;
@@ -228,7 +227,7 @@ typedef struct {
 	Bool        alternate, disconnected, serial, linear, spiral, spots;
 } kaleidstruct;
 
-static kaleidstruct *kaleids = NULL;
+static kaleidstruct *kaleids = (kaleidstruct *) NULL;
 
 /*-
  *
@@ -1112,7 +1111,7 @@ init_kaleid(ModeInfo * mi)
 		/* if kp->PenCount is random ... the size can change */
 		if (kp->pen != NULL) {
 			(void) free((void *) kp->pen);
-			kp->pen = NULL;
+			kp->pen = (penstruct *) NULL;
 		}
 		kp->PenCount = NRAND(-kp->PenCount - MINPENS + 1) + MINPENS;
 	} else if (kp->PenCount < MINPENS)
@@ -1316,7 +1315,7 @@ draw_kaleid(ModeInfo * mi)
 	if ((segs = (XSegment *) malloc(NumberOfSegments *
 			sizeof (XSegment))) == NULL) {
 		(void) free((void *) kp->pen);
-		kp->pen = NULL;
+		kp->pen = (penstruct *) NULL;
 		return;
 	}
 
@@ -1394,7 +1393,7 @@ release_kaleid(ModeInfo * mi)
 				(void) free((void *) kp->pen);
 		}
 		(void) free((void *) kaleids);
-		kaleids = NULL;
+		kaleids = (kaleidstruct *) NULL;
 	}
 }
 
