@@ -123,7 +123,7 @@ ModeSpecOpt kumppa_opts =
 #ifdef USE_MODULES
 ModStruct   kumppa_description =
 {"kumppa", "init_kumppa", "draw_kumppa", "release_kumppa",
- "init_kumppa", "init_kumppa", NULL, &kumppa_opts,
+ "init_kumppa", "init_kumppa", (char *) NULL, &kumppa_opts,
  10000, 1, 1000, 1, 64, 1.0, "",
  "Shows Kumppa", 0, NULL};
 
@@ -185,7 +185,7 @@ typedef struct {
 	ModeInfo   *mi;
 } kumppastruct;
 
-static kumppastruct *kumppas = NULL;
+static kumppastruct *kumppas = (kumppastruct *) NULL;
 
 
 
@@ -319,31 +319,31 @@ free_kumppa(Display *display, kumppastruct *s)
 	}
 	if (s->acosinus != NULL) {
 		(void) free((void *) s->acosinus);
-		s->acosinus = NULL;
+		s->acosinus = (float *) NULL;
 	}
 	if (s->Xrotations != NULL) {
 		(void) free((void *) s->Xrotations);
-		s->Xrotations = NULL;
+		s->Xrotations = (int *) NULL;
 	}
 	if (s->Yrotations != NULL) {
 		(void) free((void *) s->Yrotations);
-		s->Yrotations = NULL;
+		s->Yrotations = (int *) NULL;
 	}
 	if (s->Xrottable != NULL) {
 		(void) free((void *) s->Xrottable);
-		s->Xrottable = NULL;
+		s->Xrottable = (int *) NULL;
 	}
 	if (s->Yrottable != NULL) {
 		(void) free((void *) s->Yrottable);
-		s->Yrottable = NULL;
+		s->Yrottable = (int *) NULL;
 	}
 	if (s->rotateX != NULL) {
 		(void) free((void *) s->rotateX);
-		s->rotateX = NULL;
+		s->rotateX = (int *) NULL;
 	}
 	if (s->rotateY != NULL) {
 		(void) free((void *) s->rotateY);
-		s->rotateY = NULL;
+		s->rotateY = (int *) NULL;
 	}
 }
 
@@ -521,6 +521,10 @@ make_rots(ModeInfo * mi, double xspeed, double yspeed)
 	(void) free((void *) chks);
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
 
 void
 init_kumppa(ModeInfo * mi)
@@ -545,9 +549,6 @@ init_kumppa(ModeInfo * mi)
 			XColor      color;
 
 #ifndef STANDALONE
-			extern char *background;
-			extern char *foreground;
-
 			s->fg = MI_FG_PIXEL(mi);
 			s->bg = MI_BG_PIXEL(mi);
 #endif
@@ -805,7 +806,7 @@ release_kumppa(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_kumppa(MI_DISPLAY(mi), &kumppas[screen]);
 		(void) free((void *) kumppas);
-		kumppas = NULL;
+		kumppas = (kumppastruct *) NULL;
 	}
 }
 
