@@ -50,7 +50,7 @@ ModeSpecOpt laser_opts =
 #ifdef USE_MODULES
 ModStruct   laser_description =
 {"laser", "init_laser", "draw_laser", "release_laser",
- "refresh_laser", "init_laser", NULL, &laser_opts,
+ "refresh_laser", "init_laser", (char *) NULL, &laser_opts,
  20000, -10, 200, 1, 64, 1.0, "",
  "Shows spinning lasers", 0, NULL};
 
@@ -104,14 +104,14 @@ typedef struct {
 	laserstruct *laser;
 } lasersstruct;
 
-static lasersstruct *lasers = NULL;
+static lasersstruct *lasers = (lasersstruct *) NULL;
 
 static void
 free_laser(Display *display, lasersstruct *lp)
 {
 	if (lp->laser != NULL) {
 		(void) free((void *) lp->laser);
-		lp->laser = NULL;
+		lp->laser = (laserstruct *) NULL;
 	}
 	if (lp->stippledGC != None) {
 		XFreeGC(display, lp->stippledGC);
@@ -142,7 +142,7 @@ init_laser(ModeInfo * mi)
 		/* if lp->ln is random ... the size can change */
 		if (lp->laser != NULL) {
 			(void) free((void *) lp->laser);
-			lp->laser = NULL;
+			lp->laser = (laserstruct *) NULL;
 		}
 		lp->ln = NRAND(-lp->ln - MINLASER + 1) + MINLASER;
 	} else if (lp->ln < MINLASER)
@@ -348,7 +348,7 @@ release_laser(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_laser(MI_DISPLAY(mi), &lasers[screen]);
 		(void) free((void *) lasers);
-		lasers = NULL;
+		lasers = (lasersstruct *) NULL;
 	}
 }
 
