@@ -177,7 +177,7 @@ ModeSpecOpt life_opts =
 #ifdef USE_MODULES
 ModStruct   life_description =
 {"life", "init_life", "draw_life", "release_life",
- "refresh_life", "change_life", NULL, &life_opts,
+ "refresh_life", "change_life", (char *) NULL, &life_opts,
  750000, 40, 140, 0, 64, 1.0, "",
  "Shows Conway's game of Life", 0, NULL};
 
@@ -278,9 +278,9 @@ typedef struct {
 
 } lifestruct;
 
-static lifestruct *lifes = NULL;
+static lifestruct *lifes = (lifestruct *) NULL;
 
-static char *filePattern = NULL;
+static char *filePattern = (char *) NULL;
 
 static char plots[NEIGHBORKINDS] =
 {
@@ -1921,7 +1921,7 @@ static void
 parseRule(ModeInfo * mi)
 {
 	lifestruct *lp = &lifes[MI_SCREEN(mi)];
-	int         n, g, l, neighbor_kind;
+	int         n, g = 0, l = 0, neighbor_kind;
 	char        serving = 0;
 	static Bool found = False;
 
@@ -2084,11 +2084,13 @@ init_list(lifestruct * lp, int state)
 	}
 	if ((lp->first[state] = (CellList *) malloc(sizeof (CellList))) == NULL) {
 		(void) free((void *) lp->last[state]);
-		lp->last[state] = NULL;
+		lp->last[state] = (CellList *) NULL;
 		return False;
 	}
-	lp->first[state]->previous = lp->last[state]->next = NULL;
-	lp->first[state]->next = lp->last[state]->previous = NULL;
+	lp->first[state]->previous = lp->last[state]->next =
+		 (struct _CellList *) NULL;
+	lp->first[state]->next = lp->last[state]->previous =
+		 (struct _CellList *) NULL;
 	lp->first[state]->next = lp->last[state];
 	lp->last[state]->previous = lp->first[state];
 	return True;
@@ -2118,7 +2120,7 @@ removefrom_list(lifestruct * lp, int state, CellList * curr)
 	curr->previous->next = curr->next;
 	curr->next->previous = curr->previous;
 	if (curr->info.position >= 0) {
-		lp->arr[curr->info.position] = NULL;
+		lp->arr[curr->info.position] = (CellList *) NULL;
 		lp->ncells[state]--;
 	}
 	(void) free((void *) curr);
@@ -2252,7 +2254,7 @@ free_cells(lifestruct * lp)
 {
 	if (lp->arr != NULL) {
 		(void) free((void *) lp->arr);
-		lp->arr = NULL;
+		lp->arr = (CellList **) NULL;
 	}
 }
 
@@ -2280,16 +2282,16 @@ free_life(Display * display, lifestruct * lp)
 			flush_list(lp, state);
 		if (lp->last[state])
 			(void) free((void *) lp->last[state]);
-		lp->last[state] = NULL;
+		lp->last[state] = (CellList *) NULL;
 		if (lp->first[state])
 			(void) free((void *) lp->first[state]);
-		lp->first[state] = NULL;
+		lp->first[state] = (CellList *) NULL;
 	}
 	free_cells(lp);
 	free_stuff(display, lp);
-	if (lp->logo != NULL) {
+	if (lp->logo != None) {
 		destroyImage(&lp->logo, &lp->graphics_format);
-		lp->logo = NULL;
+		lp->logo = None;
 	}
 }
 
@@ -2368,7 +2370,7 @@ setcell(ModeInfo * mi, int col, int row, int state)
 	if (state == LIVE) {
 		if (curr && curr->info.state == DEAD) {
 			removefrom_list(lp, DEAD, curr);
-			curr = NULL;
+			curr = (CellList *) NULL;
 		}
 		if (!curr) {
 			for (n = 0; n < lp->neighbors; n++) {
@@ -2474,7 +2476,7 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 {
 	lifestruct *lp = &lifes[MI_SCREEN(mi)];
 	int         row, col, orient, temp;
-	char       *patptr = NULL;
+	char       *patptr = (char *) NULL;
 
 	if (filePattern) {
 		patptr = &filePattern[0];
@@ -3186,7 +3188,7 @@ release_life(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_life(MI_DISPLAY(mi), &lifes[screen]);
 		(void) free((void *) lifes);
-		lifes = NULL;
+		lifes = (lifestruct *) NULL;
 	}
 }
 
