@@ -91,7 +91,7 @@ ModeSpecOpt life1d_opts =
 #ifdef USE_MODULES
 ModStruct   life1d_description =
 {"life1d", "init_life1d", "draw_life1d", "release_life1d",
- "refresh_life1d", "init_life1d", NULL, &life1d_opts,
+ "refresh_life1d", "init_life1d", (char *) NULL, &life1d_opts,
  10000, 1, 10, 0, 64, 1.0, "",
  "Shows Wolfram's game of 1D Life", 0, NULL};
 
@@ -150,7 +150,7 @@ typedef struct {
 	int         busyLoop;
 } life1dstruct;
 
-static life1dstruct *life1ds = NULL;
+static life1dstruct *life1ds = (life1dstruct *) NULL;
 
 static int  totalistic_rules[][3] =
 {
@@ -601,9 +601,9 @@ free_life1d(Display * display, life1dstruct * lp)
 {
 	int         shade;
 
-	if (lp->stippledGC != NULL) {
+	if (lp->stippledGC != None) {
 		XFreeGC(display, lp->stippledGC);
-		lp->stippledGC = NULL;
+		lp->stippledGC = None;
 	}
 	if (lp->init_bits != 0) {
 		for (shade = 0; shade < MAXSTATES; shade++)
@@ -612,24 +612,24 @@ free_life1d(Display * display, life1dstruct * lp)
 	}
 	if (lp->newcells != NULL) {
 		(void) free((void *) lp->newcells);
-		lp->newcells = NULL;
+		lp->newcells = (unsigned char *) NULL;
 	}
 	if (lp->oldcells != NULL) {
 		(void) free((void *) lp->oldcells);
-		lp->oldcells = NULL;
+		lp->oldcells = (unsigned char *) NULL;
 	}
 	if (lp->buffer != NULL) {
 		(void) free((void *) lp->buffer);
-		lp->buffer = NULL;
+		lp->buffer = (unsigned char *) NULL;
 	}
 	if (lp->nextstate != NULL) {
 		(void) free((void *) lp->nextstate);
-		lp->nextstate = NULL;
+		lp->nextstate = (char *) NULL;
 	}
 	free_stuff(display, lp);
-	if (lp->logo) {
+	if (lp->logo != None) {
 		destroyImage(&lp->logo, &lp->graphics_format);
-		lp->logo = NULL;
+		lp->logo = None;
 	}
 }
 
@@ -884,7 +884,7 @@ release_life1d(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_life1d(MI_DISPLAY(mi), &life1ds[screen]);
 		(void) free((void *) life1ds);
-		life1ds = NULL;
+		life1ds = (life1dstruct *) NULL;
 	}
 }
 
