@@ -97,7 +97,7 @@ ModeSpecOpt life3d_opts =
 #ifdef USE_MODULES
 ModStruct   life3d_description =
 {"life3d", "init_life3d", "draw_life3d", "release_life3d",
- "refresh_life3d", "change_life3d", NULL, &life3d_opts,
+ "refresh_life3d", "change_life3d", (char *) NULL, &life3d_opts,
  1000000, 35, 85, 1, 64, 1.0, "",
  "Shows Bays' game of 3D Life", 0, NULL};
 
@@ -180,11 +180,11 @@ typedef struct {
 	Bool        wireframe;
 } life3dstruct;
 
-static life3dstruct *life3ds = NULL;
+static life3dstruct *life3ds = (life3dstruct *) NULL;
 
 static paramstruct input_param;
 static Bool allPatterns = False, allGliders = False;
-static char *filePattern = NULL;
+static char *filePattern = (char *) NULL;
 
 /*-
  * S45/B5 life is probably the best
@@ -1386,7 +1386,7 @@ parseFile(void)
 static void
 Init3D(life3dstruct * lp)
 {
-	lp->ptrhead = lp->ptrend = NULL;
+	lp->ptrhead = lp->ptrend = (CellList *) NULL;
 	lp->eraserhead.next = &lp->eraserend;
 	lp->eraserend.prev = &lp->eraserhead;
 }
@@ -1407,13 +1407,13 @@ AddToList(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z)
 	tmp->z = z;
 	if (lp->ptrhead == NULL) {
 		lp->ptrhead = lp->ptrend = tmp;
-		tmp->prev = NULL;
+		tmp->prev = (struct _CellList *) NULL;
 	} else {
 		lp->ptrend->next = tmp;
 		tmp->prev = lp->ptrend;
 		lp->ptrend = tmp;
 	}
-	lp->ptrend->next = NULL;
+	lp->ptrend->next = (struct _CellList *) NULL;
 	return True;
 }
 
@@ -1434,7 +1434,7 @@ DelFromList(life3dstruct * lp, CellList * cell)
 	else {
 		lp->ptrhead = cell->next;
 		if (lp->ptrhead != NULL)
-			lp->ptrhead->prev = NULL;
+			lp->ptrhead->prev = (struct _CellList *) NULL;
 	}
 
 	if (cell != lp->ptrend)
@@ -1442,7 +1442,7 @@ DelFromList(life3dstruct * lp, CellList * cell)
 	else {
 		lp->ptrend = cell->prev;
 		if (lp->ptrend != NULL)
-			lp->ptrend->next = NULL;
+			lp->ptrend->next = (struct _CellList *) NULL;
 	}
 
 	AddToEraseList(lp, cell);
@@ -1469,7 +1469,7 @@ MemInit(life3dstruct * lp)
 	for (i = 0; i < BASESIZE; ++i) {
 		if (lp->base[i] != NULL) {
 			(void) free((void *) lp->base[i]);
-			lp->base[i] = NULL;
+			lp->base[i] = (unsigned char *) NULL;
 		}
 	}
 	lp->memstart = 0;
@@ -1533,7 +1533,7 @@ ClearMem(life3dstruct * lp)
 					++count;
 			if (!count) {
 				(void) free((void *) lp->base[i]);
-				lp->base[i] = NULL;
+				lp->base[i] = (unsigned char *) NULL;
 			}
 		}
 }
@@ -1699,7 +1699,7 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
 	int         x, y, z;
-	char       *patptr = NULL;
+	char       *patptr = (char *) NULL;
 
 	if (filePattern) {
 		patptr = &filePattern[0];
@@ -1777,7 +1777,7 @@ SortList(life3dstruct * lp)
 	CellList   *ptr;
 
 	for (i = 0; i < NBUCKETS; ++i)
-		lp->buckethead[i] = lp->bucketend[i] = NULL;
+		lp->buckethead[i] = lp->bucketend[i] = (CellList *) NULL;
 
 	/* Calculate distances and re-arrange pointers to chain off buckets */
 	ptr = lp->ptrhead;
@@ -1800,11 +1800,12 @@ SortList(life3dstruct * lp)
 
 		if (lp->buckethead[dist] == NULL) {
 			lp->buckethead[dist] = lp->bucketend[dist] = ptr;
-			ptr->priority = NULL;
+			ptr->priority = (struct _CellList *) NULL;
 		} else {
 			lp->bucketend[dist]->priority = ptr;
 			lp->bucketend[dist] = ptr;
-			lp->bucketend[dist]->priority = NULL;
+			lp->bucketend[dist]->priority =
+				(struct _CellList *) NULL;
 		}
 		ptr = ptr->next;
 	}
@@ -2254,7 +2255,7 @@ release_life3d(ModeInfo * mi)
 				End3D(lp);
 		}
 		(void) free((void *) life3ds);
-		life3ds = NULL;
+		life3ds = (life3dstruct *) NULL;
 	}
 }
 
