@@ -43,12 +43,12 @@ static const char sccsid[] = "@(#)lightning.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_lightning
 
 ModeSpecOpt lightning_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   lightning_description =
 {"lightning", "init_lightning", "draw_lightning", "release_lightning",
- "refresh_lightning", "init_lightning", NULL, &lightning_opts,
+ "refresh_lightning", "init_lightning", (char *) NULL, &lightning_opts,
  10000, 1, 1, 1, 64, 0.6, "",
  "Shows Keith's fractal lightning bolts", 0, NULL};
 
@@ -115,7 +115,7 @@ typedef struct {
 	unsigned long color;
 } Storm;
 
-static Storm *Helga = NULL;
+static Storm *Helga = (Storm *) NULL;
 
 /*-------------------   function prototypes  ----------------------------*/
 
@@ -598,7 +598,7 @@ release_lightning(ModeInfo * mi)
 {
 	if (Helga != NULL) {
 		(void) free((void *) Helga);
-		Helga = NULL;
+		Helga = (Storm *) NULL;
 	}
 }
 
