@@ -82,7 +82,7 @@ ModeSpecOpt lisa_opts =
 #ifdef USE_MODULES
 ModStruct   lisa_description =
 {"lisa", "init_lisa", "draw_lisa", "release_lisa",
- "refresh_lisa", "change_lisa", NULL, &lisa_opts,
+ "refresh_lisa", "change_lisa", (char *) NULL, &lisa_opts,
  25000, 1, 256, -1, 64, 1.0, "",
  "Shows animated lisajous loops", 0, NULL};
 
@@ -133,7 +133,7 @@ typedef struct lisacontext_struct {
 	Bool        painted;
 } lisacons;
 
-static lisacons *Lisa = NULL;
+static lisacons *Lisa = (lisacons *) NULL;
 
 static lisafuncs Function[NUMSTDFUNCS] =
 {
@@ -179,7 +179,7 @@ free_lisa(lisacons *lc)
 			(void) free((void *) lc->lisajous[lctr].lastpoint);
 		}
 		(void) free((void *) lc->lisajous);
-		lc->lisajous = NULL;
+		lc->lisajous = (lisas *) NULL;
 	}
 }
 
@@ -541,7 +541,7 @@ release_lisa(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_lisa(&Lisa[screen]);
 		(void) free(Lisa);
-		Lisa = NULL;
+		Lisa = (lisacons *) NULL;
 	}
 }
 
