@@ -55,7 +55,7 @@ ModeSpecOpt lissie_opts =
 #ifdef USE_MODULES
 ModStruct   lissie_description =
 {"lissie", "init_lissie", "draw_lissie", "release_lissie",
- "refresh_lissie", "init_lissie", NULL, &lissie_opts,
+ "refresh_lissie", "init_lissie", (char *) NULL, &lissie_opts,
  10000, 1, 2000, -200, 64, 0.6, "",
  "Shows lissajous worms", 0, NULL};
 
@@ -105,7 +105,7 @@ typedef struct {
 	int         loopcount;
 } lissstruct;
 
-static lissstruct *lisses = NULL;
+static lissstruct *lisses = (lissstruct *) NULL;
 
 
 static void
@@ -235,7 +235,7 @@ init_lissie(ModeInfo * mi)
 	if (lp->nlissies < -MINLISSIES) {
 		if (lp->lissie) {
 			(void) free((void *) lp->lissie);
-			lp->lissie = NULL;
+			lp->lissie = (lissiestruct *) NULL;
 		}
 		lp->nlissies = NRAND(-lp->nlissies - MINLISSIES + 1) + MINLISSIES;
 	} else if (lp->nlissies < MINLISSIES)
@@ -294,7 +294,7 @@ release_lissie(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) lisses);
-		lisses = NULL;
+		lisses = (lissstruct *) NULL;
 	}
 }
 
