@@ -129,7 +129,7 @@ ModeSpecOpt loop_opts =
 #ifdef USE_MODULES
 ModStruct   loop_description =
 {"loop", "init_loop", "draw_loop", "release_loop",
- "refresh_loop", "init_loop", NULL, &loop_opts,
+ "refresh_loop", "init_loop", (char *) NULL, &loop_opts,
  100000, 5, 1600, -12, 64, 1.0, "",
  "Shows Langton's self-producing loops", 0, NULL};
 
@@ -219,7 +219,7 @@ typedef struct {
 	} shape;
 } loopstruct;
 
-static loopstruct *loops = NULL;
+static loopstruct *loops = (loopstruct *) NULL;
 
 #define TRANSITION(TT,V) V=TT&7;TT>>=3
 #define FINALTRANSITION(TT,V) V=TT&7
@@ -246,8 +246,9 @@ static loopstruct *loops = NULL;
 #define TABLE_OUT(C,R,T,L,B) ((TABLE(R,T,L,B)>>((C)*3))&7)
 #define HEX_TABLE_OUT(C,R,T,t,l,b,B) ((HEX_TABLE(R,T,t,l,b,B)>>((C)*3))&7)
 
-static unsigned int *table = NULL;	/* 8*8*8*8 = 2^12 = 2^3^4 = 4096 */
-  /* 8*8*8*8*8*8 = 2^18 = 2^3^6 = 262144 = too big? */
+static unsigned int *table = (unsigned int *) NULL;
+  /* square:  8*8*8*8     = 2^12 = 2^3^4 = 4096 */
+  /* hexagon: 8*8*8*8*8*8 = 2^18 = 2^3^6 = 262144 = too big? */
 
 static char plots[NEIGHBORKINDS] =
 {
@@ -924,11 +925,11 @@ free_loop(Display *display, loopstruct * lp)
 	}
 	if (lp->oldcells != NULL) {
 		(void) free((void *) lp->oldcells);
-		lp->oldcells = NULL;
+		lp->oldcells = (unsigned char *) NULL;
 	}
 	if (lp->newcells != NULL) {
 		(void) free((void *) lp->newcells);
-		lp->newcells = NULL;
+		lp->newcells = (unsigned char *) NULL;
 	}
 	free_list(lp);
 }
@@ -1020,7 +1021,7 @@ draw_state(ModeInfo * mi, int state)
 }
 
 static Bool
-init_table()
+init_table(void)
 {
 	if (table == NULL) {
 		int mult = 1;
@@ -1412,11 +1413,11 @@ release_loop(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_loop(MI_DISPLAY(mi), &loops[screen]);
 		(void) free((void *) loops);
-		loops = NULL;
+		loops = (loopstruct *) NULL;
 	}
 	if (table != NULL) {
 		(void) free((void *) table);
-		table = NULL;
+		table = (unsigned int *) NULL;
 	}
 }
 
@@ -1547,7 +1548,7 @@ init_loop(ModeInfo * mi)
 
 	if (lp->oldcells != NULL) {
 		(void) free((void *) lp->oldcells);
-		lp->oldcells = NULL;
+		lp->oldcells = (unsigned char *) NULL;
 	}
 	if ((lp->oldcells = (unsigned char *) calloc(lp->bncols * lp->bnrows,
 			sizeof (unsigned char))) == NULL) {
@@ -1556,7 +1557,7 @@ init_loop(ModeInfo * mi)
 	}
 	if (lp->newcells != NULL) {
 		(void) free((void *) lp->newcells);
-		lp->newcells = NULL;
+		lp->newcells = (unsigned char *) NULL;
 	}
 	if ((lp->newcells = (unsigned char *) calloc(lp->bncols * lp->bnrows,
 			sizeof (unsigned char))) == NULL) {
