@@ -72,6 +72,11 @@ static const char sccsid[] = "@(#)matrix.c	5.00 2000/11/01 xlockmore";
 #include "vms_x_fix.h"
 #endif
 
+/*-
+ * due to a Bug/feature in VMS X11/Intrinsic.h has to be placed before xlock.
+ * otherwise caddr_t is not defined correctly
+ */
+
 #include <X11/Intrinsic.h>
 
 #ifdef STANDALONE
@@ -91,7 +96,7 @@ ModeSpecOpt matrix_opts =
 #ifdef USE_MODULES
 ModStruct   matrix_description =
 {"matrix", "init_matrix", "draw_matrix", "release_matrix",
- "refresh_matrix", "change_matrix", NULL, &matrix_opts,
+ "refresh_matrix", "change_matrix", (char *) NULL, &matrix_opts,
  1000, 1, 1, 1, 64, 1.0, "",
  "Shows the Matrix", 0, NULL};
 #endif
@@ -368,7 +373,7 @@ static const unsigned char katakana_bits[] = {
 /*
  * state of the Matrix
  */
-static matrix_t *matrix = NULL;
+static matrix_t *matrix = (matrix_t *) NULL;
 
 
 /* NAME: new_column
@@ -457,7 +462,7 @@ free_matrix(Display *display, matrix_t *mp)
 	  }
 
 	  (void) free((void *) mp->columns);
-	  mp->columns = NULL;
+	  mp->columns = (column_t *) NULL;
 	}
 
 	if (mp->kana[0]) {
@@ -705,7 +710,7 @@ void release_matrix(ModeInfo *mi)
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 		free_matrix(MI_DISPLAY(mi), &matrix[screen]);
 	  (void) free((void *) matrix);
-	  matrix = NULL;
+	  matrix = (matrix_t *) NULL;
   }
 }
 
