@@ -93,7 +93,7 @@ ModeSpecOpt maze_opts =
 #ifdef USE_MODULES
 ModStruct   maze_description =
 {"maze", "init_maze", "draw_maze", "release_maze",
- "refresh_maze", "init_maze", NULL, &maze_opts,
+ "refresh_maze", "init_maze", (char *) NULL, &maze_opts,
  1000, 1, 3000, -40, 64, 1.0, "",
  "Shows a random maze and a depth first search solution", 0, NULL};
 
@@ -164,7 +164,7 @@ typedef struct {
 	int         time;
 } mazestruct;
 
-static mazestruct *mazes = NULL;
+static mazestruct *mazes = (mazestruct *) NULL;
 
 static void
 draw_wall(ModeInfo * mi, int i, int j, int dir)
@@ -278,19 +278,19 @@ free_path(mazestruct * mp)
 {
 	if (mp->maze) {
 		(void) free((void *) mp->maze);
-		mp->maze = NULL;
+		mp->maze = (unsigned short *) NULL;
 	}
 	if (mp->move_list) {
 		(void) free((void *) mp->move_list);
-		mp->move_list = NULL;
+		mp->move_list = (paths *) NULL;
 	}
 	if (mp->save_path) {
 		(void) free((void *) mp->save_path);
-		mp->save_path = NULL;
+		mp->save_path = (paths *) NULL;
 	}
 	if (mp->path) {
 		(void) free((void *) mp->path);
-		mp->path = NULL;
+		mp->path = (paths *) NULL;
 	}
 }
 
@@ -903,7 +903,7 @@ release_maze(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_maze(MI_DISPLAY(mi), &mazes[screen]);
 		(void) free((void *) mazes);
-		mazes = NULL;
+		mazes = (mazestruct *) NULL;
 	}
 }
 
