@@ -47,12 +47,12 @@ static const char sccsid[] = "@(#)mountain.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_mountain
 
 ModeSpecOpt mountain_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   mountain_description =
 {"mountain", "init_mountain", "draw_mountain", "release_mountain",
- "refresh_mountain", "init_mountain", NULL, &mountain_opts,
+ "refresh_mountain", "init_mountain", (char *) NULL, &mountain_opts,
  1000, 30, 4000, 1, 64, 1.0, "",
  "Shows Papo's mountain range", 0, NULL};
 
@@ -79,7 +79,7 @@ typedef struct {
 	GC          stippledGC;
 } mountainstruct;
 
-static mountainstruct *mountains = NULL;
+static mountainstruct *mountains = (mountainstruct *) NULL;
 
 static void
 spread(int  (*m)[50], int x, int y)
@@ -270,7 +270,7 @@ release_mountain(ModeInfo * mi)
 				XFreeGC(MI_DISPLAY(mi), mp->stippledGC);
 		}
 		(void) free((void *) mountains);
-		mountains = NULL;
+		mountains = (mountainstruct *) NULL;
 	}
 }
 
