@@ -66,12 +66,12 @@ static const char sccsid[] = "@(#)munch.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_munch
 
 ModeSpecOpt munch_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   munch_description =
 {"munch", "init_munch", "draw_munch", "release_munch",
- "init_munch", "init_munch", NULL, &munch_opts,
+ "init_munch", "init_munch", (char *) NULL, &munch_opts,
  5000, 1, 7, 1, 64, 1.0, "",
  "Shows munching squares", 0, NULL};
 
@@ -99,7 +99,7 @@ typedef struct {
 	int         grav;
 } munchstruct;
 
-static munchstruct *munches = NULL;
+static munchstruct *munches = (munchstruct *) NULL;
 
 static void
 munchBit(ModeInfo * mi, int width,	/* pixels */
@@ -260,7 +260,7 @@ release_munch(ModeInfo * mi)
 				XFreeGC(MI_DISPLAY(mi), mp->gc);
 		}
 		(void) free((void *) munches);
-		munches = NULL;
+		munches = (munchstruct *) NULL;
 	}
 }
 
