@@ -76,7 +76,7 @@ ModeSpecOpt nose_opts =
 #ifdef USE_MODULES
 ModStruct   nose_description =
 {"nose", "init_nose", "draw_nose", "release_nose",
- "refresh_nose", "init_nose", NULL, &nose_opts,
+ "refresh_nose", "init_nose", (char *) NULL, &nose_opts,
  100000, 1, 1, 1, 64, 1.0, "",
  "Shows a man with a big nose runs around spewing out messages", 0, NULL};
 
@@ -137,7 +137,7 @@ typedef struct {
 	Pixmap      position[PIXMAPS];
 } nosestruct;
 
-static nosestruct *noses = NULL;
+static nosestruct *noses = (nosestruct *) NULL;
 
 #ifdef USE_MB
 static XFontSet mode_font = None;
@@ -892,7 +892,7 @@ release_nose(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_nose(MI_DISPLAY(mi), &noses[screen]);
 		(void) free((void *) noses);
-		noses = NULL;
+		noses = (nosestruct *) NULL;
 	}
 	if (mode_font != None) {
 #ifdef USE_MB
