@@ -62,7 +62,7 @@ ModeSpecOpt pacman_opts =
 #ifdef USE_MODULES
 ModStruct   pacman_description =
 {"pacman", "init_pacman", "draw_pacman", "release_pacman",
- "refresh_pacman", "init_pacman", NULL, &pacman_opts,
+ "refresh_pacman", "init_pacman", (char *) NULL, &pacman_opts,
  100000, 10, 1, 0, 64, 1.0, "",
  "Shows Pacman(tm)", 0, NULL};
 
@@ -118,7 +118,7 @@ typedef struct {
 	Pixmap      pacmanPixmap[4][MAXMOUTH];
 } pacmangamestruct;
 
-static pacmangamestruct *pacmangames = NULL;
+static pacmangamestruct *pacmangames = (pacmangamestruct *) NULL;
 
 static void
 free_pacman(Display *display, pacmangamestruct *pp)
@@ -127,12 +127,12 @@ free_pacman(Display *display, pacmangamestruct *pp)
 
 	if (pp->ghosts != NULL) {
 		(void) free((void *) pp->ghosts);
-		pp->ghosts = NULL;
+		pp->ghosts = (beingstruct *) NULL;
 	}
 #ifdef DEFUNCT
 	if (pp->eaten != NULL) {
 		(void) free((void *) pp->eaten);
-		pp->eaten = NULL;
+		pp->eaten = (unsigned int *) NULL;
 	}
 #endif
 	if (pp->stippledGC != None) {
@@ -623,7 +623,7 @@ init_pacman(ModeInfo * mi)
 		/* if pp->nghosts is random ... the size can change */
 		if (pp->ghosts != NULL) {
 			(void) free((void *) pp->ghosts);
-			pp->ghosts = NULL;
+			pp->ghosts = (beingstruct *) NULL;
 		}
 		pp->nghosts = NRAND(-pp->nghosts - MINGHOSTS + 1) + MINGHOSTS;
 	} else if (pp->nghosts < MINGHOSTS)
@@ -804,7 +804,7 @@ release_pacman(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_pacman(MI_DISPLAY(mi), &pacmangames[screen]);
 		(void) free((void *) pacmangames);
-		pacmangames = NULL;
+		pacmangames = (pacmangamestruct *) NULL;
 	}
 }
 
