@@ -48,7 +48,7 @@ If one of these are hit penrose will reinitialize.
  * untiled area.  Whenever this is in danger of happening, we just
  * do not add the tile, hoping for a better random choice the next
  * time.  Second, when choosing a vertex randomly, we will take
- * one that lies withing the viewport if available.  If this seems to
+ * one that lies within the viewport if available.  If this seems to
  * cause enclosures in the forced rule case, we will allow invisible
  * vertices to be chosen.
  *
@@ -106,7 +106,7 @@ ModeSpecOpt penrose_opts =
 #ifdef USE_MODULES
 ModStruct   penrose_description =
 {"penrose", "init_penrose", "draw_penrose", "release_penrose",
- "init_penrose", "init_penrose", NULL, &penrose_opts,
+ "init_penrose", "init_penrose", (char *) NULL, &penrose_opts,
  10000, 1, 1, -40, 64, 1.0, "",
  "Shows Penrose's quasiperiodic tilings", 0, NULL};
 
@@ -253,8 +253,7 @@ typedef struct {
 	Bool        ammann;
 } tiling_c;
 
-static tiling_c *tilings;	/* = {0} */
-
+static tiling_c *tilings = (tiling_c *) NULL;
 
 /* The tiles are listed in counterclockwise order. */
 typedef struct {
@@ -401,7 +400,7 @@ free_penrose(tiling_c * tp)
 		fp1 = fp1->next;
 		(void) free((void *) fp2);
 	} while (fp1 != tp->fringe.nodes);
-	tp->fringe.nodes = NULL;
+	tp->fringe.nodes = (fringe_node_c *) NULL;
 	for (lp1 = tp->forced.first; lp1 != 0;) {
 		lp2 = lp1;
 		lp1 = lp1->next;
@@ -854,7 +853,7 @@ fringe_changes(ModeInfo * mi, fringe_node_c * vertex,
 	       fringe_node_c ** right, fringe_node_c ** far,
 	       fringe_node_c ** left)
 {
-	fringe_node_c *v, *f = NULL;
+	fringe_node_c *v, *f = (fringe_node_c *) NULL;
 	unsigned    result = FC_NEW_FAR;	/* We clear this later if necessary. */
 
 	if (far)
@@ -974,9 +973,9 @@ add_tile(ModeInfo * mi,
 	tiling_c   *tp = &tilings[MI_SCREEN(mi)];
 
 	fringe_node_c
-		*left = NULL,
-		*right = NULL,
-		*far = NULL,
+		*left = (fringe_node_c *) NULL,
+		*right = (fringe_node_c *) NULL,
+		*far = (fringe_node_c *) NULL,
 		*node;
 	unsigned    fc = fringe_changes(mi, vertex, side, vtype, &right, &far, &left);
 
@@ -1321,7 +1320,7 @@ release_penrose(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_penrose(&tilings[screen]);
 		(void) free((void *) tilings);
-		tilings = NULL;
+		tilings = (tiling_c *) NULL;
 	}
 }
 
