@@ -58,12 +58,12 @@ static const char sccsid[] = "@(#)puzzle.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_puzzle
 
 ModeSpecOpt puzzle_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   puzzle_description =
 {"puzzle", "init_puzzle", "draw_puzzle", "release_puzzle",
- "init_puzzle", "init_puzzle", NULL, &puzzle_opts,
+ "init_puzzle", "init_puzzle", (char *) NULL, &puzzle_opts,
  10000, 250, 1, 1, 64, 1.0, "",
  "Shows a puzzle being scrambled and then solved", 0, NULL};
 
@@ -120,7 +120,7 @@ typedef struct {
 #endif
 } puzzlestruct;
 
-static puzzlestruct *puzzles = NULL;
+static puzzlestruct *puzzles = (puzzlestruct *) NULL;
 
 static void
 free_stuff(Display * display, puzzlestruct * pp)
@@ -141,16 +141,16 @@ free_puzzle(Display * display, puzzlestruct * pp)
 {
 	if (pp->fixbuff != NULL) {
 		(void) free((void *) pp->fixbuff);
-		pp->fixbuff = NULL;
+		pp->fixbuff = (int *) NULL;
 	}
 	if (pp->bufferBox != None) {
 		XFreePixmap(display, pp->bufferBox);
 		pp->bufferBox = None;
 	}
 	free_stuff(display, pp);
-	if (pp->logo) {
+	if (pp->logo != None) {
 		destroyImage(&pp->logo, &pp->graphics_format);
-		pp->logo = NULL;
+		pp->logo = None;
 	}
 }
 
@@ -496,7 +496,7 @@ init_puzzle(ModeInfo * mi)
 	if (pp->excount < 0) {
 		if (pp->fixbuff != NULL) {
 			(void) free((void *) pp->fixbuff);
-			pp->fixbuff = NULL;
+			pp->fixbuff = (int *) NULL;
 		}
 		pp->excount = NRAND(-pp->excount) + 1;
 	}
@@ -656,7 +656,7 @@ release_puzzle(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_puzzle(MI_DISPLAY(mi), &puzzles[screen]);
 		(void) free((void *) puzzles);
-		puzzles = NULL;
+		puzzles = (puzzlestruct *) NULL;
 	}
 #ifdef NUMBERED
 	if (mode_font != None) {
