@@ -66,7 +66,7 @@ ModeSpecOpt pyro_opts =
 #ifdef USE_MODULES
 ModStruct   pyro_description =
 {"pyro", "init_pyro", "draw_pyro", "release_pyro",
- "refresh_pyro", "init_pyro", NULL, &pyro_opts,
+ "refresh_pyro", "init_pyro", (char *) NULL, &pyro_opts,
  15000, 100, 1, -3, 64, 1.0, "",
  "Shows fireworks", 0, NULL};
 
@@ -164,7 +164,7 @@ typedef struct {
 static void shootup(ModeInfo * mi, pyrostruct * pp, rocket * rp);
 static void burst(ModeInfo * mi, pyrostruct * pp, rocket * rp);
 
-static pyrostruct *pyros = NULL;
+static pyrostruct *pyros = (pyrostruct *) NULL;
 static int  orig_p_ignite;
 static int  just_started = True;	/* Greet the user right away */
 
@@ -482,7 +482,7 @@ init_pyro(ModeInfo * mi)
 	if (pp->nrockets < -MINROCKETS) {
 		if (pp->rockq) {
 			(void) free((void *) pp->rockq);
-			pp->rockq = NULL;
+			pp->rockq = (rocket *) NULL;
 		}
 		pp->nrockets = NRAND(-pp->nrockets - MINROCKETS + 1) + MINROCKETS;
 	} else if (pp->nrockets < MINROCKETS)
@@ -599,7 +599,7 @@ release_pyro(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) pyros);
-		pyros = NULL;
+		pyros = (pyrostruct *) NULL;
 	}
 }
 
