@@ -56,26 +56,32 @@ static const char sccsid[] = "@(#)qix.c	5.00 2000/11/01 xlockmore";
 
 #define DEF_COMPLETE  "False"
 #define DEF_KALEID  "False"
+#define DEF_SOLID  "False"
 
 static Bool complete;
 static Bool kaleid;
+static Bool solid;
 
 static XrmOptionDescRec opts[] =
 {
 	{(char *) "-complete", (char *) ".qix.complete", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+complete", (char *) ".qix.complete", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-kaleid", (char *) ".qix.kaleid", XrmoptionNoArg, (caddr_t) "on"},
-	{(char *) "+kaleid", (char *) ".qix.kaleid", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "+kaleid", (char *) ".qix.kaleid", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-solid", (char *) ".qix.solid", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+solid", (char *) ".qix.solid", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
       {(caddr_t *) & complete, (char *) "complete", (char *) "Complete", (char *) DEF_COMPLETE, t_Bool},
-	{(caddr_t *) & kaleid, (char *) "kaleid", (char *) "Kaleid", (char *) DEF_KALEID, t_Bool}
+	{(caddr_t *) & kaleid, (char *) "kaleid", (char *) "Kaleid", (char *) DEF_KALEID, t_Bool},
+	{(caddr_t *) & solid, (char *) "solid", (char *) "Solid", (char *) DEF_SOLID, t_Bool}
 };
 static OptionStruct desc[] =
 {
 	{(char *) "-/+complete", (char *) "turn on/off complete morphing graph"},
-	{(char *) "-/+kaleid", (char *) "turn on/off complete kaleidoscope"}
+	{(char *) "-/+kaleid", (char *) "turn on/off complete kaleidoscope"},
+	{(char *) "-/+solid", (char *) "turn on/off fills"}
 };
 
 ModeSpecOpt qix_opts =
@@ -84,7 +90,7 @@ ModeSpecOpt qix_opts =
 #ifdef USE_MODULES
 ModStruct   qix_description =
 {"qix", "init_qix", "draw_qix", "release_qix",
- "refresh_qix", "init_qix", NULL, &qix_opts,
+ "refresh_qix", "init_qix", (char *) NULL, &qix_opts,
  30000, -5, 32, 1, 64, 1.0, "",
  "Shows spinning lines a la Qix(tm)", 0, NULL};
 
@@ -111,12 +117,11 @@ typedef struct {
 	int         width, height, mid, midx, midy;
 	int         nlines, linecount;
 	int         redrawing, redrawpos;
-	XPoint     *lineq;
-	Bool        complete;
-	Bool        kaleid;
+	XPoint     *lineq, *points;
+	Bool        complete, kaleid, solid;
 } qixstruct;
 
-static qixstruct *qixs = NULL;
+static qixstruct *qixs = (qixstruct *) NULL;
 
 #define check_bounds(qp, val, del, min, max)				\
 {								\
@@ -132,15 +137,19 @@ free_qix(qixstruct *qp)
 {
 	if (qp->lineq != NULL) {
 		(void) free((void *) qp->lineq);
-		qp->lineq = NULL;
+		qp->lineq = (XPoint *) NULL;
+	}
+	if (qp->points != NULL) {
+		(void) free((void *) qp->points);
+		qp->points = (XPoint *) NULL;
 	}
 	if (qp->delta != NULL) {
 		(void) free((void *) qp->delta);
-		qp->delta = NULL;
+		qp->delta = (XPoint *) NULL;
 	}
 	if (qp->position != NULL) {
 		(void) free((void *) qp->position);
-		qp->position = NULL;
+		qp->position = (XPoint *) NULL;
 	}
 }
 
@@ -182,7 +191,7 @@ init_qix(ModeInfo * mi)
 		qp->npoints = MINPOINTS;
 
 	if (MI_IS_FULLRANDOM(mi))
-		qp->complete = (Bool) (LRAND() & 1);
+		qp->complete = (Bool) (!NRAND(4));
 	else
 		qp->complete = complete;
 
@@ -190,10 +199,18 @@ init_qix(ModeInfo * mi)
 		qp->kaleid = False;
 	} else {
 		if (MI_IS_FULLRANDOM(mi))
-			qp->kaleid = (Bool) (LRAND() & 1);
+			qp->kaleid = (Bool) (!NRAND(3));
 		else
 			qp->kaleid = kaleid;
 	}
+	if (qp->complete || qp->kaleid) {
+		qp->solid = False;
+	} else {
+		if (MI_IS_FULLRANDOM(mi))
+			qp->solid = (Bool) (LRAND() & 1);
+		else
+			qp->solid = solid;
+	}
 	if (qp->delta)
 		(void) free((void *) qp->delta);
 	if (qp->position)
@@ -227,7 +244,11 @@ init_qix(ModeInfo * mi)
 	}
 	if (qp->lineq) {
 		(void) free((void *) qp->lineq);
-		qp->lineq = NULL;
+		qp->lineq = (XPoint *) NULL;
+	}
+	if (qp->points) {
+		(void) free((void *) qp->points);
+		qp->points = (XPoint *) NULL;
 	}
 	if (!qp->kaleid) {
 		if ((qp->lineq = (XPoint *) malloc(qp->nlines *
@@ -237,6 +258,13 @@ init_qix(ModeInfo * mi)
 		}
 		for (i = 0; i < qp->nlines; i++)
 			qp->lineq[i].x = qp->lineq[i].y = -1;	/* move initial point off screen */
+		if (qp->solid) {
+			if ((qp->points = (XPoint *) malloc(2 * qp->nlines *
+					sizeof (XPoint))) == NULL) {
+				free_qix(qp);
+				return;
+			}
+		}
 	}
 	MI_CLEARWINDOW(mi);
 }
@@ -247,12 +275,14 @@ draw_qix(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	GC          gc = MI_GC(mi);
 	qixstruct  *qp = &qixs[MI_SCREEN(mi)];
-	int         i, j, k, l;
+	int         i, j, k, l, prev;
 
 	qp->first = (qp->last + qp->npoints) % qp->nlines;
+	prev = (qp->last - qp->npoints + qp->nlines) % qp->nlines;
 
 	MI_IS_DRAWN(mi) = True;
 
+ 
 	for (i = 0; i < qp->npoints; i++) {
 		qp->position[i].x += qp->delta[i].x;
 		qp->position[i].y += qp->delta[i].y;
@@ -272,19 +302,39 @@ draw_qix(ModeInfo * mi)
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	if (qp->complete && qp->npoints > 3) {
 		for (i = 0; i < qp->npoints - 1; i++)
-			for (j = i + 1; j < qp->npoints; j++)
+			for (j = i + 1; j < qp->npoints; j++) {
 				XDrawLine(display, MI_WINDOW(mi), gc,
-					  qp->lineq[qp->first + i].x, qp->lineq[qp->first + i].y,
-					  qp->lineq[qp->first + j].x, qp->lineq[qp->first + j].y);
+					qp->lineq[qp->first + i].x,
+					qp->lineq[qp->first + i].y,
+					qp->lineq[qp->first + j].x,
+					qp->lineq[qp->first + j].y);
+			}
 	} else if (!qp->kaleid) {
-		for (i = 1; i < qp->npoints + ((qp->npoints == 2) ? -1 : 0); i++)
+		if (qp->solid) {
+			if (qp->lineq[qp->last].x != -1 ||
+			    qp->lineq[qp->last].y != -1) {
+			  for (i = 0; i < qp->npoints; i++) {
+			    qp->points[i] = qp->lineq[qp->last + i];
+			    qp->points[i + qp->npoints] =
+			      qp->lineq[qp->first + qp->npoints - 1 - i];
+			  }
+			  XFillPolygon(display, MI_WINDOW(mi), gc,
+			    qp->points, 2 * qp->npoints,
+			    Complex, CoordModeOrigin);
+			}
+		} else {
+			for (i = 1; i < qp->npoints +
+			    ((qp->npoints == 2) ? -1 : 0); i++)
+			  XDrawLine(display, MI_WINDOW(mi), gc,
+			    qp->lineq[qp->first + i - 1].x,
+			    qp->lineq[qp->first + i - 1].y,
+			    qp->lineq[qp->first + i].x,
+			    qp->lineq[qp->first + i].y);
 			XDrawLine(display, MI_WINDOW(mi), gc,
-				  qp->lineq[qp->first + i - 1].x, qp->lineq[qp->first + i - 1].y,
-				  qp->lineq[qp->first + i].x, qp->lineq[qp->first + i].y);
-		XDrawLine(display, MI_WINDOW(mi), gc,
 			  qp->lineq[qp->first].x, qp->lineq[qp->first].y,
 			  qp->lineq[qp->first + qp->npoints - 1].x,
 			  qp->lineq[qp->first + qp->npoints - 1].y);
+		}
 	}
 	if (MI_NPIXELS(mi) > 2) {
 		XSetForeground(display, gc, MI_PIXEL(mi, qp->pix));
@@ -350,12 +400,30 @@ draw_qix(ModeInfo * mi)
 			MI_CLEARWINDOW(mi);
 		}
 	} else {
-		for (i = 1; i < qp->npoints + ((qp->npoints == 2) ? -1 : 0); i++)
+		if (qp->solid) {
+			if (qp->lineq[prev].x != -1 || 
+			    qp->lineq[prev].y != -1) {
+			  for (i = 0; i < qp->npoints; i++) {
+			    qp->points[i] = qp->lineq[prev + i];
+			    qp->points[i + qp->npoints] =
+			      qp->position[qp->npoints - 1 - i];
+			  }
+			  XFillPolygon(display, MI_WINDOW(mi), gc,
+			    qp->points, 2 * qp->npoints,
+			    Complex, CoordModeOrigin);
+			}
+		} else {
+			for (i = 1; i < qp->npoints + ((qp->npoints == 2) ? -1 : 0); i++)
+				XDrawLine(display, MI_WINDOW(mi), gc,
+					qp->position[i - 1].x,
+					qp->position[i - 1].y,
+					qp->position[i].x,
+					qp->position[i].y);
 			XDrawLine(display, MI_WINDOW(mi), gc,
-				qp->position[i - 1].x, qp->position[i - 1].y,
-				  qp->position[i].x, qp->position[i].y);
-		XDrawLine(display, MI_WINDOW(mi), gc, qp->position[0].x, qp->position[0].y,
-			  qp->position[qp->npoints - 1].x, qp->position[qp->npoints - 1].y);
+				qp->position[0].x, qp->position[0].y,
+				qp->position[qp->npoints - 1].x,
+				qp->position[qp->npoints - 1].y);
+		}
 	}
 
 	if (!qp->kaleid)
@@ -368,21 +436,43 @@ draw_qix(ModeInfo * mi)
 		}
 	if (qp->redrawing) {
 		for (i = 0; i < REDRAWSTEP; i++) {
+			int jold = (qp->last - qp->redrawpos + qp->nlines - qp->npoints) % qp->nlines;
+
 			j = (qp->first - qp->redrawpos + qp->nlines - qp->npoints) % qp->nlines;
 			if (qp->complete && qp->npoints > 3) {
 				for (k = 0; k < qp->npoints - 1; k++)
 					for (l = k + 1; l < qp->npoints; l++)
-						XDrawLine(display, MI_WINDOW(mi), gc,
-							  qp->lineq[j + k].x, qp->lineq[j + k].y,
-							  qp->lineq[j + l].x, qp->lineq[j + l].y);
+					  XDrawLine(display, MI_WINDOW(mi), gc,
+					    qp->lineq[j + k].x,
+					    qp->lineq[j + k].y,
+					    qp->lineq[j + l].x,
+					    qp->lineq[j + l].y);
 			} else if (!qp->kaleid) {
-				for (k = 1; k < qp->npoints + ((qp->npoints == 2) ? -1 : 0); k++)
-					XDrawLine(display, MI_WINDOW(mi), gc,
-						  qp->lineq[j + k - 1].x, qp->lineq[j + k - 1].y,
-						  qp->lineq[j + k].x, qp->lineq[j + k].y);
-				XDrawLine(display, MI_WINDOW(mi), gc,
-					  qp->lineq[j].x, qp->lineq[j].y,
-					  qp->lineq[j + qp->npoints - 1].x, qp->lineq[j + qp->npoints - 1].y);
+				if (qp->solid) {
+				  if (qp->lineq[jold].x != -1 ||
+				      qp->lineq[jold].y != -1) {
+				    for (i = 0; i < qp->npoints; i++) {
+				      qp->points[i] = qp->lineq[jold + i];
+				      qp->points[i + qp->npoints] =
+				        qp->lineq[j + qp->npoints - 1 - i];
+				    }
+				    XFillPolygon(display, MI_WINDOW(mi), gc,
+				      qp->points, 2 * qp->npoints,
+				      Complex, CoordModeOrigin);
+				  }
+				} else {
+				  for (k = 1; k < qp->npoints +
+				      ((qp->npoints == 2) ? -1 : 0); k++)
+				    XDrawLine(display, MI_WINDOW(mi), gc,
+				      qp->lineq[j + k - 1].x,
+				      qp->lineq[j + k - 1].y,
+				      qp->lineq[j + k].x,
+				      qp->lineq[j + k].y);
+				  XDrawLine(display, MI_WINDOW(mi), gc,
+				    qp->lineq[j].x, qp->lineq[j].y,
+				    qp->lineq[j + qp->npoints - 1].x,
+				    qp->lineq[j + qp->npoints - 1].y);
+				}
 			}
 			qp->redrawpos += qp->npoints;
 			if (qp->redrawpos >= qp->nlines - qp->npoints) {
@@ -402,7 +492,7 @@ release_qix(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_qix(&qixs[screen]);
 		(void) free((void *) qixs);
-		qixs = NULL;
+		qixs = (qixstruct *) NULL;
 	}
 }
 
