@@ -91,7 +91,7 @@ ModeSpecOpt random_opts =
 #ifdef USE_MODULES
 ModStruct   random_description =
 {"random", "init_random", "draw_random", "release_random",
- "refresh_random", "change_random", NULL, &random_opts,
+ "refresh_random", "change_random", (char *) NULL, &random_opts,
  1, 1, 1, 1, 64, 1.0, "",
 #ifdef MODE_run
 #ifdef MODE_bomb
@@ -583,6 +583,9 @@ static char fractal_modes[][MAXMODECHARS] =
 
 static char geometry_modes[][MAXMODECHARS] =
 {
+#ifdef MODE_apollonian
+	"apollonian",
+#endif
 #ifdef MODE_braid
 	"braid",
 #endif
@@ -679,7 +682,7 @@ static randomstruct *randoms;
 static int
 pickMode(void)
 {
-	static int *mode_indexes = NULL;
+	static int *mode_indexes = (int *) NULL;
 	static int  mode_count = 0;
 	static int  last_mode = -1, last_index = -1;
 	int         mode, i;
@@ -746,7 +749,7 @@ strpmtok(int *sign, char *str)
 				continue;
 			case 0:
 				loc = p;
-				return NULL;
+				return (char *) NULL;
 		}
 		break;
 	}
