@@ -56,7 +56,7 @@ ModeSpecOpt rotor_opts =
 #ifdef USE_MODULES
 ModStruct   rotor_description =
 {"rotor", "init_rotor", "draw_rotor", "release_rotor",
- "refresh_rotor", "init_rotor", NULL, &rotor_opts,
+ "refresh_rotor", "init_rotor", (char *) NULL, &rotor_opts,
  100, 4, 100, -6, 64, 0.3, "",
  "Shows Tom's Roto-Rooter", 0, NULL};
 
@@ -104,18 +104,18 @@ typedef struct {
 	int         linewidth;
 } rotorstruct;
 
-static rotorstruct *rotors = NULL;
+static rotorstruct *rotors = (rotorstruct *) NULL;
 
 static void
 free_rotor(rotorstruct *rp)
 {
 	if (rp->elements != NULL) {
 		(void) free((void *) rp->elements);
-		rp->elements = NULL;
+		rp->elements = (elem *) NULL;
 	}
 	if (rp->save != NULL) {
 		(void) free((void *) rp->save);
-		rp->save = NULL;
+		rp->save = (XPoint *) NULL;
 	}
 }
 
@@ -169,7 +169,7 @@ init_rotor(ModeInfo * mi)
 			rp->num = NRAND(-rp->num) + 1;
 			if (rp->elements != NULL) {
 				(void) free((void *) rp->elements);
-				rp->elements = NULL;
+				rp->elements = (elem *) NULL;
 			}
 		}
 		if (rp->elements == NULL)
@@ -374,7 +374,7 @@ release_rotor(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_rotor(&rotors[screen]);
 		(void) free((void *) rotors);
-		rotors = NULL;
+		rotors = (rotorstruct *) NULL;
 	}
 }
 
