@@ -74,7 +74,7 @@ ModeSpecOpt run_opts =
 #ifdef USE_MODULES
 ModStruct   run_description =
 {"run", "init_run", "draw_run", "release_run",
- "refresh_run", "init_run", NULL, &run_opts,
+ "refresh_run", "init_run", (char *) NULL, &run_opts,
  3000000, 1, 1, 1, 64, 1.0, "",
  "Shows another xprogram", 0, NULL};
 
@@ -85,7 +85,7 @@ typedef struct {
 	int width, height;
 } runstruct;
 
-static runstruct *runs = NULL;
+static runstruct *runs = (runstruct *) NULL;
 
 void
 init_run(ModeInfo * mi)
@@ -174,7 +174,7 @@ release_run(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) runs);
-		runs = NULL;
+		runs = (runstruct *) NULL;
         }
 }
 
