@@ -2,7 +2,7 @@
 /* shape --- basic in your face shapes */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)shape.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)shape.c	5.00 2000/11/01 xlockmore";
 
 #endif
 
@@ -22,15 +22,16 @@ static const char sccsid[] = "@(#)shape.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 12-Mar-98: Got the idea for shadow from looking at xscreensaver web page.
- * 10-May-97: Compatible with xscreensaver
- * 03-Nov-95: formerly rect.c
- * 11-Aug-95: slight change to initialization of pixmaps
- * 27-Jun-95: added ellipses
- * 27-Feb-95: patch for VMS
- * 29-Sep-94: multidisplay bug fix <epstein_caleb@jpmorgan.com>
- * 15-Jul-94: xlock version David Bagley <bagleyd@tux.org>
- * 1992:      xscreensaver version Jamie Zawinski <jwz@jwz.org>
+ * 01-Nov-2000: Allocation checks
+ * 12-Mar-1998: Got the idea for shadow from looking at xscreensaver web page.
+ * 10-May-1997: Compatible with xscreensaver
+ * 03-Nov-1995: formerly rect.c
+ * 11-Aug-1995: slight change to initialization of pixmaps
+ * 27-Jun-1995: added ellipses
+ * 27-Feb-1995: patch for VMS
+ * 29-Sep-1994: multidisplay bug fix <epstein_caleb@jpmorgan.com>
+ * 15-Jul-1994: xlock version David Bagley <bagleyd@tux.org>
+ * 1992: xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
@@ -130,7 +131,7 @@ ModeSpecOpt shape_opts =
 #ifdef USE_MODULES
 ModStruct   shape_description =
 {"shape", "init_shape", "draw_shape", "release_shape",
- "refresh_shape", "init_shape", NULL, &shape_opts,
+ "refresh_shape", "init_shape", (char *) NULL, &shape_opts,
  10000, 100, 256, 1, 64, 1.0, "",
  "Shows overlaying rectangles, ellipses, and triangles", 0, NULL};
 
@@ -154,8 +155,9 @@ ModStruct   shape_description =
 #include "bitmaps/vlines2.xbm"
 #include "bitmaps/vlines3.xbm"
 #define SHAPEBITS(n,w,h)\
-  sp->pixmaps[sp->init_bits++]=\
-		XCreateBitmapFromData(display,window,(char *)n,w,h)
+  if ((sp->pixmaps[sp->init_bits]=\
+  XCreateBitmapFromData(display,window,(char *)n,w,h))==None){\
+  free_shape(display,sp); return;} else {sp->init_bits++;}
 
 typedef struct {
 	int         width;
@@ -172,7 +174,17 @@ typedef struct {
 	Pixmap      pixmaps[NBITS];
 } shapestruct;
 
-static shapestruct *shapes = NULL;
+static shapestruct *shapes = (shapestruct *) NULL;
+
+static void
+free_shape(Display *display, shapestruct *sp)
+{
+	int         bits;
+
+	for (bits = 0; bits < sp->init_bits; bits++)
+		XFreePixmap(display, sp->pixmaps[bits]);
+	sp->init_bits = 0;
+}
 
 void
 init_shape(ModeInfo * mi)
@@ -251,17 +263,19 @@ draw_shape(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	GC          gc = MI_GC(mi);
-	shapestruct *sp = &shapes[MI_SCREEN(mi)];
 	int         shape, i;
 	XPoint      shade_offset;
+	shapestruct *sp;
+
+	if (shapes == NULL)
+		return;
+	sp = &shapes[MI_SCREEN(mi)];
+	if (sp->stipple && !sp->init_bits)
+		return;
 
 	MI_IS_DRAWN(mi) = True;
-
 	shade_offset.x = 0;
 	shade_offset.y = 0;
-	if (sp->stipple)
-		if (!sp->init_bits)
-			return;
 
 	if (sp->stipple) {
 		XSetBackground(display, gc, (MI_NPIXELS(mi) > 2) ?
@@ -399,15 +413,10 @@ release_shape(ModeInfo * mi)
 	if (shapes != NULL) {
 		int         screen;
 
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
-			shapestruct *sp = &shapes[screen];
-			int         bits;
-
-			for (bits = 0; bits < sp->init_bits; bits++)
-				XFreePixmap(MI_DISPLAY(mi), sp->pixmaps[bits]);
-		}
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_shape(MI_DISPLAY(mi), &shapes[screen]);
 		(void) free((void *) shapes);
-		shapes = NULL;
+		shapes = (shapestruct *) NULL;
 	}
 }
 
