@@ -56,7 +56,7 @@ ModeSpecOpt sierpinski_opts =
 #ifdef USE_MODULES
 ModStruct   sierpinski_description =
 {"sierpinski", "init_sierpinski", "draw_sierpinski", "release_sierpinski",
- "refresh_sierpinski", "init_sierpinski", NULL, &sierpinski_opts,
+ "refresh_sierpinski", "init_sierpinski", (char *) NULL, &sierpinski_opts,
  400000, 2000, 100, 1, 64, 1.0, "",
  "Shows Sierpinski's triangle", 0, NULL};
 
@@ -76,7 +76,7 @@ typedef struct {
 	XPoint      vertex[MAXCORNERS];
 } sierpinskistruct;
 
-static sierpinskistruct *tris = NULL;
+static sierpinskistruct *tris = (sierpinskistruct *) NULL;
 
 static void
 startover(ModeInfo * mi)
@@ -122,7 +122,7 @@ free_sierpinski(sierpinskistruct *sp)
 	for (corner = 0; corner < MAXCORNERS; corner++)
 		if (sp->pointBuffer[corner] != NULL) {
 			(void) free((void *) sp->pointBuffer[corner]);
-			sp->pointBuffer[corner] = NULL;
+			sp->pointBuffer[corner] = (XPoint *) NULL;
 		}
 }
 
@@ -209,7 +209,7 @@ release_sierpinski(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_sierpinski(&tris[screen]);
 		(void) free((void *) tris);
-		tris = NULL;
+		tris = (sierpinskistruct *) NULL;
 	}
 }
 
