@@ -48,7 +48,7 @@ ModeSpecOpt slip_opts =
 #ifdef USE_MODULES
 ModStruct   slip_description =
 {"slip", "init_slip", "draw_slip", "release_slip",
- "init_slip", "init_slip", NULL, &slip_opts,
+ "init_slip", "init_slip", (char *) NULL, &slip_opts,
  50000, 35, 50, 1, 64, 1.0, "",
  "Shows slipping blits", 0, NULL};
 
@@ -65,7 +65,7 @@ typedef struct {
 	int         stage;
 	unsigned long r;
 } slipstruct;
-static slipstruct *slips = NULL;
+static slipstruct *slips = (slipstruct *) NULL;
 
 static short
 halfrandom(slipstruct *sp, int mv)
@@ -333,7 +333,7 @@ release_slip(ModeInfo * mi)
 {
 	if (slips != NULL) {
 		(void) free((void *) slips);
-		slips = NULL;
+		slips = (slipstruct *) NULL;
 	}
 }
 
