@@ -109,7 +109,7 @@ static const char *RankNames[] = {"", "A",
 #endif
 #endif
 
-static inline int round(double x) { return int(x + 0.5); }
+static inline int int_round(double x) { return int(x + 0.5); }
 
 #ifdef DOFONT
 // Does this really add anything?
@@ -297,7 +297,7 @@ void CardView::draw()
 #ifdef CENTERLABEL
 			XDrawString(display, window, gc,
 				x() + width() / 2 - strlen(RankNames[card->whichRank()]) * 8,
-				y() + round(height() * 0.40),
+				y() + int_round(height() * 0.40),
 				RankNames[card->whichRank()], strlen(RankNames[card->whichRank()]));
 #else
 			XDrawString(display, window, gc,
@@ -308,22 +308,22 @@ void CardView::draw()
 		}
 #ifdef SUITNAMES
 			char *SuitNames[] = {"Spade", "Diamond", "Club", "Heart"};
-		XDrawString(display, window, gc, x() + 0.2, y() + round(height() * 0.8),
+		XDrawString(display, window, gc, x() + 0.2, y() + int_round(height() * 0.8),
 			SuitNames[card->whichSuit()], strlen(SuitNames[card->whichSuit()]));
 #endif
 #ifdef CENTERLABEL
 		drawSuit(mi, card->whichSuit(),
-			x() + round(width() * 0.35), y() + round(height() * 0.55),
-			round(0.3 * width()), round(0.3 * height()));
+			x() + int_round(width() * 0.35), y() + int_round(height() * 0.55),
+			int_round(0.3 * width()), int_round(0.3 * height()));
 #else
 		if (width() > 16 && height() > 34) {
 			drawSuit(mi, card->whichSuit(),
 				x() + 5, y() + 25,
-				round(0.3 * width()), round(0.3 * height()));
+				int_round(0.3 * width()), int_round(0.3 * height()));
 		} else {
 			drawSuit(mi, card->whichSuit(),
 				x() + 2, y() + 2,
-				round(0.3 * width()), round(0.3 * height()));
+				int_round(0.3 * width()), int_round(0.3 * height()));
 		}
 #endif
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
@@ -342,17 +342,17 @@ void CardView::draw()
 		XFillRectangle(display, window, gc,
 			x(), y(), width(), height());
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-		n = x() + round(round(width() * 0.3));
-		XDrawLine(display, window, gc, n, y() + round(height() * 0.1),
-			n, y() + round(height() * 0.9));
-		n = x() + round(width() * 0.7);
-		XDrawLine(display, window, gc, n, y() + round(height() * 0.1),
-			n, y() + round(height() * 0.9));
-		n = y() + round(height() * 0.3);
-		XDrawLine(display, window, gc, x() + round(height() * 0.1), n,
-			x() + round(width() * 0.9), n);
-		n = y() + round(height() * 0.7);
-		XDrawLine(display, window, gc, x() + round(width() * 0.1), n,
+		n = x() + int_round(int_round(width() * 0.3));
+		XDrawLine(display, window, gc, n, y() + int_round(height() * 0.1),
+			n, y() + int_round(height() * 0.9));
+		n = x() + int_round(width() * 0.7);
+		XDrawLine(display, window, gc, n, y() + int_round(height() * 0.1),
+			n, y() + int_round(height() * 0.9));
+		n = y() + int_round(height() * 0.3);
+		XDrawLine(display, window, gc, x() + int_round(height() * 0.1), n,
+			x() + int_round(width() * 0.9), n);
+		n = y() + int_round(height() * 0.7);
+		XDrawLine(display, window, gc, x() + int_round(width() * 0.1), n,
 			x() + int(width() * 0.9), n);
 	}
 	// Shadow
@@ -670,10 +670,10 @@ void DeckPile::updateLocation(ModeInfo * a_mi)
 	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
-	x = round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
+	x = int_round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
 		(MAXALTERNATEPILES + 1.0)) / (2.0 * MAXALTERNATEPILES)) +
 		3 * bp->cardwidth / 4.0);
-	y = round(0.25 * bp->cardheight);
+	y = int_round(0.25 * bp->cardheight);
 
 	// set card
 	for (CardLink *p = top; p!= nilLink; p = p->nextCard()) {
@@ -728,10 +728,10 @@ void DiscardPile::updateLocation(ModeInfo * a_mi)
 	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
-	x = round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
+	x = int_round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
 		(MAXALTERNATEPILES + 1.0)) / (2.0 * MAXALTERNATEPILES)) +
 		2 * bp->cardwidth);
-	y = round(0.25 * bp->cardheight);
+	y = int_round(0.25 * bp->cardheight);
 
 	// set card
 	for (CardLink *p = top; p!= nilLink; p = p->nextCard()) {
@@ -785,10 +785,10 @@ void SuitPile::updateLocation(ModeInfo * a_mi)
 	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
-	x = round(((bp->cardwidth + 2.0 * suit * bp->cardwidth *
+	x = int_round(((bp->cardwidth + 2.0 * suit * bp->cardwidth *
 		(MAXALTERNATEPILES + 1.0)) / (2.0 * MAXALTERNATEPILES)) +
 		bp->cardwidth / 2.0);
-	y = round(0.25 * bp->cardheight);
+	y = int_round(0.25 * bp->cardheight);
 
 	// set card
 	for (CardLink *p = top; p!= nilLink; p = p->nextCard()) {
@@ -816,9 +816,9 @@ void AlternatePile::updateLocation(ModeInfo * a_mi)
 	int ty;
 
 	//set pile
-	x = (round((bp->cardwidth + 2.0 * pile * bp->cardwidth *
+	x = (int_round((bp->cardwidth + 2.0 * pile * bp->cardwidth *
 	 (MAXALTERNATEPILES + 1.0)) / (2.0 * MAXALTERNATEPILES)));
-	y = round(1.5 * bp->cardheight);
+	y = int_round(1.5 * bp->cardheight);
 
 	CardLink *bf = nilLink;
 	// set card
@@ -837,7 +837,7 @@ void AlternatePile::updateLocation(ModeInfo * a_mi)
 			CardLink *sp;
 			for (sp = top; sp->nextCard() != bf; sp = sp->nextCard());
 			bf = sp;
-			ty += round(bp->cardheight * OVERLAP);
+			ty += int_round(bp->cardheight * OVERLAP);
 			sp->moveTo(x, ty);
 		}
 	}
@@ -878,7 +878,7 @@ void AlternatePile::addCard(CardLink * card)
 #else
 		if (top->isFaceUp())
 #endif
-			ty += round(bp->cardheight * OVERLAP);
+			ty += int_round(bp->cardheight * OVERLAP);
 		CardPile::addCard(card);
 		top->moveTo(tx, ty);
 	}
@@ -1261,7 +1261,7 @@ ModStruct solitare_description =
 {(char *) "solitare", (char *) "init_solitare",
  (char *) "draw_solitare", (char *) "release_solitare",
  (char *) "refresh_solitare", (char *) "init_solitare",
- NULL, &solitare_opts,
+ (char *) NULL, &solitare_opts,
  2000000, 1, 1, 1, 64, 1.0, (char *) "",
  (char *) "Shows Klondike's game of solitare", 0, NULL};
 #endif
