@@ -80,7 +80,7 @@ ModeSpecOpt sphere_opts =
 #ifdef USE_MODULES
 ModStruct   sphere_description =
 {"sphere", "init_sphere", "draw_sphere", "release_sphere",
- "refresh_sphere", "init_sphere", NULL, &sphere_opts,
+ "refresh_sphere", "init_sphere", (char *) NULL, &sphere_opts,
  5000, 1, 20, 0, 64, 1.0, "",
  "Shows a bunch of shaded spheres", 0, NULL};
 
@@ -108,7 +108,7 @@ typedef struct {
 	XPoint     *points;
 } spherestruct;
 
-static spherestruct *spheres = NULL;
+static spherestruct *spheres = (spherestruct *) NULL;
 
 void
 init_sphere(ModeInfo * mi)
@@ -124,7 +124,7 @@ init_sphere(ModeInfo * mi)
 
 	if (sp->points != NULL) {
 		(void) free((void *) sp->points);
-		sp->points = NULL;
+		sp->points = (XPoint *) NULL;
 	}
 	sp->width = MI_WIDTH(mi);
 	sp->height = MI_HEIGHT(mi);
@@ -285,7 +285,7 @@ release_sphere(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) spheres);
-		spheres = NULL;
+		spheres = (spherestruct *) NULL;
 	}
 }
 
