@@ -57,7 +57,7 @@ ModeSpecOpt spiral_opts =
 #ifdef USE_MODULES
 ModStruct   spiral_description =
 {"spiral", "init_spiral", "draw_spiral", "release_spiral",
- "refresh_spiral", "init_spiral", NULL, &spiral_opts,
+ "refresh_spiral", "init_spiral", (char *) NULL, &spiral_opts,
  5000, -40, 350, 1, 64, 1.0, "",
  "Shows a helical locus of points", 0, NULL};
 
@@ -94,7 +94,7 @@ typedef struct {
 	int         redrawing, redrawpos;
 } spiralstruct;
 
-static spiralstruct *spirals = NULL;
+static spiralstruct *spirals = (spiralstruct *) NULL;
 
 static void draw_dots(ModeInfo * mi, int in);
 
@@ -308,7 +308,7 @@ release_spiral(ModeInfo * mi)
 				(void) free((void *) sp->traildots);
 		}
 		(void) free((void *) spirals);
-		spirals = NULL;
+		spirals = (spiralstruct *) NULL;
 	}
 }
 
