@@ -94,7 +94,7 @@ ModeSpecOpt spline_opts =
 #ifdef USE_MODULES
 ModStruct   spline_description =
 {"spline", "init_spline", "draw_spline", "release_spline",
- "refresh_spline", "init_spline", NULL, &spline_opts,
+ "refresh_spline", "init_spline", (char *) NULL, &spline_opts,
  30000, -6, 2048, 1, 64, 0.3, "",
  "Shows colorful moving splines", 0, NULL};
 
@@ -128,7 +128,7 @@ typedef struct {
 	splinepointstruct *pt;
 } splinestruct;
 
-static splinestruct *splines = NULL;
+static splinestruct *splines = (splinestruct *) NULL;
 
 static void XDrawSpline(Display * display, Drawable d, GC gc,
 			int x0, int y0, int x1, int y1, int x2, int y2);
@@ -139,7 +139,7 @@ free_spline(splinestruct *sp)
 
 	if (sp->pt != NULL) {
 		(void) free((void *) sp->pt);
-		sp->pt = NULL;
+		sp->pt = (splinepointstruct *) NULL;
 	}
 	if (sp->splineq != NULL) {
 		int         spline;
@@ -148,7 +148,7 @@ free_spline(splinestruct *sp)
 			if (sp->splineq[spline] != NULL)
 				(void) free((void *) sp->splineq[spline]);
 		(void) free((void *) sp->splineq);
-		sp->splineq = NULL;
+		sp->splineq = (XPoint **) NULL;
 	}
 }
 
@@ -177,14 +177,14 @@ init_spline(ModeInfo * mi)
 	if (sp->points < -MINPOINTS) {
 		if (sp->pt) {
 			(void) free((void *) sp->pt);
-			sp->pt = NULL;
+			sp->pt = (splinepointstruct *) NULL;
 		}
 		if (sp->erase) {
 			if (sp->splineq)
 				for (i = 0; i < sp->nsplines; ++i)
 					if (sp->splineq[i]) {
 						(void) free((void *) sp->splineq[i]);
-						sp->splineq[i] = NULL;
+						sp->splineq[i] = (XPoint *) NULL;
 					}
 		}
 		sp->points = NRAND(-sp->points - MINPOINTS + 1) + MINPOINTS;
@@ -434,7 +434,7 @@ release_spline(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_spline(&splines[screen]);
 		(void) free((void *) splines);
-		splines = NULL;
+		splines = (splinestruct *) NULL;
 	}
 }
 
