@@ -112,7 +112,7 @@ ModeSpecOpt star_opts =
 #ifdef USE_MODULES
 ModStruct   star_description =
 {"star", "init_star", "draw_star", "release_star",
- "refresh_star", "init_star", NULL, &star_opts,
+ "refresh_star", "init_star", (char *) NULL, &star_opts,
  40000, 100, 1, 100, 64, 0.3, "",
  "Shows a star field with a twist", 0, NULL};
 
@@ -211,7 +211,7 @@ typedef struct {
 static float cos_array[RESOLUTION], sin_array[RESOLUTION];
 static float depths[(MAX_DEPTH + 1) * DEPTH_SCALE];
 
-static starstruct *stars = NULL;
+static starstruct *stars = (starstruct *) NULL;
 
 static void star_draw(ModeInfo * mi, astar * astars, int draw_p);
 static int  compute_move(starstruct * sp, int axe);
@@ -337,13 +337,13 @@ free_star(Display *display, starstruct *sp)
 
 	if (sp->astars != NULL) {
 		(void) free((void *) sp->astars);
-		sp->astars = NULL;
+		sp->astars = (astar *) NULL;
 	}
-	if (sp->pixmaps != NULL) {
+	if (sp->pixmaps != None) {
 		for (i = 0; i < sp->max_star_size; i++)
 			XFreePixmap(display, sp->pixmaps[i]);
 		(void) free((void *) sp->pixmaps);
-		sp->pixmaps = NULL;
+		sp->pixmaps = None;
 	}
 	if (sp->stippledGC != None) {
 		XFreeGC(display, sp->stippledGC);
@@ -715,7 +715,7 @@ init_star(ModeInfo * mi)
 	if (sp->nstars < -MIN_STARS) {
 		if (sp->astars) {
 			(void) free((void *) sp->astars);
-			sp->astars = NULL;
+			sp->astars = (astar *) NULL;
 		}
 		sp->nstars = NRAND(-sp->nstars - MIN_STARS + 1) + MIN_STARS;
 	} else if (sp->nstars < MIN_STARS)
@@ -791,7 +791,7 @@ release_star(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_star(MI_DISPLAY(mi), &stars[screen]);
 		(void) free((void *) stars);
-		stars = NULL;
+		stars = (starstruct *) NULL;
 	}
 }
 
