@@ -88,7 +88,7 @@ ModeSpecOpt starfish_opts =
 #ifdef USE_MODULES
 ModStruct   starfish_description =
 {"starfish", "init_starfish", "draw_starfish", "release_starfish",
- "init_starfish", "init_starfish", NULL, &starfish_opts,
+ "init_starfish", "init_starfish", (char *) NULL, &starfish_opts,
  2000, 1, 1000, 1, 64, 1.0, "",
  "Shows starfish", 0, NULL};
 
@@ -134,8 +134,7 @@ typedef struct {
 	ModeInfo   *mi;
 } starfishstruct;
 
-static starfishstruct *starfishes = NULL;
-
+static starfishstruct *starfishes = (starfishstruct *) NULL;
 
 static void
 free_starfish(Display *display, starfishstruct * sp)
@@ -153,7 +152,7 @@ free_starfish(Display *display, starfishstruct * sp)
 			if (sp->ncolors && !sp->no_colors)
 				free_colors(display, sp->cmap, sp->colors, sp->ncolors);
 			(void) free((void *) sp->colors);
-			sp->colors = NULL;
+			sp->colors = (XColor *) NULL;
 		}
 		if (sp->cmap != None) {
 			XFreeColormap(display, sp->cmap);
@@ -166,15 +165,15 @@ free_starfish(Display *display, starfishstruct * sp)
 	}
 	if (sp->splines != NULL) {
 		free_spline(sp->splines);
-		sp->splines = NULL;
+		sp->splines = (spline *) NULL;
 	}
 	if (sp->r != NULL) {
 		(void) free((void *) sp->r);
-		sp->r = NULL;
+		sp->r = (long *) NULL;
 	}
 	if (sp->prev != NULL) {
 		(void) free((void *) sp->prev);
-		sp->prev = NULL;
+		sp->prev = (XPoint *) NULL;
 	}
 }
 
@@ -395,7 +394,7 @@ draw1_starfish(Display * display, Drawable drawable, GC gc, starfishstruct * sp)
 		(void) free((void *) points);
 
 		(void) free((void *) sp->prev);
-		sp->prev = NULL;
+		sp->prev = (XPoint *) NULL;
 	}
 	if ((sp->prev = (XPoint *) malloc(sp->splines->n_points *
 			sizeof (XPoint))) == NULL) {
@@ -418,6 +417,10 @@ draw1_starfish(Display * display, Drawable drawable, GC gc, starfishstruct * sp)
 	return True;
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
 
 void
 init_starfish(ModeInfo * mi)
@@ -466,9 +469,6 @@ init_starfish(ModeInfo * mi)
 			XColor      color;
 
 #ifndef STANDALONE
-			extern char *background;
-			extern char *foreground;
-
 			sp->fg = MI_FG_PIXEL(mi);
 			sp->bg = MI_BG_PIXEL(mi);
 #endif
@@ -494,7 +494,7 @@ init_starfish(ModeInfo * mi)
 			(void) XAllocColor(display, sp->cmap, &color);
 			MI_FG_PIXEL(mi) = color.pixel;
 #endif
-			sp->colors = NULL;
+			sp->colors = (XColor *) NULL;
 			sp->ncolors = 0;
 		}
 		gcv.foreground = sp->fg_index;
@@ -511,7 +511,7 @@ init_starfish(ModeInfo * mi)
 			if (sp->ncolors && !sp->no_colors)
 				free_colors(display, sp->cmap, sp->colors, sp->ncolors);
 			(void) free((void *) sp->colors);
-			sp->colors = NULL;
+			sp->colors = (XColor *) NULL;
 		}
 		sp->ncolors = MI_NCOLORS(mi);
 		if (sp->ncolors < 2)
@@ -522,7 +522,7 @@ init_starfish(ModeInfo * mi)
 			sp->mono_p = False;
 
 		if (sp->mono_p)
-			sp->colors = NULL;
+			sp->colors = (XColor *) NULL;
 		else
 			if ((sp->colors = (XColor *) malloc(sizeof (*sp->colors) *
 					(sp->ncolors + 1))) == NULL) {
@@ -573,7 +573,7 @@ init_starfish(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 	if (sp->prev != NULL) {
 		(void) free((void *) sp->prev);
-		sp->prev = NULL;
+		sp->prev = (XPoint *) NULL;
 	}
 	sp->stage = 0;
 	sp->counter = 0;
@@ -665,7 +665,7 @@ release_starfish(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_starfish(MI_DISPLAY(mi), &starfishes[screen]);
 		(void) free((void *) starfishes);
-		starfishes = NULL;
+		starfishes = (starfishstruct *) NULL;
 	}
 }
 
