@@ -74,7 +74,7 @@ ModeSpecOpt swarm_opts =
 #ifdef USE_MODULES
 ModStruct   swarm_description =
 {"swarm", "init_swarm", "draw_swarm", "release_swarm",
- "refresh_swarm", "init_swarm", NULL, &swarm_opts,
+ "refresh_swarm", "init_swarm", (char *) NULL, &swarm_opts,
  15000, -100, 1, -100, 64, 1.0, "",
  "Shows a swarm of bees following a wasp", 0, NULL};
 
@@ -112,18 +112,18 @@ typedef struct {
 	Cursor      cursor;
 } swarmstruct;
 
-static swarmstruct *swarms = NULL;
+static swarmstruct *swarms = (swarmstruct *) NULL;
 
 static void
 free_segs(swarmstruct *sp)
 {
 	if (sp->segs != NULL) {
 		(void) free((void *) sp->segs);
-		sp->segs = NULL;
+		sp->segs = (XSegment *) NULL;
 	}
 	if (sp->old_segs != NULL) {
 		(void) free((void *) sp->old_segs);
-		sp->old_segs = NULL;
+		sp->old_segs = (XSegment *) NULL;
 	}
 }
 
@@ -133,19 +133,19 @@ free_bees(swarmstruct *sp)
 	free_segs(sp);
 	if (sp->x != NULL) {
 		(void) free((void *) sp->x);
-		sp->x = NULL;
+		sp->x = (float *) NULL;
 	}
 	if (sp->y != NULL) {
 		(void) free((void *) sp->y);
-		sp->y = NULL;
+		sp->y = (float *) NULL;
 	}
 	if (sp->xv != NULL) {
 		(void) free((void *) sp->xv);
-		sp->xv = NULL;
+		sp->xv = (float *) NULL;
 	}
 	if (sp->yv != NULL) {
 		(void) free((void *) sp->yv);
-		sp->yv = NULL;
+		sp->yv = (float *) NULL;
 	}
 }
 
@@ -402,7 +402,7 @@ release_swarm(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_swarm(MI_DISPLAY(mi), &swarms[screen]);
 		(void) free((void *) swarms);
-		swarms = NULL;
+		swarms = (swarmstruct *) NULL;
 	}
 }
 
