@@ -59,7 +59,7 @@ ModeSpecOpt swirl_opts =
 #ifdef USE_MODULES
 ModStruct   swirl_description =
 {"swirl", "init_swirl", "draw_swirl", "release_swirl",
- "refresh_swirl", "init_swirl", NULL, &swirl_opts,
+ "refresh_swirl", "init_swirl", (char *) NULL, &swirl_opts,
  5000, 5, 1, 1, 64, 1.0, "",
  "Shows animated swirling patterns", 0, NULL};
 
@@ -160,7 +160,7 @@ static COLOUR basic_colours[SWIRLCOLOURS];
 #endif /* !STANDALONE */
 
 /* an array of swirls for each screen */
-static SWIRL_P swirls = NULL;
+static SWIRL_P swirls = (SWIRL_P) NULL;
 
 /*-
    random_no
@@ -188,7 +188,7 @@ free_swirl(Display *display, SWIRL_P swirl)
 	}
 	if (swirl->rgb_values != NULL) {
 		XFree((caddr_t) swirl->rgb_values);
-		swirl->rgb_values = NULL;
+		swirl->rgb_values = (XColor *) NULL;
 	}
 	if (swirl->ximage != None) {
 		(void) XDestroyImage(swirl->ximage);
@@ -196,7 +196,7 @@ free_swirl(Display *display, SWIRL_P swirl)
 	}
 	if (swirl->knots != NULL) {
 		(void) free((void *) swirl->knots);
-		swirl->knots = NULL;
+		swirl->knots = (KNOT_P) NULL;
 	}
 }
 
@@ -214,7 +214,7 @@ initialise_swirl(SWIRL_P swirl)
 	swirl->height = 0;
 	swirl->depth = 1;
 	swirl->rdepth = 1;
-	swirl->visual = NULL;
+	swirl->visual = (Visual *) NULL;
 	swirl->resolution = MIN_RES + 1;	/* current resolution */
 	swirl->max_resolution = MAX_RES;	/* maximum resolution */
 	swirl->n_knots = 0;	/* number of knots */
@@ -230,13 +230,13 @@ initialise_swirl(SWIRL_P swirl)
 	swirl->drawing = False;
 
 	/* image stuff */
-	swirl->ximage = NULL;
+	swirl->ximage = None;
 
 	/* colours stuff */
 	swirl->colours = 0;	/* how many colours possible */
 	swirl->dcolours = 0;	/* how many colours for shading */
-	swirl->cmap = (Colormap) NULL;
-	swirl->rgb_values = NULL;	/* colour definitions array */
+	swirl->cmap = (Colormap) None;
+	swirl->rgb_values = (XColor *) NULL;	/* colour definitions array */
 }
 
 /****************************************************************/
@@ -1502,7 +1502,7 @@ release_swirl(ModeInfo * mi)
 			free_swirl(MI_DISPLAY(mi), &swirls[screen]);
 		/* deallocate an array, one entry for each screen */
 		(void) free((void *) swirls);
-		swirls = NULL;
+		swirls = (SWIRL_P) NULL;
 	}
 }
 
