@@ -146,7 +146,7 @@ ModeSpecOpt t3d_opts =
 #ifdef USE_MODULES
 ModStruct   t3d_description =
 {"t3d", "init_t3d", "draw_t3d", "release_t3d",
- "refresh_t3d", "init_t3d", NULL, &t3d_opts,
+ "refresh_t3d", "init_t3d", (char *) NULL, &t3d_opts,
  250000, 1000, 60000 , 1, 64, 1.0, "",
  "Flying Balls Clock Demo", 0, NULL};
 
@@ -184,7 +184,7 @@ typedef struct {
    ModeInfo   *mi;
 } t3dstruct;
 
-static t3dstruct *t3ds = NULL;
+static t3dstruct *t3ds = (t3dstruct *) NULL;
 
 static void
 t3d_zeiger( ModeInfo* mi , double dist,double rad, double z, double sec,
@@ -605,7 +605,7 @@ free_t3d(Display *display, t3dstruct *t3dp)
 			if (t3dp->ncolors && !t3dp->no_colors)
 				free_colors(display, t3dp->cmap, t3dp->colors, t3dp->ncolors);
 			(void) free((void *) t3dp->colors);
-			t3dp->colors = NULL;
+			t3dp->colors = (XColor *) NULL;
 		}
 		if (t3dp->cmap != None) {
 			XFreeColormap(display, t3dp->cmap);
@@ -640,7 +640,7 @@ free_t3d(Display *display, t3dstruct *t3dp)
 #endif
 	if (t3dp->zeit != NULL) {
 		(void) free((void *) t3dp->zeit);
-		t3dp->zeit = NULL;
+		t3dp->zeit = (struct tm *) NULL;
 	}
 }
 
@@ -738,6 +738,11 @@ t3d_initialize( ModeInfo* mi )
    return True;
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
+
 void
 init_t3d(ModeInfo * mi)
 {
@@ -800,9 +805,6 @@ init_t3d(ModeInfo * mi)
 	     XColor      color;
 
 #ifndef STANDALONE
-	     extern char *background;
-	     extern char *foreground;
-
 	     t3dp->fg = MI_FG_PIXEL(mi);
 	     t3dp->bg = MI_BG_PIXEL(mi);
 #endif
@@ -828,7 +830,7 @@ init_t3d(ModeInfo * mi)
 	     (void) XAllocColor(display, t3dp->cmap, &color);
 	     MI_FG_PIXEL(mi) = color.pixel;
 #endif
-	     t3dp->colors = NULL;
+	     t3dp->colors = (XColor *) NULL;
 	     t3dp->ncolors = 0;
      	  }
      }
@@ -845,7 +847,7 @@ init_t3d(ModeInfo * mi)
 			if (t3dp->ncolors && !t3dp->no_colors)
 				free_colors(display, t3dp->cmap, t3dp->colors, t3dp->ncolors);
 			(void) free((void *) t3dp->colors);
-			t3dp->colors = NULL;
+			t3dp->colors = (XColor *) NULL;
 		}
 		t3dp->ncolors = MI_NCOLORS(mi);
 		if (t3dp->ncolors < 2)
@@ -856,7 +858,7 @@ init_t3d(ModeInfo * mi)
 			t3dp->mono_p = False;
 
 		if (t3dp->mono_p)
-			t3dp->colors = NULL;
+			t3dp->colors = (XColor *) NULL;
 		else
 			if ((t3dp->colors = (XColor *) malloc(sizeof (*t3dp->colors) *
 					(t3dp->ncolors + 1))) == NULL) {
@@ -920,7 +922,7 @@ init_t3d(ModeInfo * mi)
    t3d_init_3d( mi );
 
    if (t3dp->zeit == NULL)
-     if ((t3dp->zeit = (struct tm *)malloc(sizeof(struct tm))) == NULL) {
+     if ((t3dp->zeit = (struct tm *) malloc(sizeof(struct tm))) == NULL) {
 	free_t3d(display, t3dp);
 	return;
      }
@@ -948,7 +950,7 @@ release_t3d(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_t3d(MI_DISPLAY(mi), &t3ds[screen]);
 		(void) free((void *) t3ds);
-		t3ds = NULL;
+		t3ds = (t3dstruct *) NULL;
 	}
 }
 
@@ -1028,7 +1030,7 @@ draw_t3d(ModeInfo * mi)
    XCopyArea (display, t3dp->buffer, window, t3dp->gc, 0, 0, t3dp->width,
 	      t3dp->height, 0, 0);
 
-   XSync(display,0);
+   XFlush(display);
 
    if ( trackmouse )
      {
