@@ -142,12 +142,14 @@ ModeSpecOpt tetris_opts =
 #ifdef USE_MODULES
 ModStruct   tetris_description =
 {"tetris", "init_tetris", "draw_tetris", "release_tetris",
- "refresh_tetris", "change_tetris", NULL, &tetris_opts,
+ "refresh_tetris", "change_tetris", (char *) NULL, &tetris_opts,
  600000, -40, 200, -100, 64, 1.0, "",
  "Shows an autoplaying tetris game", 0, NULL};
 
 #endif
 
+#include "bitmaps/gray1.xbm"
+
 #define MINGRIDSIZE 10 
 #define MAXPIXELSIZE 12
 #define MINSIZE 6 
@@ -233,6 +235,7 @@ typedef struct {
   int frozen_wall[MAX_SIDES];
   fieldstruct wall[WELL_DEPTH+WELL_WIDTH][WELL_PERIMETER];
   fieldstruct base[WELL_WIDTH][WELL_WIDTH];
+  Pixmap graypix;
 
   ModeInfo *mi;
 } trisstruct;
@@ -262,7 +265,9 @@ typedef struct {
 #define IS_RIGHT_UP(n) ((n)&RIGHT_UP)
 #define IS_LEFT_UP(n) ((n)&LEFT_UP)
 
+#define CHECKLEFT(x) ((x)|LEFT)
 #define CHECKDOWN(x) ((x)|DOWN)
+#define CHECKRIGHT(x) ((x)|RIGHT)
 #define CHECKUP(x) ((x)|UP)
 
 /* Defines to access the bitmaps. */
@@ -337,7 +342,7 @@ static int images_needed[] =
  -1
 };
 
-static trisstruct *triss = NULL;
+static trisstruct *triss = (trisstruct *) NULL;
 
 /* Setup: Normal, Bonus */
 static int area_kinds[] = {3, 3};
@@ -632,10 +637,7 @@ drawSquare(ModeInfo * mi, int pmid, int cid, int col, int row)
   trisstruct *tp = &triss[MI_SCREEN(mi)];
 
   setColour(mi, cid /* , 0 */);
-  if (tp->well)
-    XFillRectangle(display, window, tp->gc,
-      tp->xb + col * tp->xs + 1, tp->yb + row * tp->ys + 1, tp->xs - 2, tp->ys - 2);
-  else if (tp->pixelmode)
+  if (tp->pixelmode)
     XFillRectangle(display, window, tp->gc,
       tp->xb + col * tp->xs, tp->yb + row * tp->ys, tp->xs, tp->ys);
   else {
@@ -645,7 +647,7 @@ drawSquare(ModeInfo * mi, int pmid, int cid, int col, int row)
  * PURIFY on SunOS4 and on Solaris 2 reports a 120 byte memory leak on
  * the next line */
     (void) XPutImage(display, window, tp->gc, tp->images[pmid], 0, 0,
-      tp->xb + tp->xs * col, tp->yb + tp->ys * row,
+      tp->xb + col * tp->xs, tp->yb + row * tp->ys,
       tp->xs, tp->ys);
   }
 }
@@ -660,14 +662,9 @@ xorSquare(ModeInfo * mi, int i, int j)
   XSetFunction(display, tp->gc, GXxor);
   XSetBackground(display, tp->gc, 0);
   XSetForeground(display, tp->gc, 0xFFFFFF);
-  if (tp->well)
-    XFillRectangle(display, window, tp->gc,
-      tp->xb + i * tp->xs + 1, tp->yb + j * tp->ys + 1,
-      tp->xs - 2, tp->ys - 2);
-  else
-    XFillRectangle(display, window, tp->gc,
-      tp->xb, tp->yb + j * tp->ys,
-      tp->xs * tp->ncols, tp->ys);
+  XFillRectangle(display, window, tp->gc,
+    tp->xb + i * tp->xs, tp->yb + j * tp->ys,
+    tp->xs, tp->ys);
   XSetFunction(display, tp->gc, GXcopy);
   XSetBackground(display, tp->gc, tp->blackpixel);
   XSetForeground(display, tp->gc, tp->whitepixel);
@@ -716,6 +713,10 @@ drawWallSquare(ModeInfo * mi, GC gc, int i, int j)
     5 * DELTA;
   plateau_x = tp->xs + (WELL_DEPTH - j - 1) * 2 *
     tp->xs / WELL_DEPTH - 5 * DELTA;
+  {
+    XSetFillStyle(display, gc, FillOpaqueStippled);
+    XSetStipple(display, gc, tp->graypix);
+  }
   switch (w) {
   case 0:
     XFillTrapazoid(display, window, gc,
@@ -740,6 +741,9 @@ drawWallSquare(ModeInfo * mi, GC gc, int i, int j)
   default:
     (void) fprintf (stderr, "trapazoid kinds range 0-3, got %d.\n", w);
   }
+  {
+    XSetFillStyle(display, gc, FillSolid);
+  }
 }
 
 static void
@@ -776,6 +780,57 @@ freezeTrapazoid(ModeInfo * mi, int i, int j)
   XSetForeground(display, tp->gc, tp->whitepixel);
 }
 
+static int
+checkWall(int pmid, int base_i, int base_j)
+{
+  if (pmid < 0)
+    return pmid;
+  /* Check if next to well wall */
+  if (base_i == 0)
+    pmid = CHECKLEFT((unsigned int) pmid);
+  if (base_j == 0)
+    pmid = CHECKUP((unsigned int) pmid);
+  if (base_i == WELL_WIDTH - 1)
+    pmid = CHECKRIGHT((unsigned int) pmid);
+  if (base_j == WELL_WIDTH - 1)
+    pmid = CHECKDOWN((unsigned int) pmid);
+  return pmid;
+}
+
+static int
+checkSides(int pmid, int i)
+{
+  if (pmid < 0)
+    return pmid;
+  if (i == 0 || i == 3 * WELL_WIDTH - 1)
+    pmid = CHECKLEFT((unsigned int) pmid);
+  else if (i == WELL_WIDTH - 1 || i == 2 * WELL_WIDTH)
+    pmid = CHECKRIGHT((unsigned int) pmid);
+  else if (i == WELL_WIDTH || i == 4 * WELL_WIDTH - 1)
+    pmid = CHECKUP((unsigned int) pmid);
+  else if (i == 2 * WELL_WIDTH - 1 || i == 3 * WELL_WIDTH)
+    pmid = CHECKDOWN((unsigned int) pmid);
+  return pmid;
+}
+
+static int
+checkBottom(int pmid, int i, int j)
+{
+  if (pmid < 0 || j != WELL_DEPTH - 1)
+    return pmid;
+  switch (i / WELL_WIDTH) {
+  case 0:
+    return CHECKDOWN((unsigned int) pmid);
+  case 1:
+    return CHECKLEFT((unsigned int) pmid);
+  case 2:
+    return CHECKUP((unsigned int) pmid);
+  case 3:
+    return CHECKRIGHT((unsigned int) pmid);
+  }
+  return EMPTY;
+}
+
 /* Wall number ... imagine a 4 hour clock...
      0
     3+1
@@ -846,14 +901,20 @@ dropWall(ModeInfo *mi, int w)
             if (l + j >= WELL_DEPTH) {
               wall_to_base(&base_x, &base_y, k, l + j);
               tp->base[base_y][base_x] = tp->wall[l][k];
+              tp->base[base_y][base_x].pmid =
+                checkWall(tp->base[base_y][base_x].pmid, base_x, base_y);
               tp->wall[l][k].pmid = EMPTY;
               clearTrapazoid(mi, k, l);
-              drawSquare(mi, tp->wall[l][k].pmid, tp->wall[l][k].cid, base_x, base_y);
+              drawSquare(mi, tp->base[base_y][base_x].pmid,
+                tp->base[base_y][base_x].cid, base_x, base_y);
             } else {
               tp->wall[l + j][k] = tp->wall[l][k];
+              tp->wall[l + j][k].pmid =
+                checkBottom(tp->wall[l + j][k].pmid, k, l + j);
               tp->wall[l][k].pmid = EMPTY;
               clearTrapazoid(mi, k, l);
-              drawTrapazoid(mi, /* tp->wall[l][k].pmid, */ tp->wall[l][k].cid, k, l + j);
+              drawTrapazoid(mi, /* tp->wall[l][k].pmid, */ tp->wall[l][k].cid,
+                k, l + j);
             }
             XFlush(display);
           }
@@ -897,23 +958,16 @@ checkFreeze(ModeInfo *mi)
   int w;
 
   for (w = 0; w < MAX_SIDES; w++) {
-    if (tp->frozen_wall[w] == 0) {
+    if (!tp->frozen_wall[w]) {
       dropWall(mi, w);
     } else {
       tp->frozen_wall[w]--;
-      if (tp->frozen_wall[w] == 0) {
+      if (!tp->frozen_wall[w]) {
         freezeWall(mi, w);
         dropWall(mi, w);
       }
     }
   }
-  /* pick a free spot on the rim,  not all walls frozen or else
-     this is an infinite loop */
-  tp->curPolyomino.xpos = NRAND(WELL_WIDTH - tp->curPolyomino.size + 1);
-  do {
-    w = NRAND(MAX_SIDES);
-  } while (tp->frozen_wall[w]);
-  tp->curPolyomino.xpos += w * WELL_WIDTH;
 }
 
 static int
@@ -940,8 +994,23 @@ curPixmap(trisstruct *tp, int i, int j)
   return pmid;
 }
 
+static int
+rotateIndex(int pmid, int i)
+{
+  int wallRotation, pm1, pm0;
+
+  if (pmid == EMPTY)
+    return EMPTY;
+  wallRotation = (MAX_SIDES - i / WELL_WIDTH) % MAX_SIDES;
+  pm1 = (0xF0 & pmid) << wallRotation;
+  pm0 = (0xF & pmid) << wallRotation;
+  pm1 = (0xF0 & pm1) | ((pm1 & 0xF00) >> MAX_SIDES);
+  pm0 = (0xF & pm0) | ((pm0 & 0xF0) >> MAX_SIDES);
+  return (pm1 | pm0);
+}
+
 static void
-drawBox(ModeInfo * mi, int cid, int i, int j)
+drawBox(ModeInfo * mi, int pmid, int cid, int i, int j)
 {
   if (j < WELL_DEPTH) {
     drawTrapazoid(mi, /* pmid, */ cid, i, j);
@@ -949,7 +1018,7 @@ drawBox(ModeInfo * mi, int cid, int i, int j)
     int base_i, base_j;
 
     wall_to_base(&base_i, &base_j, i, j);
-    drawSquare(mi, 15, cid, base_i, base_j);
+    drawSquare(mi, pmid, cid, base_i, base_j);
   }
 }
 
@@ -961,26 +1030,8 @@ clearSquare(ModeInfo * mi, int col, int row)
   trisstruct *tp = &triss[MI_SCREEN(mi)];
 
   XSetForeground(display, tp->gc, tp->blackpixel);
-  if (tp->well)
-    XFillRectangle(display, window, tp->gc,
-      tp->xb + col * tp->xs + 1, tp->yb + row * tp->ys + 1,
-      tp->xs - 2, tp->ys - 2);
-  else
-    XFillRectangle(display, window, tp->gc,
-      tp->xb + col * tp->xs, tp->yb + row * tp->ys, tp->xs, tp->ys);
-}
-
-static void
-clearBox(ModeInfo * mi, int i, int j)
-{
-  if (j < WELL_DEPTH) {
-    clearTrapazoid(mi, i, j);
-  } else {
-    int base_i, base_j;
-
-    wall_to_base(&base_i, &base_j, i, j);
-    clearSquare(mi, base_i, base_j);
-  }
+  XFillRectangle(display, window, tp->gc,
+    tp->xb + col * tp->xs, tp->yb + row * tp->ys, tp->xs, tp->ys);
 }
 
 static void
@@ -989,16 +1040,62 @@ drawPolyomino(ModeInfo * mi)
   trisstruct *tp = &triss[MI_SCREEN(mi)];
   int   i, j;
 
-  for (i = 0; i < tp->curPolyomino.size; i++) {
-    for (j = 0; j < tp->curPolyomino.size; j++) {
-      if (polytris[(int) tp->bonusNow].polyomino[tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
-        if (tp->well) {
+  if (tp->well) {
+    int xi, yj, base_i, base_j;
+    int temp_base[WELL_WIDTH][WELL_WIDTH];
+
+    /* Initialize */
+    for (i = 0; i < WELL_WIDTH; i++)
+      for (j = 0; j < WELL_WIDTH; j++)
+        temp_base[j][i] = 0;
+    /* Find pieces and overlap them if necessary */
+    for (i = 0; i < tp->curPolyomino.size; i++) {
+      for (j = 0; j < tp->curPolyomino.size; j++) {
+        if (polytris[(int) tp->bonusNow].polyomino
+                    [tp->curPolyomino.polyomino_number].shape
+                    [j * tp->curPolyomino.size + i]) {
           int xi, yj;
 
           xi = (tp->curPolyomino.xpos + i) % WELL_PERIMETER;
           yj = tp->curPolyomino.ypos + j;
-          drawBox(mi, tp->curPolyomino.color_number, xi, yj);
-        } else {
+          if (yj >= WELL_DEPTH) {
+            wall_to_base(&base_i, &base_j, xi, yj);
+            xi = checkWall(rotateIndex(curPixmap(tp, i, j), xi),
+              base_i, base_j);
+            if (!temp_base[base_j][base_i])
+              temp_base[base_j][base_i] = xi;
+            else
+              temp_base[base_j][base_i] &= xi;
+          }
+        }
+      }
+      /* Now draw */
+      for (i = 0; i < tp->curPolyomino.size; i++)
+        for (j = 0; j < tp->curPolyomino.size; j++)
+          if (polytris[(int) tp->bonusNow].polyomino
+                      [tp->curPolyomino.polyomino_number].shape
+                      [j * tp->curPolyomino.size + i]) {
+            xi = (tp->curPolyomino.xpos + i) % WELL_PERIMETER;
+            yj = tp->curPolyomino.ypos + j;
+            if (yj >= WELL_DEPTH) {
+              wall_to_base(&base_i, &base_j, xi, yj);
+              if (temp_base[base_j][base_i]) {
+                drawSquare(mi, temp_base[base_j][base_i],
+                  tp->curPolyomino.color_number, base_i, base_j);
+                temp_base[base_j][base_i] = 0;
+              }
+            } else if (yj >= 0) {
+              drawTrapazoid(mi, /* tp->curPolyomino.pmid, */
+                tp->curPolyomino.color_number, xi, yj);
+            }
+          }
+    }
+  } else {
+    for (i = 0; i < tp->curPolyomino.size; i++) {
+      for (j = 0; j < tp->curPolyomino.size; j++) {
+        if (polytris[(int) tp->bonusNow].polyomino
+                    [tp->curPolyomino.polyomino_number].shape
+                    [j * tp->curPolyomino.size + i]) {
           drawSquare(mi, curPixmap(tp, i, j),
             tp->curPolyomino.color_number,
             tp->curPolyomino.xpos + i, tp->curPolyomino.ypos + j);
@@ -1014,45 +1111,103 @@ drawPolyominoDiff(ModeInfo *mi, thing_t * old)
   trisstruct *tp = &triss[MI_SCREEN(mi)];
   int   i, j, ox, oy;
 
-  /* Erase first or will have invisible squares when folded down a corner */
-  for (i = 0; i < tp->curPolyomino.size; i++)
-    for (j = 0; j < tp->curPolyomino.size; j++) {
-      ox = old->xpos + i - tp->curPolyomino.xpos;
-      oy = old->ypos + j - tp->curPolyomino.ypos;
-      if (polytris[(int) tp->bonusNow].polyomino[old->polyomino_number].shape[j * tp->curPolyomino.size + i] &&
-        ((ox < 0) || (ox >= tp->curPolyomino.size) ||
-        (oy < 0) || (oy >= tp->curPolyomino.size) ||
-        !polytris[(int) tp->bonusNow].polyomino
-          [tp->curPolyomino.polyomino_number].shape[oy * tp->curPolyomino.size + ox])) {
-        if (tp->well) {
-          int xi, yj;
-
-          xi = (old->xpos + i) % WELL_PERIMETER;
-          yj = old->ypos + j;
-          clearBox(mi, xi, yj);
-        } else {
-          clearSquare(mi, (old->xpos + i), (old->ypos + j));
-        }
-      }
-    }
-
-  for (i = 0; i < tp->curPolyomino.size; i++)
-    for (j = 0; j < tp->curPolyomino.size; j++)
-      if ((tp->curPolyomino.ypos + j >= 0) &&
-        polytris[(int) tp->bonusNow].polyomino
-          [tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
-        if (tp->well) {
-          int xi, yj;
+  if (tp->well) {
+    int xi, yj, base_i, base_j;
+    int temp_base[WELL_WIDTH][WELL_WIDTH];
 
+    /* Initialize */
+    for (i = 0; i < WELL_WIDTH; i++)
+      for (j = 0; j < WELL_WIDTH; j++)
+        temp_base[j][i] = 0;
+    /* Find pieces and overlap them if necessary */
+    for (i = 0; i < tp->curPolyomino.size; i++)
+      for (j = 0; j < tp->curPolyomino.size; j++)
+        if (polytris[(int) tp->bonusNow].polyomino
+                    [tp->curPolyomino.polyomino_number].shape
+                    [j * tp->curPolyomino.size + i]) {
           xi = (tp->curPolyomino.xpos + i) % WELL_PERIMETER;
           yj = tp->curPolyomino.ypos + j;
-          drawBox(mi, tp->curPolyomino.color_number, xi, yj);
-        } else {
+          if (yj >= WELL_DEPTH) {
+            wall_to_base(&base_i, &base_j, xi, yj);
+            xi = checkWall(rotateIndex(curPixmap(tp, i, j), xi),
+              base_i, base_j);
+            if (!temp_base[base_j][base_i])
+              temp_base[base_j][base_i] = xi;
+            else
+              temp_base[base_j][base_i] &= xi;
+           }
+          }
+    /* Now draw */
+    for (i = 0; i < tp->curPolyomino.size; i++)
+      for (j = 0; j < tp->curPolyomino.size; j++)
+        if (polytris[(int) tp->bonusNow].polyomino
+                    [tp->curPolyomino.polyomino_number].shape
+                    [j * tp->curPolyomino.size + i]) {
+          xi = (tp->curPolyomino.xpos + i) % WELL_PERIMETER;
+          yj = tp->curPolyomino.ypos + j;
+          if (yj >= WELL_DEPTH) {
+            wall_to_base(&base_i, &base_j, xi, yj);
+            if (temp_base[base_j][base_i] > 0) {
+              drawSquare(mi, temp_base[base_j][base_i],
+                tp->curPolyomino.color_number, base_i, base_j);
+               /* negate for erase */
+               temp_base[base_j][base_i] = -temp_base[base_j][base_i];
+             }
+           } else if (yj >= 0) {
+              drawTrapazoid(mi, /* tp->curPolyomino.pmid, */
+                tp->curPolyomino.color_number, xi, yj);
+            }
+          }
+    /* Erase */
+    for (i = 0; i < old->size; i++)
+      for (j = 0; j < old->size; j++) {
+        xi = (old->xpos + i) % WELL_PERIMETER;
+        yj = old->ypos + j;
+        ox = (xi - tp->curPolyomino.xpos + WELL_PERIMETER) % WELL_PERIMETER;
+        oy = yj - tp->curPolyomino.ypos;
+        if (yj >= WELL_DEPTH) {
+          wall_to_base(&base_i, &base_j, xi, yj);
+          if (polytris[(int) tp->bonusNow].polyomino
+                      [old->polyomino_number].shape
+                      [j * old->size + i] &&
+            ((ox >= tp->curPolyomino.size) || (oy < 0) ||
+             (oy >= tp->curPolyomino.size) || !temp_base[base_j][base_i]))
+            clearSquare(mi, base_i, base_j);
+        } else if (yj >= 0) {
+           if (polytris[(int) tp->bonusNow].polyomino
+                       [old->polyomino_number].shape
+                       [j * old->size + i] &&
+             ((ox >= tp->curPolyomino.size) || (oy < 0) ||
+              (oy >= tp->curPolyomino.size) || !polytris
+		[(int) tp->bonusNow].polyomino
+                [tp->curPolyomino.polyomino_number].shape
+                [oy * tp->curPolyomino.size + ox]))
+              clearTrapazoid(mi, xi, yj);
+          }
+        }
+  } else {
+    for (i = 0; i < tp->curPolyomino.size; i++)
+      for (j = 0; j < tp->curPolyomino.size; j++)
+        if ((tp->curPolyomino.ypos + j >= 0) &&
+          polytris[(int) tp->bonusNow].polyomino
+            [tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
           drawSquare(mi, curPixmap(tp, i, j),
             tp->curPolyomino.color_number,
             tp->curPolyomino.xpos + i, tp->curPolyomino.ypos + j);
         }
+    for (i = 0; i < tp->curPolyomino.size; i++)
+      for (j = 0; j < tp->curPolyomino.size; j++) {
+        ox = old->xpos + i - tp->curPolyomino.xpos;
+        oy = old->ypos + j - tp->curPolyomino.ypos;
+        if (polytris[(int) tp->bonusNow].polyomino[old->polyomino_number].shape[j * tp->curPolyomino.size + i] &&
+          ((ox < 0) || (ox >= tp->curPolyomino.size) ||
+          (oy < 0) || (oy >= tp->curPolyomino.size) ||
+          !polytris[(int) tp->bonusNow].polyomino
+            [tp->curPolyomino.polyomino_number].shape[oy * tp->curPolyomino.size + ox])) {
+          clearSquare(mi, (old->xpos + i), (old->ypos + j));
+        }
       }
+  }
 }
 
 static void
@@ -1069,8 +1224,6 @@ redoNext(ModeInfo * mi)
     tp->curPolyomino.polyomino_number = polytris[(int) tp->bonusNow].polyomino
       [tp->curPolyomino.polyomino_number].rotation;
   tp->curPolyomino.size = polytris[(int) tp->bonusNow].polyomino[tp->curPolyomino.polyomino_number].size;
-  tp->curPolyomino.xpos = NRAND(tp->ncols - tp->curPolyomino.size + 1);
-  /* tp->curPolyomino.xpos = (tp->ncols - tp->curPolyomino.size) / 2; */
   tp->curPolyomino.ypos = -polytris[(int) tp->bonusNow].polyomino
     [tp->curPolyomino.polyomino_number].leadingEmptyHeight;
 }
@@ -1093,6 +1246,21 @@ newPolyomino(ModeInfo * mi) {
     }
   }
   redoNext(mi);
+  if (tp->well) {
+    int w;
+
+    /* pick a free spot on the rim, not all frozen else this is an infinite
+       loop */
+    /* tp->curPolyomino.xpos = (WELL_WIDTH - tp->curPolyomino.size) / 2; */
+    tp->curPolyomino.xpos = NRAND(WELL_WIDTH - tp->curPolyomino.size + 1);
+    do {
+      w = NRAND(MAX_SIDES);
+    } while (tp->frozen_wall[w]);
+    tp->curPolyomino.xpos += w * WELL_WIDTH;
+  } else {
+    tp->curPolyomino.xpos = NRAND(tp->ncols - tp->curPolyomino.size + 1);
+    /* tp->curPolyomino.xpos = (tp->ncols - tp->curPolyomino.size) / 2; */
+  }
 }
 
 static void
@@ -1107,22 +1275,28 @@ putBox(ModeInfo * mi)
       if ((y + j >= 0) && polytris[(int) tp->bonusNow].polyomino
         [tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
         if (tp->well) {
+          /* Set pieces and overlap them if necessary */
           int xi, yj;
 
           xi = (x + i) % WELL_PERIMETER;
           yj = y + j;
-          if (yj < WELL_DEPTH) {
-            tp->wall[yj][xi].pmid = polytris[(int) tp->bonusNow].polyomino
-              [tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i];
-            tp->wall[yj][xi].cid = tp->curPolyomino.color_number;
-            tp->frozen_wall[xi / WELL_WIDTH] = MAX_SIDES;
-          } else {
+          if (yj >= WELL_DEPTH) {
             int base_i, base_j;
 
             wall_to_base(&base_i, &base_j, xi, yj);
-            tp->base[base_j][base_i].pmid = polytris[(int) tp->bonusNow].polyomino
-              [tp->curPolyomino.polyomino_number].shape[j * tp->curPolyomino.size + i];
+            xi = checkWall(rotateIndex(curPixmap(tp, i, j), xi),
+              base_i, base_j);
+            if (!tp->base[base_j][base_i].pmid)
+              tp->base[base_j][base_i].pmid = xi;
+            else
+              tp->base[base_j][base_i].pmid &= xi;
             tp->base[base_j][base_i].cid = tp->curPolyomino.color_number;
+          } else {
+            tp->wall[yj][xi].pmid =
+              checkSides(checkBottom(rotateIndex(curPixmap(tp, i,
+              j), xi), xi, yj), xi);
+            tp->wall[yj][xi].cid = tp->curPolyomino.color_number;
+            tp->frozen_wall[xi / WELL_WIDTH] = MAX_SIDES;
           }
         } else {
           pos = (y + j) * tp->ncols + x + i;
@@ -1379,7 +1553,7 @@ fillLines(ModeInfo *mi)
   if (tp->well) {
     for (j = 0; j < WELL_DEPTH + WELL_WIDTH; j++)
       for (i = 0; i < WELL_PERIMETER; i++) {
-         drawBox(mi, /* 0, */
+         drawBox(mi, BITMAPS - 1, 
            LRAND() % polytris[(int) tp->bonusNow].mode.number,
                  i, j);
          XFlush(display);
@@ -1443,20 +1617,24 @@ free_tetris(Display *display, trisstruct *tp)
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
       (void) free((void *) tp->colors);
-      tp->colors = NULL;
+      tp->colors = (XColor *) NULL;
     }
     if (tp->cmap != None) {
       XFreeColormap(display, tp->cmap);
       tp->cmap = None;
     }
   }
-  if (tp->gc != NULL) {
+  if (tp->gc != None) {
      XFreeGC(display, tp->gc);
-     tp->gc = NULL;
+     tp->gc = None;
+  }
+  if (tp->graypix != None) {
+    XFreePixmap(display, tp->graypix);
+    tp->graypix = None;
   }
   if (tp->field != NULL) {
      (void) free((void *) tp->field);
-     tp->field = NULL;
+     tp->field = (fieldstruct *) NULL;
   }
   free_images(tp);
 }
@@ -1470,10 +1648,11 @@ checkLines(ModeInfo *mi)
 
   if (tp->well) {
     int             lSet[2][WELL_WIDTH], nset[2];
-    int             i, j, k;
+    int             i, j, k, *tmp;
 
     nset[0] = nset[1] = 0;
 
+    /* Find filled rows */
     for (j = 0; j < WELL_WIDTH; j++) {
       lSet[0][j] = 0;
       for (i = 0; i < WELL_WIDTH; i++)
@@ -1482,6 +1661,7 @@ checkLines(ModeInfo *mi)
       if (lSet[0][j] == WELL_WIDTH)
         nset[0] ++;
     }
+    /* Find filled columns */
     for (i = 0; i < WELL_WIDTH; i++) {
       lSet[1][i] = 0;
       for (j = 0; j < WELL_WIDTH; j++)
@@ -1508,13 +1688,21 @@ checkLines(ModeInfo *mi)
         for (j = 0; j < WELL_WIDTH; j++)
           for (i = 0; i < WELL_WIDTH; i++)
             temp_base[j][i] = tp->base[j][i];
-        if (nset[0] > 0) {
+        if (nset[0]) {
           for (j = 0; j < WELL_WIDTH / 2; j++)
             if (lSet[0][j] == WELL_WIDTH)
               for (i = 0; i < WELL_WIDTH; i++) {
                 for (k = j; k > 0; k--)
                   temp_base[k][i] = temp_base[k - 1][i];
                 temp_base[0][i].pmid = EMPTY;
+                if (j > 0) {
+                  tmp = &temp_base[j][i].pmid;
+                  if (*tmp >= 0)
+                     *tmp = CHECKDOWN((unsigned int) *tmp);
+                }
+                tmp = &temp_base[j + 1][i].pmid;
+                if (*tmp >= 0)
+                   *tmp = CHECKUP((unsigned int) *tmp);
               }
           for (j = WELL_WIDTH - 1; j >= WELL_WIDTH / 2; j--)
             if (lSet[0][j] == WELL_WIDTH)
@@ -1522,15 +1710,31 @@ checkLines(ModeInfo *mi)
                 for (k = j; k < WELL_WIDTH - 1; k++)
                   temp_base[k][i] = temp_base[k + 1][i];
                 temp_base[WELL_WIDTH - 1][i].pmid = EMPTY;
+                if (j < WELL_WIDTH - 1) {
+                  tmp = &temp_base[j][i].pmid;
+                  if (*tmp >= 0)
+                     *tmp = CHECKUP((unsigned int) *tmp);
+                }
+                tmp = &temp_base[j - 1][i].pmid;
+                if (*tmp >= 0)
+                   *tmp = CHECKDOWN((unsigned int) *tmp);
               }
         }
-        if (nset[1] > 0) {
+        if (nset[1]) {
           for (i = 0; i < WELL_WIDTH / 2; i++)
             if (lSet[1][i] == WELL_WIDTH)
               for (j = 0; j < WELL_WIDTH; j++) {
                 for (k = i; k > 0; k--)
                   temp_base[j][k] = temp_base[j][k - 1];
                 temp_base[j][0].pmid = EMPTY;
+                if (i > 0) {
+                  tmp = &temp_base[j][i].pmid;
+                  if (*tmp >= 0)
+                     *tmp = CHECKRIGHT((unsigned int) *tmp);
+                }
+                tmp = &temp_base[j][i + 1].pmid;
+                if (*tmp >= 0)
+                   *tmp = CHECKLEFT((unsigned int) *tmp);
               }
           for (i = WELL_WIDTH - 1; i >= WELL_WIDTH / 2; i--)
             if (lSet[1][i] == WELL_WIDTH)
@@ -1538,6 +1742,14 @@ checkLines(ModeInfo *mi)
                 for (k = i; k < WELL_WIDTH - 1; k++)
                   temp_base[j][k] = temp_base[j][k + 1];
                 temp_base[j][WELL_WIDTH - 1].pmid = EMPTY;
+                if (i < WELL_WIDTH - 1) {
+                  tmp = &temp_base[j][i].pmid;
+                  if (*tmp >= 0)
+                     *tmp = CHECKLEFT((unsigned int) *tmp);
+                }
+                tmp = &temp_base[j][i - 1].pmid;
+                if (*tmp >= 0)
+                   *tmp = CHECKRIGHT((unsigned int) *tmp);
               }
         }
         for (j = 0; j < WELL_WIDTH; j++)
@@ -1550,9 +1762,7 @@ checkLines(ModeInfo *mi)
                 drawSquare(mi, tp->base[j][i].pmid, tp->base[j][i].cid, i, j);
               else
                 clearSquare(mi, i, j);
-              XFlush(display);
             }
-
        XFlush(display);
     }
 
@@ -1576,7 +1786,8 @@ checkLines(ModeInfo *mi)
       for (i = 0; i < ((NUM_FLASHES / nset) % 2) * 2; i++) {
         for (j = 0; j < tp->nrows; j++) {
           if (lSet[j] == tp->ncols)
-            xorSquare(mi, i, j);
+            for (i = 0; i < tp->ncols; i++)
+              xorSquare(mi, i, j);
         }
         XFlush(display);
       }
@@ -1901,7 +2112,7 @@ release_tetris(ModeInfo * mi) {
     for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
        free_tetris(MI_DISPLAY(mi), &triss[screen]);
     (void) free((void *) triss);
-    triss = NULL;
+    triss = (trisstruct *) NULL;
     for (bonustype = 0; bonustype < 2; bonustype++) {
       if (polytris[bonustype].polyomino != NULL) {
         for (number = 0; number < max_ominoes[bonustype]; number++) {
@@ -1909,11 +2120,11 @@ release_tetris(ModeInfo * mi) {
             (void) free((void *) polytris[bonustype].polyomino[number].shape);
         }
         (void) free((void *) polytris[bonustype].polyomino);
-        polytris[bonustype].polyomino = NULL;
+        polytris[bonustype].polyomino = (Polyominoes *) NULL;
       }
       if (polytris[bonustype].mode.start != NULL) {
         (void) free((void *) polytris[bonustype].mode.start);
-        polytris[bonustype].mode.start = NULL;
+        polytris[bonustype].mode.start = (int *) NULL;
       }
     }
   }
@@ -1932,6 +2143,11 @@ change_tetris(ModeInfo * mi) {
   tryMove(mi, ROTATE);
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
+
 void
 init_tetris(ModeInfo * mi) {
   Display *   display = MI_DISPLAY(mi);
@@ -1980,9 +2196,6 @@ init_tetris(ModeInfo * mi) {
       XColor      color;
 
 #ifndef STANDALONE
-      extern char *background;
-      extern char *foreground;
-
       tp->fg = MI_FG_PIXEL(mi);
       tp->bg = MI_BG_PIXEL(mi);
 #endif
@@ -2007,7 +2220,7 @@ init_tetris(ModeInfo * mi) {
       (void) XAllocColor(display, tp->cmap, &color);
       MI_FG_PIXEL(mi) = color.pixel;
 #endif
-      tp->colors = NULL;
+      tp->colors = (XColor *) NULL;
       tp->ncolors = 0;
     }
     if ((tp->gc = XCreateGC(display, MI_WINDOW(mi),
@@ -2055,7 +2268,7 @@ init_tetris(ModeInfo * mi) {
         ((tp->well) ? 3 * MINGRIDSIZE : MINGRIDSIZE)));
     tp->xs = tp->ys;
   }
-  if (tp->ys >= MAXPIXELSIZE && !tp->well) {
+  if (tp->ys >= MAXPIXELSIZE) {
     tp->xs = tp->ys = (tp->ys / 12) * 12;
     if (!create_images(mi, tp)) {
       free_images(tp);
@@ -2065,6 +2278,11 @@ init_tetris(ModeInfo * mi) {
   } else
     tp->pixelmode = True;
   if (tp->well) {
+    if ((tp->graypix = XCreateBitmapFromData(display, window,
+         (char *) gray1_bits, gray1_width, gray1_height)) == None) {
+      free_tetris(display, tp);
+      return;
+    }
     tp->ncols = MAX_SIDES * WELL_WIDTH;
     tp->nrows = WELL_DEPTH;
     tp->xb = tp->width / 2 - tp->xs * WELL_WIDTH / 2;
@@ -2112,7 +2330,7 @@ init_tetris(ModeInfo * mi) {
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
       (void) free((void *) tp->colors);
-      tp->colors = NULL;
+      tp->colors = (XColor *) NULL;
     }
     tp->ncolors = MI_NCOLORS(mi);
     if (tp->ncolors < 2)
@@ -2123,7 +2341,7 @@ init_tetris(ModeInfo * mi) {
       tp->mono_p = False;
 
     if (tp->mono_p)
-      tp->colors = NULL;
+      tp->colors = (XColor *) NULL;
     else
       if ((tp->colors = (XColor *) malloc(sizeof (*tp->colors) *
           (tp->ncolors + 1))) == NULL) {
@@ -2269,7 +2487,6 @@ moveOne(ModeInfo *mi, move_t move)
         }
       }
     }
-    newPolyomino(mi);
     XFlush(display);
     if (tp->well) {
       if (allFrozen(mi)) {
@@ -2277,6 +2494,9 @@ moveOne(ModeInfo *mi, move_t move)
         init_tetris(mi);
         return False;
       }
+    }
+    newPolyomino(mi);
+    if (tp->well) {
       checkFreeze(mi);
     }
     if (overlapping(mi)) {
