@@ -53,7 +53,7 @@ ModeSpecOpt thornbird_opts =
 #ifdef USE_MODULES
 ModStruct   thornbird_description =
 {"thornbird", "init_thornbird", "draw_thornbird", "release_thornbird",
- "refresh_thornbird", "init_thornbird", NULL, &thornbird_opts,
+ "refresh_thornbird", "init_thornbird", (char *) NULL, &thornbird_opts,
  1000, 800, 16, 1, 64, 1.0, "",
  "Shows an animated Bird in a Thorn Bush fractal map", 0, NULL};
 
@@ -88,7 +88,7 @@ typedef struct {
 	XPoint    **pointBuffer;	/* pointer for XDrawPoints */
 } thornbirdstruct;
 
-static thornbirdstruct *thornbirds = NULL;
+static thornbirdstruct *thornbirds = (thornbirdstruct *) NULL;
 
 static void
 free_thornbird(thornbirdstruct *hp)
@@ -100,7 +100,7 @@ free_thornbird(thornbirdstruct *hp)
 			if (hp->pointBuffer[buffer] != NULL)
 				(void) free((void *) hp->pointBuffer[buffer]);
 		(void) free((void *) hp->pointBuffer);
-		hp->pointBuffer = NULL;
+		hp->pointBuffer = (XPoint **) NULL;
 	}
 }
 
@@ -256,7 +256,7 @@ release_thornbird(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_thornbird(&thornbirds[screen]);
 		(void) free((void *) thornbirds);
-		thornbirds = NULL;
+		thornbirds = (thornbirdstruct *) NULL;
 	}
 }
 
