@@ -88,7 +88,7 @@ ModeSpecOpt tik_tak_opts =
 #ifdef USE_MODULES
 ModStruct   tik_tak_description =
 {"tik_tak", "init_tik_tak", "draw_tik_tak", "release_tik_tak",
- "refresh_tik_tak", "init_tik_tak", NULL, &tik_tak_opts,
+ "refresh_tik_tak", "init_tik_tak", (char *) NULL, &tik_tak_opts,
  60000, -20, 200, -1000, 64, 1.0, "",
  "Shows rotating polygons", 0, NULL};
 
@@ -120,7 +120,7 @@ typedef struct {
 	ModeInfo   *mi;
 } tik_takstruct;
 
-static tik_takstruct *tik_taks = NULL;
+static tik_takstruct *tik_taks = (tik_takstruct *) NULL;
 
 static void
 tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
@@ -229,7 +229,7 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
 			(void) free((void *) tiktak->colors);
-			tiktak->colors = NULL;
+			tiktak->colors = (XColor *) NULL;
 		}
 		if (tiktak->cmap != None) {
 			XFreeColormap(display, tiktak->cmap);
@@ -253,104 +253,14 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 				(void) free((void *) object0->xy);
 		}
 		(void) free((void *) tiktak->object);
-		tiktak->object = NULL;
+		tiktak->object = (tik_takobject *) NULL;
 	 }
 }
 
-void
-draw_tik_tak(ModeInfo * mi)
-{
-	Display    *display = MI_DISPLAY(mi);
-	int         i;
-	tik_takstruct *tiktak;
-
-	if (tik_taks == NULL)
-		return;
-	tiktak = &tik_taks[MI_SCREEN(mi)];
-	if (tiktak->object == NULL)
-		return;
-
-	if (tiktak->no_colors) {
-		free_tik_tak(display, tiktak);
-		init_tik_tak(mi);
-		return;
-	}
-	tiktak->painted = True;
-	MI_IS_DRAWN(mi) = True;
-	XSetFunction(display, tiktak->gc, GXxor);
-
-/* Rotate colours */
-	if (tiktak->cycle_p) {
-		rotate_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors,
-			      tiktak->direction);
-		if (!(LRAND() % 1000))
-			tiktak->direction = -tiktak->direction;
-	}
-	for (i = 0; i < tiktak->num_object; i++) {
-		tik_takobject *object0;
-
-		object0 = &tiktak->object[i];
-		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
-			XSetForeground(display, tiktak->gc, tiktak->colors[object0->colour].pixel);
-		} else {
-			XSetForeground(display, tiktak->gc, object0->colour);
-		}
-		object0->velocity_a += ((float) NRAND(1001) - 500.0) / 200000.0;
-		object0->angle += object0->velocity_a;
-		object0->velocity_a1 += ((float) NRAND(1001) - 500.0) / 200000.0;
-		object0->angle1 += object0->velocity_a1;
-		tik_tak_setupobject( mi , object0);
-		tik_tak_drawobject(mi, object0 );
-	}
-	XSetFunction(display, tiktak->gc, GXcopy);
-}
-
-void
-refresh_tik_tak(ModeInfo * mi)
-{
-	Display    *display = MI_DISPLAY(mi);
-	int         i;
-	tik_takstruct *tiktak;
-
-	if (tik_taks == NULL)
-		return;
-	tiktak = &tik_taks[MI_SCREEN(mi)];
-	if (tiktak->object == NULL)
-		return;
-
-	if (!tiktak->painted)
-		return;
-	MI_CLEARWINDOW(mi);
-	XSetFunction(display, tiktak->gc, GXxor);
-
-	for (i = 0; i < tiktak->num_object; i++) {
-		tik_takobject *object0;
-
-		object0 = &tiktak->object[i];
-		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
-			XSetForeground(display, tiktak->gc, tiktak->colors[object0->colour].pixel);
-		} else {
-			XSetForeground(display, tiktak->gc, object0->colour);
-		}
-		tik_tak_setupobject( mi , object0);
-		tik_tak_reset_object( object0);
-		tik_tak_drawobject(mi, object0 );
-	}
-	XSetFunction(display, tiktak->gc, GXcopy);
-}
-
-void
-release_tik_tak(ModeInfo * mi)
-{
-	if (tik_taks != NULL) {
-		int         screen;
-
-		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_tik_tak(MI_DISPLAY(mi), &tik_taks[screen]);
-		(void) free((void *) tik_taks);
-		tik_taks = NULL;
-	}
-}
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
 
 void
 init_tik_tak(ModeInfo * mi)
@@ -374,9 +284,6 @@ init_tik_tak(ModeInfo * mi)
 			XColor      color;
 
 #ifndef STANDALONE
-			extern char *background;
-			extern char *foreground;
-
 			tiktak->fg = MI_FG_PIXEL(mi);
 			tiktak->bg = MI_BG_PIXEL(mi);
 #endif
@@ -402,7 +309,7 @@ init_tik_tak(ModeInfo * mi)
 			(void) XAllocColor(display, tiktak->cmap, &color);
 			MI_FG_PIXEL(mi) = color.pixel;
 #endif
-			tiktak->colors = NULL;
+			tiktak->colors = (XColor *) NULL;
 			tiktak->ncolors = 0;
 		}
 		if ((tiktak->gc = XCreateGC(display, MI_WINDOW(mi),
@@ -455,7 +362,7 @@ init_tik_tak(ModeInfo * mi)
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
 			(void) free((void *) tiktak->colors);
-			tiktak->colors = NULL;
+			tiktak->colors = (XColor *) NULL;
 		}
 		tiktak->ncolors = MI_NCOLORS(mi);
 		if (tiktak->ncolors < 2)
@@ -466,7 +373,7 @@ init_tik_tak(ModeInfo * mi)
 			tiktak->mono_p = False;
 
 		if (tiktak->mono_p)
-			tiktak->colors = NULL;
+			tiktak->colors = (XColor *) NULL;
 		else
 			if ((tiktak->colors = (XColor *) malloc(sizeof (*tiktak->colors) *
 					(tiktak->ncolors + 1))) == NULL) {
@@ -574,7 +481,7 @@ init_tik_tak(ModeInfo * mi)
 	     {
 		object0->inner = False;
 		if ( object0->xy1 != NULL ) free( object0->xy1 );
-		object0->xy1 = NULL;
+		object0->xy1 = (XPoint *) NULL;
 	     }
 	   else
 	     {
@@ -607,4 +514,99 @@ init_tik_tak(ModeInfo * mi)
 	XSetFunction(display, tiktak->gc, GXcopy);
 }
 
+void
+draw_tik_tak(ModeInfo * mi)
+{
+	Display    *display = MI_DISPLAY(mi);
+	int         i;
+	tik_takstruct *tiktak;
+
+	if (tik_taks == NULL)
+		return;
+	tiktak = &tik_taks[MI_SCREEN(mi)];
+	if (tiktak->object == NULL)
+		return;
+
+	if (tiktak->no_colors) {
+		free_tik_tak(display, tiktak);
+		init_tik_tak(mi);
+		return;
+	}
+	tiktak->painted = True;
+	MI_IS_DRAWN(mi) = True;
+	XSetFunction(display, tiktak->gc, GXxor);
+
+/* Rotate colours */
+	if (tiktak->cycle_p) {
+		rotate_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors,
+			      tiktak->direction);
+		if (!(LRAND() % 1000))
+			tiktak->direction = -tiktak->direction;
+	}
+	for (i = 0; i < tiktak->num_object; i++) {
+		tik_takobject *object0;
+
+		object0 = &tiktak->object[i];
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XSetForeground(display, tiktak->gc, tiktak->colors[object0->colour].pixel);
+		} else {
+			XSetForeground(display, tiktak->gc, object0->colour);
+		}
+		object0->velocity_a += ((float) NRAND(1001) - 500.0) / 200000.0;
+		object0->angle += object0->velocity_a;
+		object0->velocity_a1 += ((float) NRAND(1001) - 500.0) / 200000.0;
+		object0->angle1 += object0->velocity_a1;
+		tik_tak_setupobject( mi , object0);
+		tik_tak_drawobject(mi, object0 );
+	}
+	XSetFunction(display, tiktak->gc, GXcopy);
+}
+
+void
+refresh_tik_tak(ModeInfo * mi)
+{
+	Display    *display = MI_DISPLAY(mi);
+	int         i;
+	tik_takstruct *tiktak;
+
+	if (tik_taks == NULL)
+		return;
+	tiktak = &tik_taks[MI_SCREEN(mi)];
+	if (tiktak->object == NULL)
+		return;
+
+	if (!tiktak->painted)
+		return;
+	MI_CLEARWINDOW(mi);
+	XSetFunction(display, tiktak->gc, GXxor);
+
+	for (i = 0; i < tiktak->num_object; i++) {
+		tik_takobject *object0;
+
+		object0 = &tiktak->object[i];
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XSetForeground(display, tiktak->gc, tiktak->colors[object0->colour].pixel);
+		} else {
+			XSetForeground(display, tiktak->gc, object0->colour);
+		}
+		tik_tak_setupobject( mi , object0);
+		tik_tak_reset_object( object0);
+		tik_tak_drawobject(mi, object0 );
+	}
+	XSetFunction(display, tiktak->gc, GXcopy);
+}
+
+void
+release_tik_tak(ModeInfo * mi)
+{
+	if (tik_taks != NULL) {
+		int         screen;
+
+		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
+			free_tik_tak(MI_DISPLAY(mi), &tik_taks[screen]);
+		(void) free((void *) tik_taks);
+		tik_taks = (tik_takstruct *) NULL;
+	}
+}
+
 #endif /* MODE_tik_tak */
