@@ -74,7 +74,7 @@ ModeSpecOpt triangle_opts =
 #ifdef USE_MODULES
 ModStruct   triangle_description =
 {"triangle", "init_triangle", "draw_triangle", "release_triangle",
- "refresh_triangle", "init_triangle", NULL, &triangle_opts,
+ "refresh_triangle", "init_triangle", (char *) NULL, &triangle_opts,
  10000, 1, 1, 1, 64, 1.0, "",
  "Shows a triangle mountain range", 0, NULL};
 
@@ -116,7 +116,7 @@ typedef struct {
 	Bool        joke;
 } trianglestruct;
 
-static trianglestruct *triangles = NULL;
+static trianglestruct *triangles = (trianglestruct *) NULL;
 
 static
 void
@@ -361,7 +361,7 @@ release_triangle(ModeInfo * mi)
 {
 	if (triangles != NULL) {
 		(void) free((void *) triangles);
-		triangles = NULL;
+		triangles = (trianglestruct *) NULL;
 	}
 }
 
