@@ -50,7 +50,7 @@ ModeSpecOpt turtle_opts =
 #ifdef USE_MODULES
 ModStruct   turtle_description =
 {"turtle", "init_turtle", "draw_turtle", "release_turtle",
- "init_turtle", "init_turtle", NULL, &turtle_opts,
+ "init_turtle", "init_turtle", (char *) NULL, &turtle_opts,
  1000000, 1, 20, 1, 64, 1.0, "",
  "Shows turtle fractals", 0, NULL};
 
@@ -88,7 +88,7 @@ typedef struct {
 	int         sign;
 } turtlestruct;
 
-static turtlestruct *turtles = NULL;
+static turtlestruct *turtles = (turtlestruct *) NULL;
 
 static void
 generate_hilbert(ModeInfo * mi, int r1, int r2)
@@ -409,7 +409,7 @@ release_turtle(ModeInfo * mi)
 {
 	if (turtles != NULL) {
 		(void) free((void *) turtles);
-		turtles = NULL;
+		turtles = (turtlestruct *) NULL;
 	}
 }
 
