@@ -78,7 +78,7 @@ ModeSpecOpt voters_opts =
 #ifdef USE_MODULES
 ModStruct   voters_description =
 {"voters", "init_voters", "draw_voters", "release_voters",
- "refresh_voters", "init_voters", NULL, &voters_opts,
+ "refresh_voters", "init_voters", (char *) NULL, &voters_opts,
  1000, 0, 327670, 0, 64, 1.0, "",
  "Shows Dewdney's Voters", 0, NULL};
 
@@ -146,7 +146,7 @@ static char plots[NEIGHBORKINDS] =
 	3, 4, 6, 8, 9, 12	/* Neighborhoods */
 };
 
-static voterstruct *voters = NULL;
+static voterstruct *voters = (voterstruct *) NULL;
 static int  icon_width, icon_height;
 
 static void
@@ -257,8 +257,8 @@ init_list(voterstruct * vp)
 	    ((vp->first = (CellList *) malloc(sizeof (CellList))) == NULL)) {
 		return False;
 	}
-	vp->first->previous = vp->last->next = NULL;
-	vp->first->next = vp->last->previous = NULL;
+	vp->first->previous = vp->last->next = (struct _CellList *) NULL;
+	vp->first->next = vp->last->previous = (struct _CellList *) NULL;
 	vp->first->next = vp->last;
 	vp->last->previous = vp->first;
 	return True;
@@ -583,15 +583,15 @@ free_voters(voterstruct *vp)
 	if (vp->first != NULL) {
 		flush_list(vp);
 		(void) free((void *) vp->first);
-		vp->first = NULL;
+		vp->first = (CellList *) NULL;
 	}
 	if (vp->last != NULL) {
 		(void) free((void *) vp->last);
-		vp->last = NULL;
+		vp->last = (CellList *) NULL;
 	}
 	if (vp->arr != NULL) {
 		(void) free((void *) vp->arr);
-		vp->arr = NULL;
+		vp->arr = (char *) NULL;
 	}
 }
 
@@ -853,7 +853,7 @@ release_voters(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_voters(&voters[screen]);
 		(void) free((void *) voters);
-		voters = NULL;
+		voters = (voterstruct *) NULL;
 	}
 }
 
