@@ -78,7 +78,7 @@ ModeSpecOpt wator_opts =
 #ifdef USE_MODULES
 ModStruct   wator_description =
 {"wator", "init_wator", "draw_wator", "release_wator",
- "refresh_wator", "init_wator", NULL, &wator_opts,
+ "refresh_wator", "init_wator", (char *) NULL, &wator_opts,
  750000, 1, 32767, 0, 64, 1.0, "",
  "Shows Dewdney's Water-Torus planet of fish and sharks", 0, NULL};
 
@@ -171,7 +171,7 @@ static char plots[NEIGHBORKINDS] =
 	3, 4, 6, 8, 9, 12	/* Neighborhoods */
 };
 
-static watorstruct *wators = NULL;
+static watorstruct *wators = (watorstruct *) NULL;
 static int  icon_width, icon_height;
 
 #if 0
@@ -313,8 +313,10 @@ init_kindlist(watorstruct * wp, int kind)
 			 NULL)) {
 		return False;
 	}
-	wp->firstkind[kind]->previous = wp->lastkind[kind]->next = NULL;
-	wp->firstkind[kind]->next = wp->lastkind[kind]->previous = NULL;
+	wp->firstkind[kind]->previous = wp->lastkind[kind]->next =
+		(struct _CellList *) NULL;
+	wp->firstkind[kind]->next = wp->lastkind[kind]->previous =
+		(struct _CellList *) NULL;
 	wp->firstkind[kind]->next = wp->lastkind[kind];
 	wp->lastkind[kind]->previous = wp->firstkind[kind];
 	return True;
@@ -630,16 +632,16 @@ free_wator(watorstruct *wp)
 		if (wp->firstkind[kind] != NULL) {
 			flush_kindlist(wp, kind);
 			(void) free((void *) wp->firstkind[kind]);
-			wp->firstkind[kind] = NULL;
+			wp->firstkind[kind] = (struct _CellList *) NULL;
 		}
 		if (wp->lastkind[kind] != NULL) {
 			(void) free((void *) wp->lastkind[kind]);
-			wp->lastkind[kind] = NULL;
+			wp->lastkind[kind] = (struct _CellList *) NULL;
 		}
 	}
 	if (wp->arr != NULL) {
 		(void) free((void *) wp->arr);
-		wp->arr = NULL;
+		wp->arr = (CellList **) NULL;
 	}
 }
 
@@ -726,7 +728,7 @@ init_wator(ModeInfo * mi)
 		wp->ncols = nccols / 2;
 		wp->nrows = 2 * (ncrows / 4);
 		wp->xb = (wp->width - wp->xs * nccols) / 2 + wp->xs / 2;
-		wp->yb = (wp->height - wp->ys * (ncrows / 2) * 2) / 2 + wp->ys;
+		wp->yb = (wp->height - wp->ys * (ncrows / 2) * 2) / 2 + wp->ys - 2;
 		for (sides = 0; sides < 6; sides++) {
 			wp->shape.hexagon[sides].x = (wp->xs - 1) * hexagonUnit[sides].x;
 			wp->shape.hexagon[sides].y =
@@ -975,7 +977,10 @@ draw_wator(ModeInfo * mi)
 					if (++(wp->currkind->info.age) >= wp->breed[wp->kind]) {	/* breed */
 						cutfrom_kindlist(wp);	/* This rotates out who goes first */
 						wp->babykind->info.age = 0;
-						dupin_kindlist(wp);
+						if (!dupin_kindlist(wp)) {
+							free_wator(wp);
+							return;
+						}
 						wp->arr[colrow] = wp->babykind;
 						wp->babykind->info.col = col;
 						wp->babykind->info.row = row;
@@ -1017,7 +1022,7 @@ release_wator(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_wator(&wators[screen]);
 		(void) free((void *) wators);
-		wators = NULL;
+		wators = (watorstruct *) NULL;
 	}
 }
 
