@@ -132,7 +132,7 @@ ModeSpecOpt wire_opts =
 #ifdef USE_MODULES
 ModStruct   wire_description =
 {"wire", "init_wire", "draw_wire", "release_wire",
- "refresh_wire", "init_wire", NULL, &wire_opts,
+ "refresh_wire", "init_wire", (char *) NULL, &wire_opts,
  500000, 1000, 150, -8, 64, 1.0, "",
  "Shows a random circuit with 2 electrons", 0, NULL};
 
@@ -190,7 +190,7 @@ typedef struct {
 static char plots[NEIGHBORKINDS] =
 {3, 4, 6, 8, 9, 12};		/* Neighborhoods */
 
-static circuitstruct *circuits = NULL;
+static circuitstruct *circuits = (circuitstruct *) NULL;
 
 static void
 position_of_neighbor(circuitstruct * wp, int dir, int *pcol, int *prow)
@@ -476,7 +476,7 @@ addtolist(ModeInfo * mi, int col, int row, unsigned char state)
 	circuitstruct *wp = &circuits[MI_SCREEN(mi)];
 	CellList   *current = wp->cellList[state];
 
-	wp->cellList[state] = NULL;
+	wp->cellList[state] = (CellList *) NULL;
 	if ((wp->cellList[state] = (CellList *) malloc(sizeof (CellList))) ==
 			NULL) {
 		return False;
@@ -754,11 +754,11 @@ free_wire(Display *display, circuitstruct *wp)
 	}
 	if (wp->oldcells != NULL) {
 		(void) free((void *) wp->oldcells);
-		wp->oldcells = NULL;
+		wp->oldcells = (unsigned char *) NULL;
 	}
 	if (wp->newcells != NULL) {
 		(void) free((void *) wp->newcells);
-		wp->newcells = NULL;
+		wp->newcells = (unsigned char *) NULL;
 	}
 	free_list(wp);
 }
@@ -772,7 +772,7 @@ release_wire(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_wire(MI_DISPLAY(mi), &circuits[screen]);
 		(void) free((void *) circuits);
-		circuits = NULL;
+		circuits = (circuitstruct *) NULL;
 	}
 }
 
@@ -938,7 +938,7 @@ init_wire(ModeInfo * mi)
 
 	if (wp->oldcells != NULL) {
 		(void) free((void *) wp->oldcells);
-		wp->oldcells = NULL;
+		wp->oldcells = (unsigned char *) NULL;
 	}
 	if ((wp->oldcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
 			sizeof (unsigned char))) == NULL) {
@@ -948,7 +948,7 @@ init_wire(ModeInfo * mi)
 
 	if (wp->newcells != NULL) {
 		(void) free((void *) wp->newcells);
-		wp->newcells = NULL;
+		wp->newcells = (unsigned char *) NULL;
 	}
 	if ((wp->newcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
 			sizeof (unsigned char))) == NULL) {
