@@ -47,12 +47,12 @@ static const char sccsid[] = "@(#)world.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_world
 
 ModeSpecOpt world_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   world_description =
 {"world", "init_world", "draw_world", "release_world",
- "refresh_world", "init_world", NULL, &world_opts,
+ "refresh_world", "init_world", (char *) NULL, &world_opts,
  100000, -16, 1, 1, 64, 0.3, "",
  "Shows spinning Earths", 0, NULL};
 
@@ -148,7 +148,7 @@ typedef struct {
 	planetstruct *planets;
 } worldstruct;
 
-static worldstruct *worlds = NULL;
+static worldstruct *worlds = (worldstruct *) NULL;
 
 void
 init_world(ModeInfo * mi)
@@ -282,7 +282,7 @@ release_world(ModeInfo * mi)
 			if (worlds[screen].planets != NULL)
 				(void) free((void *) worlds[screen].planets);
 		(void) free((void *) worlds);
-		worlds = NULL;
+		worlds = (worldstruct *) NULL;
 	}
 }
 
