@@ -68,7 +68,7 @@ ModeSpecOpt worm_opts =
 #ifdef USE_MODULES
 ModStruct   worm_description =
 {"worm", "init_worm", "draw_worm", "release_worm",
- "refresh_worm", "init_worm", NULL, &worm_opts,
+ "refresh_worm", "init_worm", (char *) NULL, &worm_opts,
  17000, -20, 10, -3, 64, 1.0, "",
  "Shows wiggly worms", 0, NULL};
 
@@ -114,7 +114,7 @@ static float sintab[SEGMENTS];
 static float costab[SEGMENTS];
 static int  init_table = 0;
 
-static wormstruct *worms = NULL;
+static wormstruct *worms = (wormstruct *) NULL;
 
 static void
 worm_doit(ModeInfo * mi, int which, unsigned long color)
@@ -266,15 +266,15 @@ free_worm(wormstruct * wp)
 				(void) free((void *) wp->worm[wn].diffcirc);
 		}
 		(void) free((void *) wp->worm);
-		wp->worm = NULL;
+		wp->worm = (wormstuff *) NULL;
 	}
 	if (wp->rects) {
 		(void) free((void *) wp->rects);
-		wp->rects = NULL;
+		wp->rects = (XRectangle *) NULL;
 	}
 	if (wp->size) {
 		(void) free((void *) wp->size);
-		wp->size = NULL;
+		wp->size = (int *) NULL;
 	}
 }
 
@@ -443,7 +443,7 @@ release_worm(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_worm(&worms[screen]);
 		(void) free((void *) worms);
-		worms = NULL;
+		worms = (wormstruct *) NULL;
 	}
 }
 
