@@ -114,7 +114,7 @@ ModeSpecOpt xcl_opts =
 #ifdef USE_MODULES    /* for xlockmore */
 ModStruct   xcl_description =
 {"xcl", "init_xcl", "draw_xcl", "release_xcl",
- "draw_xcl", "init_xcl", NULL, &xcl_opts ,
+ "draw_xcl", "init_xcl", (char *) NULL, &xcl_opts ,
  20000, -3, 1, 1, 64, 1.0, "",
  "Shows a control line combat model race", 0, NULL};
 #endif
@@ -157,7 +157,7 @@ typedef struct
   int no_preset;
 } xclstruct;
 
-static xclstruct *xcls = NULL;
+static xclstruct *xcls = (xclstruct *) NULL;
 
 static int my_random(void)  /* not really good, but it works */
 {
@@ -225,7 +225,7 @@ static void view_3d(XSegment *xseg, xclstruct *dp)
   }
 }
 
-static long get_color(Display *dpy,char *color,XColor *final_color)
+static long get_color(Display *dpy, char *color, XColor *final_color)
 {
   XColor cdef;
   Colormap cmap;
@@ -268,11 +268,11 @@ free_xcl(Display *display, xclstruct  *dp)
     for (plane = 0; plane < dp->planes; plane++) {
       if (dp->xseg[plane] != NULL) {
         (void) free((void *) dp->xseg[plane]);
-        dp->xseg[plane] = NULL;
+        dp->xseg[plane] = (XSegment *) NULL;
       }
       if (dp->xseg_old[plane] != NULL) {
         free(dp->xseg_old[plane]);
-        dp->xseg_old[plane] = NULL;
+        dp->xseg_old[plane] = (XSegment *) NULL;
       }
       if (dp->gc[plane] != None) {
         XFreeGC(display, dp->gc[plane]);
@@ -292,7 +292,7 @@ void release_xcl(ModeInfo * mi)
     for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
       free_xcl(MI_DISPLAY(mi), &xcls[screen]);
     (void) free((void *) xcls);
-    xcls = NULL;
+    xcls = (xclstruct *) NULL;
   }
 }
 
@@ -376,10 +376,12 @@ void init_xcl(ModeInfo * mi)
         for(i=0;i< dp->planes; i++) { 
           switch(i) {
           case 0:
-            dp->planecolor[0] = get_color(display, (char *) "yellow",NULL);
+            dp->planecolor[0] = get_color(display, (char *) "yellow",
+		(XColor *) NULL);
             break;
           case 1:
-            dp->planecolor[1] = get_color(display, (char *) "red",NULL);
+            dp->planecolor[1] = get_color(display, (char *) "red",
+		(XColor *) NULL);
             break;
           default:
             dp->planecolor[i] = MI_PIXEL(mi, NRAND(MI_NPIXELS(mi)));
