@@ -142,6 +142,12 @@ monoColormap(Screen * scr, ScreenInfo * si, char *foreground, char *background)
 	si->npixels = 2;
 }
 
+extern char *foreground;
+extern char *background;
+#ifdef USE_DTSAVER
+extern Bool dtsaver;
+#endif
+
 void
 fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	    Bool mono, Bool install, Bool inroot, Bool inwindow, Bool verbose)
@@ -152,15 +158,11 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	Colormap    cmap = MI_COLORMAP(mi);
 	Colormap    dcmap = DefaultColormapOfScreen(scr);
 	XColor      xcolor;
-	unsigned char *red, *green, *blue;
+	unsigned char *red = (unsigned char *) NULL,
+		*green = (unsigned char *) NULL,
+		*blue = (unsigned char *) NULL;
 	int         colorcount, i, fixed, visualclass;
-	extern char *foreground;
-	extern char *background;
 
-#ifdef USE_DTSAVER
-	extern Bool dtsaver;
-
-#endif
 #ifndef COMPLIANT_COLORMAP
 	Bool        retry = False;
 
@@ -506,8 +508,12 @@ make_color_ramp(Display * dpy, Colormap cmap,
 		return;
 
 	if (writable_p) {
-		unsigned long *pixels = (unsigned long *)
-		malloc(sizeof (unsigned long) * ((*ncolorsP) + 1));
+		unsigned long *pixels;
+
+		if ((pixels = (unsigned long *) malloc(sizeof (unsigned long) *
+				((*ncolorsP) + 1))) == NULL) {
+			goto FAIL;
+		}
 
 		/* allocate_writable_colors() won't do here, because we need exactly this
 		   number of cells, or the color sequence we've chosen won't fit. */
