@@ -14,10 +14,6 @@ static const char sccsid[] = "@(#)iostuff.c	4.10 98/10/23 xlockmore";
  * 23-Apr-98: Separated out of util.c
  *
  */
-#ifdef USE_MAGICK
-# include "magick.h"
-#endif
-
 #ifdef STANDALONE
 #include "utils.h"
 extern char *message, *messagefile, *messagesfile, *program;
@@ -34,6 +30,11 @@ char       *messagefontname;
 #include "mode.h"
 #include "iostuff.h"
 #include "random.h"
+#ifdef USE_MAGICK
+#undef inline
+#include "magick.h"
+#endif
+
 
 #include <X11/Xutil.h>
 #include <sys/stat.h>
@@ -53,16 +54,16 @@ readable(char *filename)
 FILE       *
 my_fopen(char *filename, const char *type)
 {
-	FILE       *fp = NULL;
+	FILE       *fp = (FILE *) NULL;
 	int         s;
 	struct stat fileStat;
 
 	s = stat(filename, &fileStat);
 	if ((s >= 0 && S_ISREG(fileStat.st_mode)) || (s < 0 && type[0] == 'w')) {
 		if ((fp = fopen(filename, type)) == NULL)
-			return NULL;
+			return (FILE *) NULL;
 	} else {
-		return NULL;
+		return (FILE *) NULL;
 	}
 
 	return fp;
@@ -186,22 +187,17 @@ get_dir(char *fullpath, char *dir, char *filename)
 		(void) printf("get_dir %s %s %s\n", fullpath, dir, filename);
 }
 
+extern char filename_r[MAXNAMLEN];
+
 /* Procedure to select the matching filenames  Author: J. Jansen */
 int
 sel_image(struct dirent *name)
 {
-	extern char filename_r[MAXNAMLEN];
 	char       *name_tmp = name->d_name;
 	char       *filename_tmp = filename_r;
-	int         numfrag = -1;
+	int         numfrag = -1, ip, i = -1;
 #define MAX_FRAGS 64
-#ifdef VMS
-   char *frags[MAX_FRAGS];
-#else
-   static char *frags[MAX_FRAGS];
-#endif
-
-	int         ip, i = -1;
+	char *frags[MAX_FRAGS];
 
 	if (numfrag == -1) {
 		++numfrag;
@@ -325,14 +321,14 @@ scan_dir(const char *directoryname, struct dirent ***namelist,
 #endif
 
 #if HAVE_DIRENT_H
+extern char directory_r[DIRBUF];
+extern struct dirent **image_list;
+extern int  num_list;
+
 static void
 getRandomFile(char *randomfile, char *randomfile_local)
 {
-	extern char directory_r[DIRBUF];
-	struct dirent ***images_list = NULL;
-	extern struct dirent **image_list;
-	extern int  num_list;
-	extern char filename_r[MAXNAMLEN];
+	struct dirent ***images_list = (struct dirent ***) NULL;
 
 	get_dir(randomfile, directory_r, filename_r);
 	if (image_list != NULL) {
@@ -343,7 +339,7 @@ getRandomFile(char *randomfile, char *randomfile_local)
 				(void) free((void *) image_list[i]);
 		}
 		(void) free((void *) image_list);
-		image_list = NULL;
+		image_list = (struct dirent **) NULL;
 	}
 	if ((images_list = (struct dirent ***) malloc(sizeof (struct dirent **))) != NULL) {
 		num_list = scan_dir(directory_r, images_list, sel_image, NULL);
@@ -354,7 +350,7 @@ getRandomFile(char *randomfile, char *randomfile_local)
 				randomfile_local);
 		} else if (num_list < 0) {
 			num_list = 0;
-			image_list = NULL;
+			image_list = (struct dirent **) NULL;
 		}
 	} else
 		num_list = 0;
@@ -394,7 +390,7 @@ getImage(ModeInfo * mi, XImage ** logo,
 	 unsigned long *black)
 {
 	Display    *display = MI_DISPLAY(mi);
-	static char *bitmap_local = NULL;
+	static char *bitmap_local = (char *) NULL;
 
 #ifndef STANDALONE
 #if defined( USE_XPM ) || defined( USE_XPMINC )
@@ -426,7 +422,7 @@ getImage(ModeInfo * mi, XImage ** logo,
 
 	if (bitmap_local != NULL) {
 		(void) free((void *) bitmap_local);
-		bitmap_local = NULL;
+		bitmap_local = (char *) NULL;
 	}
 	if (MI_BITMAP(mi) && strlen(MI_BITMAP(mi))) {
 #ifdef STANDALONE
@@ -560,12 +556,12 @@ destroyImage(XImage ** logo, int *graphics_format)
 {
 	switch (*graphics_format) {
 		case IS_XBM:
-			blogo.data = NULL;
+			blogo.data = (char *) NULL;
 			break;
 		case IS_XBMFILE:
 			if (blogo.data) {
 				(void) free((void *) blogo.data);
-				blogo.data = NULL;
+				blogo.data = (char *) NULL;
 			}
 			break;
 		case IS_XPM:
@@ -577,7 +573,7 @@ destroyImage(XImage ** logo, int *graphics_format)
 			break;
 	}
 	*graphics_format = -1;
-	*logo = NULL;
+	*logo = (XImage *) NULL;
 }
 
 void
@@ -619,11 +615,11 @@ getPixmap(ModeInfo * mi, Drawable drawable,
 	  int *graphics_format)
 {
 	Display    *display = MI_DISPLAY(mi);
-	static char *bitmap_local = NULL;
+	static char *bitmap_local = (char *) NULL;
 
 	if (bitmap_local) {
 		(void) free((void *) bitmap_local);
-		bitmap_local = NULL;
+		bitmap_local = (char *) NULL;
 	}
 	if (MI_BITMAP(mi) && strlen(MI_BITMAP(mi))) {
 #ifdef STANDALONE
@@ -648,11 +644,11 @@ getPixmap(ModeInfo * mi, Drawable drawable,
 char *
 getModeFont(char *infont)
 {
-	static char *localfont = NULL;
+	static char *localfont = (char *) NULL;
 
 	if (localfont != NULL) {
 		(void) free((void *) localfont);
-		localfont = NULL;
+		localfont = (char *) NULL;
 	}
 	if (infont && strlen(infont)) {
 #ifdef STANDALONE
@@ -661,7 +657,7 @@ getModeFont(char *infont)
 		if ((localfont = (char *) malloc(256)) == NULL) {
 			(void) fprintf(stderr , "no memory for \"%s\"\n" ,
 				infont);
-			return NULL;
+			return (char *) NULL;
 		}
 		(void) strncpy(localfont, infont, 256);
 #if HAVE_DIRENT_H
@@ -674,7 +670,7 @@ getModeFont(char *infont)
 		       "could not read file \"%s\"\n", localfont);
 		if (localfont) {
 			(void) free((void *) localfont);
-			localfont = NULL;
+			localfont = (char *) NULL;
 		}
 	}
 	return localfont;
@@ -704,23 +700,23 @@ isRibbon(void)
 	return (getwordsfrom == FROM_RESRC);
 }
 
-char       *
+#if !defined(__cplusplus) && !defined(c_plusplus)
+extern int  pclose(FILE *);
+#endif
+
+char *
 getWords(int screen, int screens)
 {
 	FILE       *pp;
-	static char *buf = NULL, progerr[BUFSIZ], progrun[BUFSIZ];
+	static char *buf = (char *) NULL, progerr[BUFSIZ], progrun[BUFSIZ];
 	register char *p;
 	int         i;
 
-#if !defined(__cplusplus) && !defined(c_plusplus)
-	extern int  pclose(FILE *);
-
-#endif
 
 	if (buf == NULL) {
 		if ((buf = (char *) calloc(screens * BUFSIZ,
 				sizeof (char))) == NULL)
-			return NULL;
+			return (char *) NULL;
 	}
 	p = &buf[screen * BUFSIZ];
 	*p = '\0';
