@@ -39,8 +39,13 @@
 #define IS_RASTERFILE 6
 #define IS_MAGICKFILE 7
 
-extern FILE *my_fopen(char *, const char *);
 
+#ifdef __cplusplus
+  extern "C" {
+#endif
+
+extern FILE *my_fopen(char *, const char *);
+int index_dir(char *str1, char *substr);
 extern void get_dir(char *fullpath, char *dir, char *filename);
 #if HAVE_DIRENT_H
 extern int  sel_image(struct dirent *name);
@@ -71,4 +76,9 @@ extern void getPixmap(ModeInfo * mi, Drawable drawable,
 		      int *width, int *height, Pixmap * pixmap,
 		      int *graphics_format);
 
+extern char * getModeFont(char *infont);
+#ifdef __cplusplus
+  }
+#endif
+
 #endif /* _FILE_H_ */
