@@ -504,11 +504,6 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_superquadrics
 #ifdef USE_UNSTABLE
 #define MODE_skewb /* under development */
-#ifdef HAVE_CXX
-#if defined( HAVE_TTF ) && defined( HAVE_GLTT )
-#define MODE_text3d
-#endif
-#endif
 #endif
 #define MODE_atlantis
 #define MODE_bubble3d
@@ -516,13 +511,16 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_sproingies
 #ifdef HAVE_CXX
 #define MODE_invert
+#if defined( HAVE_TTF ) && defined( HAVE_GLTT )
+#define MODE_text3d
+#endif
 #endif
 #endif
 #ifdef HAVE_CXX
 #define MODE_solitare
 #endif
 #ifdef USE_UNSTABLE
-#define MODE_run /* VMS problems as well as --debug problems */
+#define MODE_run /* VMS problems as well as -debug problems */
 #ifdef UNDER_DEVELOPMENT
 #if 0
 #ifdef HAVE_CXX
@@ -532,6 +530,7 @@ extern void release_last_mode(ModeInfo *);
 #endif
 #endif
 #define MODE_ant
+#define MODE_apollonian
 #define MODE_ball
 #define MODE_bat
 #define MODE_blot
@@ -648,6 +647,14 @@ extern ModeHook refresh_ant;
 extern ModeSpecOpt ant_opts;
 #endif
 
+#ifdef MODE_apollonian
+extern ModeHook init_apollonian;
+extern ModeHook draw_apollonian;
+extern ModeHook release_apollonian;
+extern ModeHook refresh_apollonian;
+extern ModeSpecOpt apollonian_opts;
+#endif
+
 #ifdef MODE_atlantis
 extern ModeHook init_atlantis;
 extern ModeHook draw_atlantis;
