@@ -53,6 +53,10 @@ extern Bool grabmouse;
 extern Bool nolock;
 extern char *cpasswd;
 
+#if defined( __CYGWIN__ )
+#include <crypt.h>
+#endif
+
 #if defined( USE_XLOCKRC ) || defined( FALLBACK_XLOCKRC )
 #include <sys/stat.h>		/* order of includes matters */
 #endif
@@ -61,11 +65,6 @@ extern char *cpasswd;
 #include <pwd.h>
 #endif
 
-#if defined( USE_XLOCKRC ) || defined( FALLBACK_XLOCKRC )  || defined( __bsdi__ ) || defined( HAVE_KRB4 ) || defined( HAVE_KRB5 )
-#include <sys/param.h>
-#endif
-
-
 #if defined( __bsdi__ ) && _BSDI_VERSION >= 199608
 #define       BSD_AUTH
 #endif
@@ -667,6 +666,8 @@ passwd_invalid(char *passwd)
 
 	return (i == 1 || i == 2);
 }
+
+extern Bool verbose, debug;
 #endif
 
 #ifdef OSF1_ENH_SEC
@@ -676,7 +677,6 @@ static int user_oldcrypt, root_oldcrypt;
 static void
 getCryptedUserPasswd(void)
 {
-
 #ifdef VMS
 	struct itmlst il[4];
 
@@ -788,8 +788,6 @@ getCryptedUserPasswd(void)
 #ifdef HAVE_SHADOW
 #if !defined ( AFS ) && !defined ( SIA )
 	if (passwd_invalid(pw->pw_passwd)) {
-		extern Bool verbose, debug;
-
 		buf = (char *) malloc(strlen(ProgramName) + 80);
 		if (verbose || debug) {
 			(void) fprintf(stderr,
