@@ -90,7 +90,11 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 
 #ifdef USE_MODULES
 # ifndef DEF_MODULEPATH
-#  define DEF_MODULEPATH "/usr/lib/X11/xlock_modules"
+#if 1
+#  define DEF_MODULEPATH "/usr/lib/X11/xlock/modules"
+#else
+#  define DEF_MODULEPATH "@PREFIX@/lib/X11/xlock/modules"
+#endif
 # endif
 #endif
 
@@ -255,9 +259,6 @@ static int  descr();
 #   define DEF_INVALIDSOUND	"[]not-programmed.au"
 #  endif /* !USE_VMSPLAY */
 #  ifdef USE_ESOUND
-#   ifndef DEFAULT_SOUND_DIR
-#    define DEFAULT_SOUND_DIR "/usr/share/sounds/xlockmore"
-#   endif
 #   define DEF_LOCKSOUND 	"thank-you.au"
 #   define DEF_INFOSOUND	"identify-please.au"
 #   define DEF_VALIDSOUND	"complete.au"
@@ -332,8 +333,8 @@ Bool        mouse;
 #endif
 
 char        hostname[MAXHOSTNAMELEN];
-static char *mode = NULL;
-char       *displayname = NULL;
+static char *mode = (char *) NULL;
+char       *displayname = (char *) NULL;
 static char *classname;
 static char *modename;
 static char *modeclassname;
@@ -342,9 +343,9 @@ static char *parentname;
 extern Bool parentSet;
 
 #if HAVE_DIRENT_H
-static struct dirent ***images_list = NULL;
+static struct dirent ***images_list = (struct dirent ***) NULL;
 int         num_list = 0;
-struct dirent **image_list = NULL;
+struct dirent **image_list = (struct dirent **) NULL;
 char        filename_r[MAXNAMLEN];
 char        directory_r[DIRBUF];
 
@@ -537,7 +538,7 @@ static XrmOptionDescRec cmdlineTable[] =
 	{(char *) "-dtsaver", (char *) ".dtsaver", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+dtsaver", (char *) ".dtsaver", XrmoptionNoArg, (caddr_t) "off"},
 #endif
-	{(char *) "-xrm", NULL, XrmoptionResArg, (caddr_t) NULL}
+	{(char *) "-xrm", (char *) NULL, XrmoptionResArg, (caddr_t) NULL}
 };
 
 #define cmdlineEntries (sizeof cmdlineTable / sizeof cmdlineTable[0])
@@ -1214,7 +1215,7 @@ GetResource(XrmDatabase database,
 	} else {
 		string = def;
 		if (!string || !*string) {
-			*valuep = NULL;
+			*valuep = (caddr_t) NULL;
 			return;
 		}
 		len = strlen(string);
@@ -1265,7 +1266,7 @@ static      XrmDatabase
 parsefilepath(char *xfilesearchpath, const char *typeName,
         char *className, char *customName)
 {
-	XrmDatabase database = NULL;
+	XrmDatabase database = (XrmDatabase) NULL;
 	char       *appdefaults;
 	char       *src;
 	char       *dst;
@@ -1477,16 +1478,14 @@ checkDisplay(void)
 
 #if defined(__cplusplus) || defined(c_plusplus)		/* !__bsdi__ */
 /* #include <netdb.h> */
-#if !HAVE_GETHOSTNAME
 #ifdef SunCplusplus
 	extern struct hostent *gethostbyname(const char *);
-
 #else
+#if !HAVE_GETHOSTNAME
 #if 0
 	extern int  gethostname(char *, size_t);
 	extern struct hostent *gethostbyname(const char *);
 
-#endif
 #endif
 #else
 #if 1
@@ -1495,6 +1494,7 @@ extern int  gethostname(char *, size_t);
 #define gethostname(name,namelen) sysinfo(SI_HOSTNAME,name,namelen)
 #endif
 #endif
+#endif
 #endif
 
 	/*
@@ -1669,10 +1669,10 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 {
 	char       *env;
 	char       *userpath;
-	char       *userfile = NULL;
-	XrmDatabase cmdlineDB = NULL;
-	XrmDatabase userDB = NULL;
-	XrmDatabase applicationDB = NULL;
+	char       *userfile = (char *) NULL;
+	XrmDatabase cmdlineDB = (XrmDatabase) NULL;
+	XrmDatabase userDB = (XrmDatabase) NULL;
+	XrmDatabase applicationDB = (XrmDatabase) NULL;
 
 	env = getenv("XFILESEARCHPATH");
 	applicationDB = parsefilepath(env ? env : (char *) DEF_FILESEARCHPATH,
@@ -1749,23 +1749,6 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 #endif
 }
 
-void
-getResources(Display ** displayp, int argc, char **argv)
-{
-	XrmDatabase RDB = NULL;
-
-#ifdef USE_MODULES
-	XrmDatabase modulepathDB = NULL;
-
-#endif
-	XrmDatabase serverDB = NULL;
-	XrmDatabase earlyCmdlineDB = NULL;
-	XrmDatabase modeDB = NULL;
-	XrmDatabase generalDB = NULL;
-	char       *custom = NULL;
-	char       *homeenv = NULL;
-	int         i, j;
-	int         max_length;
 extern void XlockrmParseCommand(
     XrmDatabase		*pdb,		/* data base */
     register XrmOptionDescList options, /* pointer to table of valid options */
@@ -1775,9 +1758,29 @@ extern void XlockrmParseCommand(
     char              **arg_v);		/* argument list (command line)	     */
 
 #if defined( USE_AUTO_LOGOUT ) || defined( USE_BUTTON_LOGOUT )
-	extern int  fullLock();
+extern int  fullLock();
 
 #endif
+extern int  erasemodefromname(char *name);
+
+
+void
+getResources(Display ** displayp, int argc, char **argv)
+{
+	XrmDatabase RDB = (XrmDatabase) NULL;
+
+#ifdef USE_MODULES
+	XrmDatabase modulepathDB = (XrmDatabase) NULL;
+
+#endif
+	XrmDatabase serverDB = (XrmDatabase) NULL;
+	XrmDatabase earlyCmdlineDB = (XrmDatabase) NULL;
+	XrmDatabase modeDB = (XrmDatabase) NULL;
+	XrmDatabase generalDB = (XrmDatabase) NULL;
+	char       *custom = (char *) NULL;
+	char       *homeenv = (char *) NULL;
+	int         i, j;
+	int         max_length;
 
 	XrmInitialize();
 
@@ -1834,7 +1837,7 @@ extern void XlockrmParseCommand(
 			&argc, argv);
 	(void) XrmMergeDatabases(modulepathDB, &RDB);
 	GetResource(RDB, ProgramName, classname, "modulepath", "Modulepath",
-		    t_String, DEF_MODULEPATH, &modulepath);
+		    t_String, (char *) DEF_MODULEPATH, &modulepath);
 
 	/* read modules from modules directory */
 	atexit(UnloadModules);	/* make sure modules get unloaded */
@@ -1861,7 +1864,7 @@ extern void XlockrmParseCommand(
 
 	for (i = 0; i < numprocs; i++) {
 		/* if (!strcmp(mode, LockProcs[i].cmdline_arg)) */
-		XrmDatabase optDB = NULL;
+		XrmDatabase optDB = (XrmDatabase) NULL;
 		ModeSpecOpt *ms = LockProcs[i].msopt;
 
 		if (!ms->numopts)
@@ -1880,7 +1883,7 @@ extern void XlockrmParseCommand(
 	}
 	for (i = 0; i < numprocs; i++) {
 		/* if (!strcmp(mode, LockProcs[i].cmdline_arg)) */
-		XrmDatabase nullDB = NULL;
+		XrmDatabase nullDB = (XrmDatabase) NULL;
 		ModeSpecOpt *ms = LockProcs[i].msopt;
 
 		if (!ms->numopts)
@@ -1949,7 +1952,7 @@ extern void XlockrmParseCommand(
 		(void) sprintf(modename, "%s.%s", ProgramName, LockProcs[i].cmdline_arg);
 		(void) sprintf(modeclassname, "%s.%s", classname, LockProcs[i].cmdline_arg);
 		for (j = 0; j < (int) NMODEARGS; j++) {
-			char       *buf = NULL;
+			char       *buf = (char *) NULL;
 			void       *p = (void *) ((char *) (&LockProcs[i]) + modevaroffs[j]);
 
 			switch (modevars[j].type) {
@@ -1980,7 +1983,7 @@ extern void XlockrmParseCommand(
 			}
 			if (buf) {
 				(void) free((void *) buf);
-				buf = NULL;
+				buf = (char *) NULL;
 			}
 		}
 		if (!ms->numvarsdesc)
@@ -2087,8 +2090,6 @@ extern void XlockrmParseCommand(
 		if (verbose)
 			(void) fprintf(stderr, "Using random erase mode\n");
 	} else {
-		extern int  erasemodefromname(char *name);
-
 		erasemode = erasemodefromname(erasemodename);
 		if (verbose)
 			(void) fprintf(stderr, "Using erase mode %s\n",
@@ -2106,7 +2107,7 @@ extern void XlockrmParseCommand(
 					(void) free((void *) image_list[num]);
 			}
 			(void) free((void *) image_list);
-			image_list = NULL;
+			image_list = (struct dirent **) NULL;
 		}
 		images_list = (struct dirent ***) malloc(sizeof (struct dirent **));
 
@@ -2114,13 +2115,13 @@ extern void XlockrmParseCommand(
 		image_list = *images_list;
 		if (images_list) {
 			(void) free((void *) images_list);
-			images_list = NULL;
+			images_list = (struct dirent ***) NULL;
 		}
 		if (debug)
 			for (i = 0; i < num_list; i++)
 				(void) printf("File number %d: %s\n", i, image_list[i]->d_name);
 		if (num_list < 0) {
-			image_list = NULL;
+			image_list = (struct dirent **) NULL;
 			num_list = 0;
 		}
 	} else {
@@ -2131,11 +2132,11 @@ extern void XlockrmParseCommand(
 	(void) free((void *) modeclassname);
 }
 
+extern char * old_default_mode;
 
 void
 checkResources(void)
 {
-	extern char * old_default_mode;
 	int         i;
 
 	/* in case they have a 'xlock*mode: ' empty resource */
