@@ -154,13 +154,16 @@ play_sound(char *filename, Bool verbose)
 #ifdef USE_ESOUND
 
 #ifndef DEFAULT_SOUND_DIR
-#define DEFAULT_SOUND_DIR "/usr/share/sounds/xlockmore/"
+#if 1
+#define DEFAULT_SOUND_DIR "/usr/lib/X11/xlock/sounds/"
+#else
+#define DEFAULT_SOUND_DIR "@PREFIX@/lib/X11/xlock/sounds/"
+#endif
 #endif
 
 #ifdef HAVE_LIBESD
 
 #include <sys/stat.h>
-#include <sys/param.h>
 #include <esd.h>
 
 #else
@@ -217,6 +220,17 @@ void shutdown_sound(void)
     sound_esd_shutdown();
 }
 
+/* Found this snippet from modes/glx/xpm-image.c by way of
+   Jamie Zawinski <jwz@jwz.org> Copyright (c) 1998 */
+static Bool
+bigendian (void)
+{
+  union { int i; char c[sizeof(int)]; } u;
+  u.i = 1;
+  return !u.c[0];
+}
+
+
 /*
  * Private ESOUND sound functions
  * ==============================
@@ -295,11 +309,8 @@ sound_esd_load_sample(char *file)
    in_channels = afGetChannels(in_file, AF_DEFAULT_TRACK);
    in_rate = afGetRate(in_file, AF_DEFAULT_TRACK);
    afGetSampleFormat(in_file, AF_DEFAULT_TRACK, &in_format, &in_width);
-#ifdef WORDS_BIGENDIAN
-   afSetVirtualByteOrder(in_file, AF_DEFAULT_TRACK, AF_BYTEORDER_BIGENDIAN);
-#else
-   afSetVirtualByteOrder(in_file, AF_DEFAULT_TRACK, AF_BYTEORDER_LITTLEENDIAN);
-#endif
+   afSetVirtualByteOrder(in_file, AF_DEFAULT_TRACK, (bigendian()) ?
+	AF_BYTEORDER_BIGENDIAN : AF_BYTEORDER_LITTLEENDIAN);
    s->file = strdup(origfile);
    s->rate = 44100;
    s->format = ESD_STREAM | ESD_PLAY;
