@@ -317,16 +317,18 @@ Setup_Widget(Widget father)
  */
 		ac = 0;
 #ifndef USE_MB
-		label_str = XmStringCreate("Exit", XmSTRING_DEFAULT_CHARSET);
+		label_str = XmStringCreate((char *) "Exit",
+			XmSTRING_DEFAULT_CHARSET);
 		XtSetArg(args[ac], XmNlabelString, label_str);
 		ac++;
 #endif
-		exitwidgetB = XmCreatePushButton(PushButtonRow, "Exit",
-						    args, ac);
+		exitwidgetB = XmCreatePushButton(PushButtonRow,
+			(char *) "Exit", args, ac);
 #ifndef USE_MB
 		XmStringFree(label_str);
 #endif
-		XtAddCallback(exitwidgetB, XmNactivateCallback, exitcallback, (XtPointer) NULL);
+		XtAddCallback(exitwidgetB, XmNactivateCallback, exitcallback,
+			(XtPointer) NULL);
 		XtManageChild(exitwidgetB);
 
 	
@@ -406,7 +408,8 @@ main(int argc, char **argv)
 
 /* PURIFY 4.0.1 on Solaris 2 reports an unitialized memory read on the next
    line. */
-	toplevel = XtInitialize(argv[0], "XmLock", NULL, 0, &argc, argv);
+	toplevel = XtInitialize(argv[0], "XmLock", (XrmOptionDescRec*) NULL, 0,
+		&argc, argv);
 	XtSetArg(args[0], XtNiconPixmap,
 		 XCreateBitmapFromData(XtDisplay(toplevel),
 				       RootWindowOfScreen(XtScreen(toplevel)),
@@ -415,7 +418,7 @@ main(int argc, char **argv)
 	/* creation Widget */
 /* PURIFY 4.0.1 on Solaris 2 reports an unitialized memory read on the next
    line. */
-	form = XmCreateForm(toplevel, (char *) "Form", NULL, 0);
+	form = XmCreateForm(toplevel, (char *) "Form", (Arg *) NULL, 0);
 	Setup_Widget(form);
 	setup_Option(Menuoption);
 	XtManageChild(form);
